/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include <assert.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "alloc.h"

include(`common.m4')
define(`ALLOCS', `
`$1'* alloc`$1'() { 
	`$1'* res = calloc(1, sizeof *res);
	return res;
}

/*@
  @   requires  is_allocated{Pre}((char*)ptr);
  @   assigns  __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   frees ptr;
  @   ensures !is_allocated{Post}((char*)ptr);
  @   ensures old_allocated{Pre,Post}((char *)ptr);
  @   ensures \forall size_t s; is_allocated_size{Pre}((char*)ptr,s) ==> \at(__size_allocated,Post) == \at(__size_allocated,Pre) - s;
  @   ensures allocation_footprint{Post,Pre}((size_t)(\block_length{Pre}((char*)ptr)), (size_t)1);
  @*/
void free`$1'(`$1'* ptr) {
	free(ptr);
}

/*@
  @   requires  is_allocated{Pre}((char*)(*ptr)) && \valid(*ptr) && \valid(ptr);
  @   assigns  __allocated[__num_allocated], __size_allocated, __num_allocated, *ptr;
  @   frees *ptr;
  @   ensures !is_allocated{Post}((char*)(*ptr));
  @   ensures old_allocated{Pre,Post}((char *)(*ptr));
  @   ensures \forall size_t s; is_allocated_size{Pre}((char*)(*ptr),s) ==> \at(__size_allocated,Post) == \at(__size_allocated,Pre) - s;
  @   ensures allocation_footprint{Post,Pre}((size_t)(\block_length{Pre}((char*)(*ptr))), (size_t)1);
  @   ensures *ptr == 0;
  @*/
void free`$1'z(`$1'** ptr) {
	free(*ptr);
	*ptr = 0;
}

/*@ requires valid_`$1'_ptr(arg);
  @ behavior allocation:
  @   assumes is_allocable{Pre}((size_t)sizeof(`$1'),(size_t)1);
  @   assigns __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   ensures allocation_footprint{Pre,Post}((size_t)(sizeof(`$1')),(size_t)1);
  @   ensures is_allocated_size{Post}((char*)\result,(size_t)(sizeof(`$1')));
  @   ensures \valid((char*)\result+(0..sizeof(`$1')-1));
  @   ensures \result!=\null;
  @   ensures isShallowCopyOf`$1'{Post,Pre}(*\result,*arg);
  @ behavior no_allocation:
  @   assumes !is_allocable{Pre}((size_t)sizeof(`$1'),(size_t)1);
  @   assigns \nothing;
  @   ensures \result==\null;
  @   ensures allocation_footprint{Pre,Post}((size_t)0,(size_t)0);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
`$1'* copy`$1'(const `$1'* arg) {
	/* FIXME FIXME FIXME make deep copy */
	return make`$1'(*arg);
}
')

define(`PREMAKE', `
`$1'* make`$1'(const `$1' arg) {
  `$1'* res = alloc`$1'();
  if (res==NULL) return NULL;
  res->which = arg.which;')

define(`POSTMAKE', `  return res;
}
')



ALLOCS(Type)
PREMAKE(Type)
  START:
  res->tVar = arg.tVar;
  res->tAll = arg.tAll;
  //@ assert res->tVar == arg.tVar && res->tAll == arg.tAll;
  //@ assert isShallowCopyOfType{Here,START}(arg,arg);
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Type)));
  res->tApp = arg.tApp;
  res->tExi = arg.tExi;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Type)));
  res->tAnd = arg.tAnd;
  res->tOr = arg.tOr;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Type)));
  res->tBot = arg.tBot;
POSTMAKE(Type)

ALLOCS(Term)
PREMAKE(Term)
  START:
  res->mVar = arg.mVar;
  res->mApp = arg.mApp;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mLam = arg.mLam;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mWit = arg.mWit;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mAbs = arg.mAbs;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mTup = arg.mTup;
  //@ assert res->mVar == arg.mVar && res->mApp == arg.mApp;
  //@ assert res->mLam == arg.mLam && res->mWit == arg.mWit;
  //@ assert res->mAbs == arg.mAbs && res->mTup == arg.mTup;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mPi1 = arg.mPi1;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mPi2 = arg.mPi2;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mIn1 = arg.mIn1;
  //@ assert res->mVar == arg.mVar && res->mApp == arg.mApp;
  //@ assert res->mLam == arg.mLam && res->mWit == arg.mWit;
  //@ assert res->mAbs == arg.mAbs && res->mTup == arg.mTup  && res->mPi1 == arg.mPi1 && res->mPi2 == arg.mPi2  && res->mIn1 == arg.mIn1;
  //@ assert isShallowCopyOfTerm{Here,START}(arg,arg);
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mIn2 = arg.mIn2;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mCas = arg.mCas;
  //@ assert is_allocated_size((char*)res,(size_t)(sizeof(Term)));
  res->mEps = arg.mEps;
POSTMAKE(Term)

ALLOCS(Kind)
PREMAKE(Kind)
  res->kStar = arg.kStar;
  res->kPi = arg.kPi;
POSTMAKE(Kind)

ALLOCS(Any)
PREMAKE(Any)
  res->mType = arg.mType;
  res->mTerm = arg.mTerm;
  res->mKind = arg.mKind;
  res->mName = arg.mName;
  res->mBind = arg.mBind;
POSTMAKE(Any)


/*@ requires size+1 <= UINT32_MAX;
  @ behavior allocation:
  @   assumes is_allocable{Pre}((size_t)(size+1),(size_t)1);
  @   assigns __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   ensures allocation_footprint{Pre,Post}((size_t)(size+1),(size_t)1);
  @   ensures is_allocated_size{Post}((char*)\result,(size_t)(size+1));
  @   ensures \forall char* p; (is_allocated{Pre}(p) ==> p != (char*)\result);
  @   ensures \forall char* p, size_t n; is_allocated_size{Pre}(p,n) ==> is_allocated_size{Post}(p,n);
  @   ensures \forall size_t i; 0 <= i <= \at(__num_allocated,Post)-1 ==> \at(__allocated[i],Post) == \at(__allocated[i],Pre);
  @   ensures __allocated[__num_allocated-1] == (char*)\result;
  @   ensures \valid((char*)\result+(0..size));
  @   ensures \separated(__allocated+(0..MAX_ALLOCS-1),(char*)\result+(0..size));
  @   ensures \forall char** a, size_t s; is_allocated_size{Pre}((char*)a, s) ==> 
  @                     \separated((char*)\result+(0..(size_t)(size)),a+(0..s-1));
  @   ensures \forall char* p, size_t n; is_allocated_size{Pre}(p,n) ==> is_allocated_size{Post}(p,n);
  @   ensures \result!=\null;
  @ behavior no_allocation:
  @   assumes !is_allocable{Pre}((size_t)(size+1),(size_t)1);
  @   assigns \nothing;
  @   ensures \result==\null;
  @   ensures allocation_footprint{Pre,Post}((size_t)0,(size_t)0);
  @   ensures \forall char* p, size_t n; is_allocated_size{Pre}(p,n) ==> is_allocated_size{Post}(p,n);
  @   ensures \forall size_t i; 0 <= i <= \at(__num_allocated,Post) ==> \at(__allocated[i],Post) == \at(__allocated[i],Pre);
  @   ensures !is_allocable{Pre}((size_t)(size+1),(size_t)1);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
Name allocName(size_t size) { 
/* size = size of string excluding terminating NULL */
	Name res = calloc(1, size+1);
	return res;
}

/*@ requires valid_string(arg);
  @ requires strlen(arg)+1 <= UINT32_MAX;
  @ behavior allocation:
  @   assumes is_allocable{Pre}((size_t)(strlen(arg)+1),(size_t)1);
  @   assigns __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   ensures allocation_footprint{Pre,Post}((size_t)(strlen(arg)+1),(size_t)1);
  @   ensures is_allocated_size{Post}((char*)\result,(size_t)strlen(arg));
  @   ensures \valid((char*)\result+(0..strlen(arg)));
  @   ensures \result!=\null;
  @ behavior no_allocation:
  @   assumes !is_allocable{Pre}((size_t)(strlen(arg)+1),(size_t)1);
  @   assigns \nothing;
  @   ensures \result==\null;
  @   ensures allocation_footprint{Pre,Post}((size_t)0,(size_t)0);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
Name makeName(const Name arg) {
     Name res = allocName(strlen(arg));
     //@ assert valid_string(arg);
     if (res==NULL) return NULL;
     strcpy(res, arg);
     return res;
}

/*@ requires valid_string(arg);
  @ requires strlen(arg)+1 <= UINT32_MAX;
  @ behavior allocation:
  @   assumes is_allocable{Pre}((size_t)(strlen(arg)+1),(size_t)1);
  @   assigns __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   ensures allocation_footprint{Pre,Post}((size_t)(strlen(arg)+1),(size_t)1);
  @   ensures is_allocated_size{Post}((char*)\result,(size_t)strlen(arg));
  @   ensures \valid((char*)\result+(0..strlen(arg)));
  @   ensures \result!=\null;
  @ behavior no_allocation:
  @   assumes !is_allocable{Pre}((size_t)(strlen(arg)+1),(size_t)1);
  @   assigns \nothing;
  @   ensures \result==\null;
  @   ensures allocation_footprint{Pre,Post}((size_t)0,(size_t)0);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
Name copyName(const Name arg) {
	return makeName(arg);
}

/*@
  @   requires  is_allocated{Pre}((char*)ptr);
  @   assigns  __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   frees ptr;
  @   ensures !is_allocated{Post}((char*)ptr);
  @   ensures old_allocated{Pre,Post}((char *)ptr);
  @   ensures \forall size_t s; is_allocated_size{Pre}((char*)ptr,s) ==> \at(__size_allocated,Post) == \at(__size_allocated,Pre) - s;
  @   ensures allocation_footprint{Post,Pre}((size_t)(\block_length{Pre}((char*)ptr)), (size_t)1);
  @*/
void freeName(Name ptr) {
	free(ptr);
}

/*@   requires \valid(ptr) && valid_string(*ptr);
  @   requires  is_allocated{Pre}((char*)(*ptr));
  @   assigns  __allocated[__num_allocated], __size_allocated, __num_allocated, *ptr;
  @   frees *ptr;
  @   ensures !is_allocated{Post}((char*)(*ptr));
  @   ensures old_allocated{Pre,Post}((char *)(*ptr));
  @   ensures \forall size_t s; is_allocated_size{Pre}((char*)(*ptr),s) ==> \at(__size_allocated,Post) == \at(__size_allocated,Pre) - s;
  @   ensures allocation_footprint{Post,Pre}((size_t)(\block_length{Pre}((char*)(*ptr))), (size_t)1);
  @   ensures *ptr == 0;
  @*/
void freeNamez(Name* ptr) {
	free(*ptr);
        //@ assert !is_allocated{Here}((char*)(*ptr));
        //@ assert old_allocated{Pre,Here}((char *)(*ptr));
        //@ assert \forall size_t s; is_allocated_size{Pre}((char*)(*ptr),s) ==> \at(__size_allocated,Here) == \at(__size_allocated,Pre) - s;
        //@ assert allocation_footprint{Here,Pre}((size_t)(\block_length{Pre}((char*)(*ptr))), (size_t)1);
	*ptr = 0;
}

void die(const char* reason) {
	fprintf(stderr, "%s", reason);
	abort();
}


