/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
/**
 * @file errorMessages.h
 * @brief Implementation of procedures that handle printing of error messages.
 * @author Aleksy Schubert
 */
#ifndef _ERRORMESSAGES_H
#define _ERRORMESSAGES_H  1
#include <stdlib.h>

#define BUFFER_LEN 4096
extern char errorBuffer[BUFFER_LEN];
//@ logic size_t L_BUFFER_LEN = (size_t)4096;
extern int errorNum;


//@ logic size_t ENV_MSG_UNDECLARED_TVAR = (size_t)0;
#define ENV_MSG_UNDECLARED_TVAR             0
//@ logic size_t ENV_MSG_OBJECT_VAR = (size_t)1;
#define ENV_MSG_OBJECT_VAR                  1
//@ logic size_t ENV_MSG_UNDECLARED_MVAR = (size_t)2;
#define ENV_MSG_UNDECLARED_MVAR             2
//@ logic size_t ENV_MSG_TVAR = (size_t)3;
#define ENV_MSG_TVAR                        3
//@ logic size_t ENV_MSG_TNAME_DEFINED = (size_t)4;
#define ENV_MSG_TNAME_DEFINED               4
//@ logic size_t ENV_MSG_ONAME_DEFINED = (size_t)5;
#define ENV_MSG_ONAME_DEFINED               5
//@ logic size_t ENV_MSG_WRONG_ACTUAL_KIND = (size_t)6;
#define ENV_MSG_WRONG_ACTUAL_KIND           6
//@ logic size_t ENV_MSG_EXPECTED_PRODUCT_KIND = (size_t)7;
#define ENV_MSG_EXPECTED_PRODUCT_KIND       7
//@ logic size_t ENV_MSG_WRONG_ACTUAL_TYPE = (size_t)8;
#define ENV_MSG_WRONG_ACTUAL_TYPE           8
//@ logic size_t ENV_MSG_IN_INFERTERM = (size_t)9;
#define ENV_MSG_IN_INFERTERM                9
//@ logic size_t ENV_MSG_NOT_FUNCTION_TYPE = (size_t)10;
#define ENV_MSG_NOT_FUNCTION_TYPE          10
//@ logic size_t ENV_MSG_WITNESS_FOR_NONEXISTENTIAL = (size_t)11;
#define ENV_MSG_WITNESS_FOR_NONEXISTENTIAL 11
//@ logic size_t ENV_MSG_IN = (size_t)12;
#define ENV_MSG_IN                         12
//@ logic size_t ENV_MSG_IN_INFERTERM_CHECK = (size_t)13;
#define ENV_MSG_IN_INFERTERM_CHECK         13
//@ logic size_t ENV_MSG_TUPLE_NOT_AND = (size_t)14;
#define ENV_MSG_TUPLE_NOT_AND              14
//@ logic size_t ENV_MSG_IS_NOT_PAIR = (size_t)15;
#define ENV_MSG_IS_NOT_PAIR                15
//@ logic size_t ENV_MSG_IN_CASE = (size_t)16;
#define ENV_MSG_IN_CASE                    16
//@ logic size_t ENV_MSG_UNHANDLED_TERM = (size_t)17;
#define ENV_MSG_UNHANDLED_TERM             17
//@ logic size_t ENV_MSG_PRINT_BUFFER_OVERFLOW = (size_t)18;
#define ENV_MSG_PRINT_BUFFER_OVERFLOW             18
//@ logic size_t ENV_MSG_UNHANDLED_TYPE = (size_t)19;
#define ENV_MSG_UNHANDLED_TYPE             19
//@ logic size_t ENV_MSG_NO_KIND_FOR_TYPE = (size_t)20;
#define ENV_MSG_NO_KIND_FOR_TYPE             20
//@ logic size_t ENV_MSG_IMPOSSIBLE_COPY_ENV = (size_t)21;
#define ENV_MSG_IMPOSSIBLE_COPY_ENV             21
//@ logic size_t ENV_MSG_CANNOT_INSERT_VARIABLE = (size_t)22;
#define ENV_MSG_CANNOT_INSERT_VARIABLE             22


//@ logic size_t ENV_MSG_MAX = (size_t)ENV_MSG_NO_KIND_FOR_TYPE;
#define ENV_MSG_MAX                        ENV_MSG_CANNOT_INSERT_VARIABLE

extern char * messages[];

/*@ axiomatic messages {
  @
  @
  @    axiom valid_messages:
  @       \forall size_t i; 0 <= i <= ENV_MSG_MAX ==>
  @              valid_string(messages[i]);
  @ }
  @*/

/*@ predicate errorBufferValid(integer a) = valid_string((char*)errorBuffer) && 
  @          0 <= errorNum < 2147483647 &&
  @          strlen((char*)errorBuffer) < L_BUFFER_LEN;
  @*/


/*@
  @ requires valid_string(a);
  @ requires errorBufferValid(0) && errorNum < 2147483646;
  @ assigns errorBuffer[0..4095], errorNum;
  @ ensures errorBufferValid(0) && errorNum == \old(errorNum)+1;
  @*/
void reportError(char *a);

#endif
