/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include <assert.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "free.h"
#include "alloc.h"


/*@ axiomatic carrier {

  @
  @   logic set<Kind*> carrierOfKpiKind{L}(Kpi k);
  @   logic set<Kind*> carrierOfKindKind{L}(Kind* t);
  @
  @   axiom carrierOfKpiKind_def{L}:
  @        \forall Kpi k; carrierOfKpiKind{L}(k) == carrierOfKindKind{L}(k.kind);
  @
  @   axiom carrierOfKindKind_def{L}:
  @        \forall Kind* t;
  @            (t->which==eKstar ==> carrierOfKindKind{L}(t)==(t)) &&
  @            (t->which==eKpi  ==> carrierOfKindKind{L}(t)==\union(carrierOfKpiKind{L}(t->kPi),(t))) &&
  @            ((t->which!=eKstar && t->which!=eKpi) ==> carrierOfKindKind{L}(t)==\empty);
  @
  @   logic set<Name> carrierOfKpiName{L}(Kpi k);
  @   logic set<Name> carrierOfKindName{L}(Kind* t);
  @   logic set<Name> carrierOfTypeName{L}(Type* t);
  @
  @   axiom carrierOfKpiName_def{L}:
  @        \forall Kpi k; carrierOfKpiName{L}(k) == 
  @             \union(k.name, \union(carrierOfTypeName{L}(k.type),
  @                                   carrierOfKindName{L}(k.kind)));
  @
  @   axiom carrierOfKindName_def{L}:
  @        \forall Kind *k; carrierOfKindName{L}(k) == carrierOfKpiName{L}(k->kPi);
  @
  @   axiom carrierOfTypeName_def{L}:
  @        \forall Type *t; carrierOfTypeName{L}(t) == \empty; //TODO: this must be changed
  @
  @
  @  //predicate is_allocatedKind{L}(Kind *t) = 
  @ 
  @ }
  @*/

/* --------------------------------- freeKind -------------------*/

/*@ // specyfikacja separacji wskaźników
  @ requires \separated(carrierOfKindKind(t));
  @ //requires \separated(carrierOfKindTerm(t));
  @ //requires \separated(carrierOfKindType(t));
  @ requires \separated(carrierOfKindName(t));
  @
  @ // specyfikacja, że wszystko w drzewie widocznym w t zaalokowane
  @ requires \forall Kind* p; \union(p, carrierOfKindKind(t)) == carrierOfKindKind(t)  ==> 
  @                 is_allocated_size((char*)p,
                                      (size_t)sizeof(Kind));

  @
  @ assigns  __allocated[0..__num_allocated], __size_allocated, __num_allocated;
  @
  @ // po wyjściu wszystko widoczne z t zwolnione
  @ //ensures !is_allocatedKindPrePost{Pre,Post}(t);
  @
  @ // cała reszta natomiast nie jest zwolniona
  @ //ensures old_allocated{Pre,Post}(t);
  @
  @ // ile pamięci zostało zwolnione
  @ //ensures allocation_footprint{Post,Pre}((size_t)(\block_length{Pre}((char*)(*ptr))), (size_t)1);
  @*/
void freeKindDeep(Kind* t) {
  switch (t->which) {
  case eKstar:
    freeKStarDeep(t->kStar);
    break;
  case eKpi:
    freeKpiDeep(t->kPi);
    break;
  default: /* nothing */
    break;
  }
  free(t);
}

void freeKStarDeep(Kstar t) { /* nothing is freed */
}

void freeKpiDeep(Kpi t) {
  freeName(t.name);
  //freeTypeDeep(t.type);
  freeKindDeep(t.kind);
}


/* --------------------------------- freeType -------------------*/

void freeTypeDeep(Type* t) {
  switch (t->which) {
  case etVar:
    freeVarParts(t->tVar);
    break;
  case etAll:
    freeAllParts(t->tAll);
    break;
  case etApp:
    freeAppParts(t->tApp);
    break;
  case etExi:
    freeExiParts(t->tExi);
    break;
  case etAnd:
    freeAndParts(t->tAnd);
    break;
  case etOr:
    freeOrParts(t->tOr);
    break;
  case etBot:
    freeBotParts(t->tBot);
    break;
  default: /* nothing */
    break;
  }
  free(t);
}

void freeVarParts(Tvar t) {
  freeName(t.name);
}

void freeAllParts(Tall t) {
  freeName(t.name);
  freeTypeDeep(t.type1);
  freeTypeDeep(t.type2);
}

void freeAppParts(Tapp t) {
  freeTypeDeep(t.type);
  freeTermDeep(t.term);
}

void freeExiParts(Texi t) {
  freeName(t.name);
  freeTypeDeep(t.type1);
  freeTypeDeep(t.type2);
}

void freeAndParts(Tand t) {
  freeTypeDeep(t.type1);
  freeTypeDeep(t.type2);
}

void freeOrParts(Tor t) {
  freeTypeDeep(t.type1);
  freeTypeDeep(t.type2);
}

void freeBotParts(Tbot t) { /* nothing is freed */
}

/* --------------------------------- freeTerm -------------------*/

void freeTermDeep(Term* t) {
  switch (t->which) {
  case emVar:
    freeMVarParts(t->mVar);
    break;
  case emApp:
    freeMAppParts(t->mApp);
    break;
  case emLam:
    freeMLamParts(t->mLam);
    break;
  case emWit:
    freeMWitParts(t->mWit);
    break;
  case emAbs:
    freeMAbsParts(t->mAbs);
    break;
  case emTup:
    freeMTupParts(t->mTup);
    break;
  case emPi1:
    freeMPi1Parts(t->mPi1);
    break;
  case emPi2:
    freeMPi2Parts(t->mPi2);
    break;
  case emIn1:
    freeMIn1Parts(t->mIn1);
    break;
  case emIn2:
    freeMIn2Parts(t->mIn2);
    break;
  case emCas:
    freeMCasParts(t->mCas);
    break;
  case emEps:
    freeMEpsParts(t->mEps);
    break;
  default: /* nothing */
    break;
  }
  free(t);
}

void freeMVarParts(Mvar t) {
  freeName(t.name);
}

void freeMAppParts(Mapp t) {
  freeTermDeep(t.term1);
  freeTermDeep(t.term2);
}

void freeMLamParts(Mlam t) {
  freeName(t.name);
  freeTypeDeep(t.type);
  freeTermDeep(t.term);
}

void freeMWitParts(Mwit t) {
  freeTypeDeep(t.type);
  freeTermDeep(t.term1);
  freeTermDeep(t.term2);
}

void freeMAbsParts(Mabs t) {
  freeName(t.name1);
  freeTypeDeep(t.type2);
  freeName(t.name3);
  freeTypeDeep(t.type4);
  freeTermDeep(t.term5);
  freeTermDeep(t.term6);
}

void freeMTupParts(Mtup t) {
  freeTypeDeep(t.type);
  freeTermDeep(t.term1);
  freeTermDeep(t.term2);
}

void freeMPi1Parts(Mpi1 t) {
  freeTermDeep(t.term);
}

void freeMPi2Parts(Mpi2 t) {
  freeTermDeep(t.term);
}

void freeMIn1Parts(Min1 t) {
  freeTypeDeep(t.type);
  freeTermDeep(t.term);
}

void freeMIn2Parts(Min2 t) {
  freeTypeDeep(t.type);
  freeTermDeep(t.term);
}

void freeCasInParts(McasIn t) {
  freeName(t.name);
  freeTypeDeep(t.type);
  freeTermDeep(t.term);
}

void freeMCasParts(Mcas t) {
  freeTermDeep(t.term);
  freeCasInParts(t.casIn1);
  freeCasInParts(t.casIn2);
}

void freeMEpsParts(Meps t) {
  freeTypeDeep(t.type);
  freeTermDeep(t.term);
}

/* --------------------------------- freeAny -------------------*/

void freeAnyDeep(Any* t) {
  switch (t->which) {
  case eAnyType:
    freeTypeDeep(t->mType);
    break;
  case eAnyTerm:
    freeTermDeep(t->mTerm);
    break;
  case eAnyKind:
    freeKindDeep(t->mKind);
    break;
  case eAnyName:
    freeName(t->mName);
    break;
  case eAnyBind:
    freeBindParts(t->mBind);
    break;
  default: /* nothing */
    break;
  }
  free(t);
}


void freeBindParts(Bind b) {
	freeName(b.name);
	freeTypeDeep(b.type);
	freeAnyDeep(b.any);
}


void freeNameDeep(Name* n) {
  freeName(*n);
  free(n);
}
