/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include "alloc.h"
#include "free.h"
#include "checker.h"
#include "gen_spec_checker.h"
#include "namemap.h"
#include <stdio.h>
#include <stdint.h>
#include <assert.h>


//! FILE GenChecker.hs 


// forward declarations for mutual recursion
Any renameM(Name, Name, const Any) ;
Term *renameM_term(Name, Name, const Term *const) ;

//! 16
//!     go n = if v n `elem` fvs then go (n+1) else v n
//!     v k = "v" ++ show k

/*@ requires true;
  @ assigns \nothing;
  @ ensures valid_Name(\result);
  @*/

static Name v(unsigned k) {
	size_t len = snprintf(NULL, 0, "v%d", k);
	assert(len>0); /* check for nonconforming sprintf */
	Name res   = allocName(len);
	size_t tmp = snprintf(res, len, "v%d", k);
	assert(tmp == len);
	return res;
}


/* axiomatic Name_injectivity{
  @   axiom Name_inj : \forall unsigned k1, k2; k1 != k2 ==> !EqName(v(k1),v(k2));
  @ }
  @*/



//! 14 17
//! freshNameFvs :: [Name] -> Name
//! freshNameFvs fvs = go 0 where
//!     go n = if v n `elem` fvs then go (n+1) else v n

/* requires valid_Nameset(fv);
  @ ensures valid_Name(\result) && isIn(\result, fv) < 0;
  @*/

/* does shallow free on argument */
/* is it a good idea? Can we specify that the result is fresh? */
Name freshNameFvs(nameSet *fv) {
	Name res;
	size_t n;
	for (n = 0; n<SIZE_MAX; ++n) 
		if (isIn(fv, (res=v(n)))<0)
			break;
		else {
			freeName(res);
			res = NULL;
		}
	freeSetShallow(fv);
	if (!res)
		die("Name space exhausted!");
	else 
		return res;
}

/* moze to niepotrzebne... a w kadym razie skomplikowane...

/*@ inductive occurKind(Name n, Kind k) = {
  @   case oKstar:
  @     \forall Name n; \forall Kind k; 
  @       k.which == k.eKstar && false ==> occurKind(n, k)
  @   case oKpi:
  @     \forall Name n; \forall Kind k; 
  @       k.which == k.eKpi && 
  @         (occurType(n, k.kPi.type) || 
  @         (!eqName(n, k.kPi.name) && occurKind(n, k.kPi.kind))) 
  @       ==> occurKind(n, k)  
  @*/

/*@ axiomatic occur{

  @ predicate occurKind(Name n, Kind *k);
  @ predicate occurType(Name n, Type *t);
  @ predicate occurTerm(Name n, Term *t);
  @ predicate occurAny(Name n, Any *a);
  @
  @ predicate occurBind(Name n, Bind b);
  @

  @ axiom oKstar:
  @     \forall Name n; \forall Kind *k; 
  @       k->which == eKstar 
  @       ==> !occurKind(n, k);
  @
  @ axiom oKpi:
  @     \forall Name n; \forall Kind *k; 
  @       k->which == eKpi ==>
  @         ((occurType(n, k->kPi.type) || 
  @         (!eqName(n, k->kPi.name) && occurKind(n, k->kPi.kind))) 
  @       <==> occurKind(n, k));
  @

  @ axiom otVar:
  @     \forall Name n; \forall Type *t; 
  @       t->which == etVar ==> 
  @         (t->tVar.name == n 
  @       <==> occurType(n, t));
  @
  @ axiom otAll:
  @     \forall Name n; \forall Type *t;
  @       t->which == etAll ==>
  @         (occurType(n, t->tAll.type1) || 
  @           (t->tAll.name != n && occurType(n, t->tAll.type2))
  @         <==> occurType(n, t));
  @
  @ axiom otApp:
  @     \forall Name n; \forall Type *t;
  @       t->which == etApp ==>
  @         (occurType(n, t->tApp.type) || occurTerm(n, t->tApp.term)
  @         <==> occurType(n, t));
  @
  @ axiom otExi:
  @     \forall Name n; \forall Type *t;
  @       t->which == etExi ==>
  @         (occurType(n, t->tExi.type1) ||
  @           (t->tExi.name != n && occurType(n, t->tExi.type2))
  @         <==> occurType(n, t));
  @
  @ axiom otAnd:
  @     \forall Name n; \forall Type *t;
  @       t->which == etAnd ==>
  @         (occurType(n, t->tAnd.type1) || occurType(n, t->tAnd.type2)
  @         <==> occurType(n, t));
  @
  @ axiom otOr:
  @     \forall Name n; \forall Type *t;
  @       t->which == etOr ==> 
  @         (occurType(n, t->tOr.type1) || occurType(n, t->tOr.type2)
  @         <==> occurType(n, t));
  @
  @ axiom otBot:
  @     \forall Name n; \forall Type *t;
  @       t->which == etBot 
  @       ==> !occurType(n, t);
  @

  @ axiom omVar:
  @     \forall Name n; \forall Term *m;
  @       m->which == emVar ==>
  @         (m->mVar.name == n
  @         <==> occurTerm(n, m));
  @
  @ axiom omApp:
  @     \forall Name n; \forall Term *m;
  @       m->which == emApp ==>
  @         (occurTerm(n, m->mApp.term1) || occurTerm(n, m->mApp.term2)
  @         <==> occurTerm(n, m));
  @
  @ axiom omLam:
  @     \forall Name n; \forall Term *m;
  @       m->which == emLam ==>
  @         (occurType(n, m->mLam.type) ||
  @           (m->mLam.name != n && occurTerm(n, m->mLam.term))
  @         <==> occurTerm(n, m));
  @
  @ axiom omWit:
  @     \forall Name n; \forall Term *m;
  @       m->which == emWit ==>
  @         (occurType(n, m->mWit.type) || occurTerm(n, m->mWit.term1) ||
  @            occurTerm(n, m->mWit.term2)
  @         <==> occurTerm(n, m));
  @
  @ axiom omAbs:
  @     \forall Name n; \forall Term *m;
  @       m->which == emAbs ==>
  @         (occurType(n, m->mAbs.type2) ||
  @          (m->mAbs.name1 != n && occurType(n, m->mAbs.type4)) ||
  @          occurTerm(n, m->mAbs.term5) ||
  @          (m->mAbs.name1 != n && m->mAbs.name3 != n &&
  @             occurTerm(n, m->mAbs.term6))
  @         <==> occurTerm(n, m));
  @
  @ axiom omTup:
  @     \forall Name n; \forall Term *m;
  @       m->which == emTup ==>
  @         (occurType(n, m->mTup.type) || occurTerm(n, m->mTup.term1) ||
  @            occurTerm(n, m->mTup.term2)
  @         <==> occurTerm(n, m));
  @
  @ axiom omPi1:
  @     \forall Name n; \forall Term *m;
  @       m->which == emPi1 ==>
  @         (occurTerm(n, m->mPi1.term)
  @         <==> occurTerm(n, m));
  @
  @ axiom omPi2:
  @     \forall Name n; \forall Term *m;
  @       m->which == emPi2 ==>
  @         (occurTerm(n, m->mPi2.term)
  @         <==> occurTerm(n, m));
  @
  @ axiom omIn1:
  @     \forall Name n; \forall Term *m;
  @       m->which == emIn1 ==>
  @         (occurType(n, m->mIn1.type) || occurTerm(n, m->mIn1.term)
  @         <==> occurTerm(n, m));
  @
  @ axiom omIn2:
  @     \forall Name n; \forall Term *m;
  @       m->which == emIn2 ==>
  @         (occurType(n, m->mIn2.type) || occurTerm(n, m->mIn2.term)
  @         <==> occurTerm(n, m));
  @
  @ axiom omCas:
  @     \forall Name n; \forall Term *m;
  @       m->which == emCas ==>
  @         (occurTerm(n, m->mCas.term) ||
  @          occurType(n, m->mCas.casIn1.type) ||
  @          (m->mCas.casIn1.name != n && occurTerm(n, m->mCas.casIn1.term)) ||
  @          occurType(n, m->mCas.casIn2.type) ||
  @          (m->mCas.casIn2.name != n && occurTerm(n, m->mCas.casIn2.term))
  @         <==> occurTerm(n, m));
  @
  @ axiom omEps:
  @     \forall Name n; \forall Term *m;
  @       m->which == emEps ==>
  @         (occurType(n, m->mEps.type) || occurTerm(n, m->mEps.term)
  @         <==> occurTerm(n, m));
  @

  @ axiom oBind:
  @     \forall Name n; \forall Bind b;
  @       occurType(n, b.type) || (b.name != n && occurAny(n, b.any))
  @       <==> occurBind(n, b);
  @        


  @ axiom oaType:
  @     \forall Name n; \forall Any *a;
  @       a->which == eAnyType ==>
  @       (occurType(n, a->mType) <==> occurAny(n, a));
  @
  @ axiom oaTerm:
  @     \forall Name n; \forall Any *a;
  @       a->which == eAnyTerm ==>
  @       (occurTerm(n, a->mTerm) <==> occurAny(n, a));
  @
  @ axiom oaKind:
  @     \forall Name n; \forall Any *a;
  @       a->which == eAnyKind ==>
  @       (occurKind(n, a->mKind) <==> occurAny(n, a));
  @
  @ axiom oaName:
  @     \forall Name n; \forall Any *a;
  @       a->which == eAnyName ==>
  @       (eqName(n, a->mName) <==> occurAny(n, a));
  @
  @ axiom oaBind:
  @     \forall Name n; \forall Any *a;
  @       a->which == eAnyBind ==>
  @       (occurBind(n, a->mBind) <==> occurAny(n, a)); 
  @

  @ 
  @ }
  @*/

Name freshName(const Any arg) {
	return freshNameFvs(freeNames(arg));
}

//! GenChecker.hs 68 73 
//!   substT n s t@(n1,t1,a)
//!       | n == n1 = (n1,substT n s t1,a)
//!       | n1 `elem` freeNames s = (n', substT n s t1, substT n s t')
//!       | otherwise = (n1, substT n s t1, substT n s a)
//!         where t' = renameM n1 n' a
//!               n' = freshName s
// Bind substT_bind(Name n, Type *s, const Bind t)
// parameter t is expanded to ease memory management
Bind substT_bind(Name n, Type *s, Name n1, Type* t1, const Any a)
{
	nameSet *set;
	Bind res;
	if (strcmp(n, n1)==0) {
		res = (Bind){.name = copyName(n1),
				.type = substT_type(n, s, t1),
				.any = copyAnyDeep(&a) /* so we don't need to copy insides */
				};
	} else if (isIn((set=freeNames(anyOfType(s))), n1)>=0) {
		Name  n_=freshName(anyOfType(s));
		Any t_ = renameM(n1, copyName(n_), a);
		res = (Bind){.name = n_,
				.type = substT_type(copyName(n), copyType(s), t1),
				.any = makeAny(substT(n, s, t_))
			};
	} else {
		res = (Bind){.name = n1,
				.type = substT_type(copyName(n), copyType(s), t1),
				.any  = makeAny(substT(n, s, a))
		};
	}

	if (set)
		freeSetShallow(set);

	assert(res.any->which == a.which);
	return res;
}

//! GenChecker.hs 74 79
//!   substM n s t@(n1,t1,a)
//!       | n == n1 = (n1,substM n s t1,a)
//!       | n1 `elem` freeNames s = (n', substM n s t1, substM n s t')
//!       | otherwise = (n1, substM n s t1, substM n s a)
//!         where t' = renameM n1 n' a
//!               n' = freshName s
Bind substM_bind(Name n, Term *s, Name n1, Type* t1, const Any a)
{
	nameSet *set;
	Bind res;
	if (strcmp(n, n1)==0) {
		res = (Bind){.name = n1,
				.type = substM_type(n, s, t1),
				.any = copyAnyDeep(&a)
				};
	} else if (isIn((set=freeNames(anyOfTerm(s))), n1)>=0) {
		Name  n_=freshName(anyOfTerm(s));
		Any t_ = renameM(n1, copyName(n_), a);
		res = (Bind){.name = n_,
				.type = substM_type(copyName(n), copyTerm(s), t1),
				.any = makeAny(substM(n, s, t_))
			};
	} else {
		res = (Bind){.name = n1,
				.type = substM_type(copyName(n), copyTerm(s), t1),
				.any  = makeAny(substM(n, s, a))
		};
	}

	if (set)
		freeSetShallow(set);

	assert(res.any->which == a.which);
	return res;
}

//! 24
//!   substT :: Name -> Type -> a -> a

//! 130 136
//!     sub t@(Tvar n1) = if n == n1 then s else  t
//!     sub t@(Tall n1 t1 t2) = uncurry3 Tall $ substT n s (n1,t1,t2)
//!     sub t@(Tapp t1 m) = uncurry Tapp $ substT n s (t1,m)
//!     sub t@(Texi n1 t1 t2) = uncurry3 Texi $ substT n s (n1,t1,t2)
//!     sub t@(Tand t1 t2) = Tand (sub t1) (sub t2)
//!     sub t@(Tor t1 t2) = Tor (sub t1) (sub t2)
//!     sub Tbot = Tbot
Type *substT_type(Name n, Type *s, const Type const*t) {
	Type *res;
	switch (t->which) {
		case etVar:
			if (strcmp(n, t->tVar.name) == 0)
				res = copyTypeDeep(s);
			else
				res = copyTypeDeep(t);
			break;
		case etAll: {
			Bind b = substT_bind(n, s, t->tAll.name, t->tAll.type1, (anyOfType(t->tAll.type2))); 
			assert(b.any->which==eAnyType);
			res = makeType((Type){
				.which=etAll,
				.tAll={.name = copyName(b.name),
					.type1 = copyTypeDeep(b.type),
					.type2 = copyTypeDeep(b.any->mType)
				}
			});
			freeBindParts(b);
			break; }
		case etApp: 
			// FIXME: refactor if pair is spelled out? (GenChecher.hs:56)
			res = makeType((Type){
				.which = etApp,
				.tApp = {
					.type = substT_type(n, s, t->tApp.type),
					.term = substT_term(n, s, t->tApp.term),
				}
			});
			break;
		case etExi: {
			Bind b = substT_bind(n, s, t->tExi.name, t->tExi.type1, anyOfType(t->tExi.type2)); 
			assert(b.any->which==eAnyType);
			res = makeType((Type){
				.which=etExi,
				.tExi={.name = copyName(b.name),
					.type1 = copyTypeDeep(b.type),
					.type2 = copyTypeDeep(b.any->mType)
				}
			});
			freeBindParts(b);
			break; }
		case etAnd: 
			res = makeType((Type){
				.which=etAnd, 
				.tAnd={
					.type1 = substT_type(n, s, t->tAnd.type1), 
					.type2 = substT_type(n, s, t->tAnd.type2)
				}
			});
			break;
		case etOr: 
			res = makeType((Type){
				.which=etOr, 
				.tOr={
					.type1 = substT_type(n, s, t->tOr.type1), 
					.type2 = substT_type(n, s, t->tOr.type2)
				}
			});
			break;
		case etBot:
			res = copyTypeDeep(t);
			break;
		default:
			die("Unhandled type!");
	}
	return res;
}

//! 138 145
//!   substM n s t = sub t where
//!     sub t@(Tvar _) = t   -- substM does not touch Tvars
//!     sub t@(Tall n1 t1 t2) = uncurry3 Tall $ substM n s (n1,t1,t2)
//!     sub t@(Tapp t1 m) = Tapp (sub t1) (substM n s m)
//!     sub t@(Texi n1 t1 t2) = uncurry3 Texi $ substM n s (n1,t1,t2)
//!     sub t@(Tand t1 t2) = Tand (sub t1) (sub t2)
//!     sub t@(Tor t1 t2) = Tor (sub t1) (sub t2)
//!     sub Tbot = Tbot
Type *substM_type(Name n, Term *s, const Type const*t) {
	Type *res;
	switch (t->which) {
		case etVar:
			res = copyTypeDeep(t);
			break;
		case etAll: {
			Bind b = substM_bind(n, s, t->tAll.name, t->tAll.type1, (anyOfType(t->tAll.type2))); 
			assert(b.any->which==eAnyType);
			res = makeType((Type){
				.which=etAll,
				.tAll={.name = copyName(b.name),
					.type1 = copyTypeDeep(b.type),
					.type2 = copyTypeDeep(b.any->mType)
				}
			});
			freeBindParts(b);
			break; }
		case etApp: 
			res = makeType((Type){
				.which = etApp,
				.tApp = {
					.type = substM_type(n, s, t->tApp.type),
					.term = substM_term(n, s, t->tApp.term),
				}
			});
			break;
		case etExi: {
			Bind b = substM_bind(n, s, t->tExi.name, t->tExi.type1, anyOfType(t->tExi.type2)); 
			assert(b.any->which==eAnyType);
			res = makeType((Type){
				.which=etExi,
				.tExi={.name = copyName(b.name),
					.type1 = copyTypeDeep(b.type),
					.type2 = copyTypeDeep(b.any->mType)
				}
			});
			freeBindParts(b);
			break; }
		case etAnd: 
			res = makeType((Type){
				.which=etAnd, 
				.tAnd={
					.type1 = substM_type(n, s, t->tAnd.type1), 
					.type2 = substM_type(n, s, t->tAnd.type2)
				}
			});
			break;
		case etOr: 
			res = makeType((Type){
				.which=etOr, 
				.tOr={
					.type1 = substM_type(n, s, t->tOr.type1), 
					.type2 = substM_type(n, s, t->tOr.type2)
				}
			});
			break;
		case etBot:
			res = copyTypeDeep(t);
			break;
		default:
			die("Unhandled type!");
	}
	return res;
}

//! 195 217
//!   substT n s t = sub t where
//!     fvs = freeNames s
//!     sub m@(Mvar _) = m -- substT does not touch Mvars
//!     sub m@(Mapp m1 m2) = Mapp (sub m1) (sub m2)
//!     sub m@(Mlam n1 t1 m1) = uncurry3 Mlam $ substT n s (n1,t1,m1)
//!     sub m@(Mwit t m1 m2) = Mwit t' m1' m2' where (t',(m1',m2')) = substT n s (t,(m1,m2))
//!     sub m@(Mabs n1 t1 n2 t2 m1 m2) = Mabs n1' t1' n2' t2' m1' m2' where
//!         fvs = freeNames s
//!         n1' = freshNameFvs fvs
//!         n2' = freshNameFvs (n1':fvs)
//!         t1' = substT n s t1
//!         t2' = substT n s t2
//!         m1' = sub m1
//!         m2' = sub . renameM n2 n2' . renameM n1 n1' $ m2
//!     sub m@(Mtup t m1 m2) = Mtup t' m1' m2' where (t',(m1',m2')) = substT n s (t,(m1,m2))
//!         -- (uncurry . uncurry $ Mtup) (substT n s ((t,m1),m2))
//!     sub m@(Mpi1 m1) = Mpi1 $ sub m1
//!     sub m@(Mpi2 m1) = Mpi2 $ sub m1
//!     sub m@(Min1 t1 m1) = uncurry Min1 $ substT n s (t1,m1)
//!     sub m@(Min2 t1 m1) = uncurry Min2 $ substT n s (t1,m1)
//!     sub m@(Mcas m1 c1 c2) = Mcas m1' c1' c2' where
//!       (m1',(c1',c2')) = substT n s (m1,(c1,c2))
//!     sub m@(Meps t1 m1) = uncurry Meps $ substT n s (t1,m1)
Term *substT_term(Name n, Type *s, const Term const * t) {
	Term *res;
	switch (t->which) {
		case emVar:
			res = copyTermDeep(t);
			break;
		case emApp:
			res = makeTerm((Term){.which = emApp,
					.mApp = {.term1=substT_term(n,s,t->mApp.term1),
						 .term2=substT_term(n,s,t->mApp.term2)}
					});
			break;
		case emLam: {
    			Bind b = substT_bind(n, s, t->mLam.name, t->mLam.type, anyOfTerm(t->mLam.term)); 
			assert(b.any->which == eAnyTerm);
			res = makeTerm((Term) {.which = emLam,
						.mLam = {.name = copyName(b.name),
							 .type = copyTypeDeep(b.type),
							 .term = copyTermDeep(b.any->mTerm) }
					});
			freeBindParts(b);
			break; }
		case emWit: 
			res = makeTerm((Term) {.which = emWit,
						.mWit = {.type = substT_type(n, s, t->mWit.type),
							.term1 = substT_term(n, s, t->mWit.term1),
							.term2 = substT_term(n, s, t->mWit.term2)}
						});
			break;
		case emAbs: {
			nameSet* fvs	= freeNames(anyOfType(s));
			Name  n1	= t->mAbs.name1;
			Name  n2	= t->mAbs.name3;
			Name  n1_ 	= freshNameFvs(fvs);
			Name  n2_ 	= freshNameFvs(addSet(fvs, n1_));
			/* fvs is modified, but we don't care */
			Type *t1_ 	= substT_type(n, s, t->mAbs.type2);
			Type *t2_ 	= substT_type(n, s, t->mAbs.type4);
			Term *m1_	= substT_term(n, s, t->mAbs.term5);
			Term *freeMe1, *freeMe2;
			Term *m2_	= substT_term(n, s, (freeMe2 = renameM_term(n2, n2_, (freeMe1 = renameM_term(n1, n1_, t->mAbs.term6)))));
			freeSetShallow(fvs);
			freeTermDeep(freeMe1);
			freeTermDeep(freeMe2);
			res = makeTerm((Term) {.which = emAbs,
						.mAbs = {
						.name1 = n1_,
						.type2 = t1_,
						.name3 = n2_,
						.type4 = t2_,
						.term5 = m1_,
						.term6 = m2_}
						});
			break; }
		case emTup:
			res = makeTerm((Term) {.which = emTup,
						.mTup = {.type = substT_type(n, s, t->mTup.type),
							.term1 = substT_term(n, s, t->mTup.term1),
							.term2 = substT_term(n, s, t->mTup.term2)}
						});
			break;
		case emPi1: 
			res = substT_term(n, s, t->mPi1.term);
		case emPi2:
			res = substT_term(n, s, t->mPi2.term);
		case emIn1:
			res = makeTerm((Term) {.which = emIn1,
						.mIn1 = {.type = substT_type(n, s, t->mIn1.type),
							.term = substT_term(n, s, t->mIn1.term)}
						});
			break;
		case emIn2:
			res = makeTerm((Term) {.which = emIn2,
						.mIn2 = {.type = substT_type(n, s, t->mIn2.type),
							.term = substT_term(n, s, t->mIn2.term)}
						});
			break;
		case emCas: {
			Bind b1 = substT_bind(n, s, t->mCas.casIn1.name, t->mCas.casIn1.type, anyOfTerm(t->mCas.casIn1.term));
			Bind b2 = substT_bind(n, s, t->mCas.casIn2.name, t->mCas.casIn2.type, anyOfTerm(t->mCas.casIn2.term));
			assert(b1.any->which == eAnyTerm);
			assert(b2.any->which == eAnyTerm);
      			res = makeTerm((Term) {.which = emCas,
						.mCas = {.term = substT_term(n, s, t->mCas.term),
							.casIn1 = {.name = copyName(b1.name),
								   .type = copyTypeDeep(b1.type),
								   .term = copyTermDeep(b1.any->mTerm)},
							.casIn2 = {.name = copyName(b2.name),
								   .type = copyTypeDeep(b2.type),
								   .term = copyTermDeep(b2.any->mTerm)}
							}
						});
			freeBindParts(b1);
			freeBindParts(b2);
			break; }
		case emEps:
			res = makeTerm((Term) {.which = emEps,
						.mEps = {.type = substT_type(n, s, t->mEps.type),
							 .term = substT_term(n, s, t->mEps.term)}
						});
			break;
		default:
			die("Unhandled term!");
	}
	return res;
}

//! 219 244
//!   substM n s t = sub t where
//!     fvs = freeNames s
//!     sub m@(Mvar n1) | n == n1  = s
//!                     | otherwise = m
//!     sub m@(Mapp m1 m2) = Mapp (sub m1) (sub m2)
//!     sub m@(Mlam n1 t1 m1) = uncurry3 Mlam $ substM n s(n1,t1,m1)
//! 
//!     sub m@(Mwit t m1 m2) = Mwit t' m1' m2' where
//!       (t',(m1',m2')) = substM n s (t,(m1,m2))
//!     sub m@(Mabs n1 t1 n2 t2 m1 m2) = Mabs n1' t1' n2' t2' m1' m2' where
//!         fvs = freeNames s
//!         n1' = freshNameFvs fvs
//!         n2' = freshNameFvs (n1':fvs)
//!         t1' = substM n s t1
//!         t2' = substM n s t2
//!         m1' = sub m1
//!         m2' = sub . renameM n2 n2' . renameM n1 n1' $ m2
//!     sub m@(Mtup t m1 m2) = Mtup t' m1' m2' where (t',(m1',m2')) = substM n s (t,(m1,m2))
//!         -- (uncurry . uncurry $ Mtup) (substT n s ((t,m1),m2))
//!     sub m@(Mpi1 m1) = Mpi1 $ sub m1
//!     sub m@(Mpi2 m1) = Mpi2 $ sub m1
//!     sub m@(Min1 t1 m1) = uncurry Min1 $ substM n s (t1,m1)
//!     sub m@(Min2 t1 m1) = uncurry Min2 $ substM n s (t1,m1)
//!     sub m@(Mcas m1 c1 c2) = Mcas m1' c1' c2'
//!       where (m1',(c1',c2')) = substM n s (m1,(c1,c2))
//!     sub m@(Meps t1 m1) = uncurry Meps $ substM n s (t1,m1)
Term *substM_term(Name n, Term *s, const Term const * t) {
	Term *res;
	switch (t->which) {
		case emVar:
			if (strcmp(t->mVar.name, n) == 0)
				res = copyTermDeep(s);
			else
				res = copyTermDeep(t);
			break;
		case emApp:
			res = makeTerm((Term){.which = emApp,
					.mApp = {.term1=substM_term(n,s,t->mApp.term1),
						 .term2=substM_term(n,s,t->mApp.term2)}
					});
			break;
		case emLam: {
    			Bind b = substM_bind(n, s, t->mLam.name, t->mLam.type, anyOfTerm(t->mLam.term)); 
			assert(b.any->which == eAnyTerm);
			res = makeTerm((Term) {.which = emLam,
						.mLam = {.name = copyName(b.name),
							 .type = copyTypeDeep(b.type),
							 .term = copyTermDeep(b.any->mTerm) }
					});
			freeBindParts(b);
			break; }
		case emWit: 
			res = makeTerm((Term) {.which = emWit,
						.mWit = {.type = substM_type(n, s, t->mWit.type),
							.term1 = substM_term(n, s, t->mWit.term1),
							.term2 = substM_term(n, s, t->mWit.term2)}
						});
			break;
		case emAbs: {
			nameSet* fvs	= freeNames(anyOfTerm(s));
			Name  n1	= t->mAbs.name1;
			Name  n2	= t->mAbs.name3;
			Name  n1_ 	= freshNameFvs(fvs);
			Name  n2_ 	= freshNameFvs(addSet(fvs, n1_));
			/* fvs is modified, but we don't care */
			Type *t1_ 	= substM_type(n, s, t->mAbs.type2);
			Type *t2_ 	= substM_type(n, s, t->mAbs.type4);
			Term *m1_	= substM_term(n, s, t->mAbs.term5);
			Term *freeMe1, *freeMe2;
			Term *m2_	= substM_term(n, s, (freeMe2 = renameM_term(n2, n2_, (freeMe1 = renameM_term(n1, n1_, t->mAbs.term6)))));
			freeSetShallow(fvs);
			freeTermDeep(freeMe1);
			freeTermDeep(freeMe2);
			res = makeTerm((Term) {.which = emAbs,
						.mAbs = {
						.name1 = n1_,
						.type2 = t1_,
						.name3 = n2_,
						.type4 = t2_,
						.term5 = m1_,
						.term6 = m2_}
						});
			break; }
		case emTup:
			res = makeTerm((Term) {.which = emTup,
						.mTup = {.type = substM_type(n, s, t->mTup.type),
							.term1 = substM_term(n, s, t->mTup.term1),
							.term2 = substM_term(n, s, t->mTup.term2)}
						});
			break;
		case emPi1: 
			res = substM_term(n, s, t->mPi1.term);
		case emPi2:
			res = substM_term(n, s, t->mPi2.term);
		case emIn1:
			res = makeTerm((Term) {.which = emIn1,
						.mIn1 = {.type = substM_type(n, s, t->mIn1.type),
							.term = substM_term(n, s, t->mIn1.term)}
						});
			break;
		case emIn2:
			res = makeTerm((Term) {.which = emIn2,
						.mIn2 = {.type = substM_type(n, s, t->mIn2.type),
							.term = substM_term(n, s, t->mIn2.term)}
						});
			break;
		case emCas: {
			Bind b1 = substM_bind(n, s, t->mCas.casIn1.name, t->mCas.casIn1.type, anyOfTerm(t->mCas.casIn1.term));
			Bind b2 = substM_bind(n, s, t->mCas.casIn2.name, t->mCas.casIn2.type, anyOfTerm(t->mCas.casIn2.term));
			assert(b1.any->which == eAnyTerm);
			assert(b2.any->which == eAnyTerm);
      			res = makeTerm((Term) {.which = emCas,
						.mCas = {.term = substM_term(n, s, t->mCas.term),
							.casIn1 = {.name = copyName(b1.name),
								   .type = copyTypeDeep(b1.type),
								   .term = copyTermDeep(b1.any->mTerm)},
							.casIn2 = {.name = copyName(b2.name),
								   .type = copyTypeDeep(b2.type),
								   .term = copyTermDeep(b2.any->mTerm)}
							}
						});
			freeBindParts(b1);
			freeBindParts(b2);
			break; }
		case emEps:
			res = makeTerm((Term) {.which = emEps,
						.mEps = {.type = substM_type(n, s, t->mEps.type),
							 .term = substM_term(n, s, t->mEps.term)}
						});
			break;
		default:
			die("Unhandled term!");
	}
	return res;
}


Kind *substT_kind(Name n, Type *s, const Kind const * t) {
	Kind *res;
	switch (t->which) {
		case eKstar:
//! 104
//!   substT _ _ Kstar = Kstar
			res = copyKindDeep(t);
			break;
		case eKpi:;
//! 105
//!   substT n s k@(Kpi n1 t1 k1) = uncurry3 Kpi $ substT n s (n1,t1,k1)
			Bind b = substT_bind(n, s, t->kPi.name, t->kPi.type, anyOfKind(t->kPi.kind));
			assert(b.any->which == eAnyKind);
			res = makeKind((Kind){.which=eKpi,
						.kPi = {.name = copyName(b.name),
							.type = copyTypeDeep(b.type),
							.kind = copyKindDeep(b.any->mKind)}
						});
			freeBindParts(b);
			break;
		default:
			die("Unhandled kind!");
	}
	return res;
}

Kind *substM_kind(Name n, Term *s, const Kind const * t) {
	Kind *res;
	switch (t->which) {
		case eKstar:
//! 106
//!   substM _ _ Kstar = Kstar
			res = copyKindDeep(t);
			break;
		case eKpi:;
//! 107
//!   substM n s (Kpi n1 t1 k1) = Kpi n2 t2 k2 where
 			Bind b = substM_bind(n, s, t->kPi.name, t->kPi.type, anyOfKind(t->kPi.kind));
			assert(b.any->which == eAnyKind);
			res = makeKind((Kind){.which=eKpi,
						.kPi = {.name = copyName(b.name),
							.type = copyTypeDeep(b.type),
							.kind = copyKindDeep(b.any->mKind)}
						});
			freeAny(b.any);
			break;
		default:
			die("Unhandled kind!");
	}
	return res;
}

//! 28
//!   substM :: Name -> Term -> a -> a
Any substM(Name n, Term *s, const Any /*t*/any) {
	switch (any.which) {
		case eAnyType:
			return anyOfType(substM_type(n, s, any.mType));
		case eAnyTerm:
			return anyOfTerm(substM_term(n, s, any.mTerm));
		case eAnyKind:
			return anyOfKind(substM_kind(n, s, any.mKind));
		case eAnyName:
			die("Undefined: substT Name");
		case eAnyBind:
			return anyOfBind(substM_bind(n, s, any.mBind.name, any.mBind.type, *any.mBind.any));
	}
	die("Unhandled option in Any");
}

Any substT(Name n, Type *s, const Any /*t*/any) {
	switch (any.which) {
		case eAnyType:
			return anyOfType(substT_type(n, s, any.mType));
		case eAnyTerm:
			return anyOfTerm(substT_term(n, s, any.mTerm));
		case eAnyKind:
			return anyOfKind(substT_kind(n, s, any.mKind));
		case eAnyName:
			die("Undefined: substT Name");
		case eAnyBind:
			return anyOfBind(substT_bind(n, s, any.mBind.name, any.mBind.type, *any.mBind.any));
	}
	die("Unhandled option in Any");
}

//! 25
//!   renameT :: Name -> Name -> a -> a
Any renameT(Name n1, Name n2, const Any a) {
	return substT(n1, tTvar(n2), a);
}

//! 29 30
//!   renameM :: Name -> Name -> a -> a
//!   renameM n n1 = substM n (Mvar n1)
Any renameM(Name n1, Name n2, const Any a) {
	return substM(n1, mMvar(n2), a);
}
Term *renameM_term(Name n1, Name n2, const Term *const t) {
	return substM_term(n1, mMvar(n2), t);
}

nameSet *freeNames(const Any any) {
	/* only do a shallow free on returned sets */
	nameSet *res;
	switch (any.which) {
		case eAnyName:
			res = singletonSet(any.mName);
			break;
		case eAnyKind:
			switch (any.mKind->which) {
				case eKstar:;
					break;
				case eKpi:;
					nameSet *s1 = freeNames(anyOfType(any.mKind->kPi.type));
					nameSet *s2 = freeNames(anyOfKind(any.mKind->kPi.kind));
					minusSet(s2, any.mKind->kPi.name);
					res=unionSet(s1, s2);
					freeSetShallow(s1);
					freeSetShallow(s2);
					break;
				default:
					die("Unhandled kind!");
			}
			break;

		case eAnyTerm:;
			const Term* m = any.mTerm;
			switch (m->which) {
				case emVar:
					res = singletonSet(m->mVar.name);
					break;
				case emApp: {
					nameSet *s1 = freeNames(anyOfTerm(m->mApp.term1));
					nameSet *s2 = freeNames(anyOfTerm(m->mApp.term2));
					res=unionSetFreeShallow(s1, s2);
					break; }
				case emLam: {
					nameSet *s1 = freeNames(anyOfType(m->mLam.type));
					nameSet *s2 = freeNames(anyOfTerm(m->mLam.term));
					minusSet(s2, m->mLam.name);
					res=unionSetFreeShallow(s1, s2);
					break; }
				case emWit: {
					nameSet *s1 = freeNames(anyOfTerm(m->mWit.term1));
					nameSet *s2 = freeNames(anyOfTerm(m->mWit.term2));
					nameSet *s3 = freeNames(anyOfType(m->mWit.type));
					nameSet *tmp = unionSetFreeShallow(s1, s2);
					res = unionSetFreeShallow(tmp, s3);
					break; }
				case emAbs: {
					nameSet *t1 = freeNames(anyOfType(m->mAbs.type2));
					nameSet *t2 = freeNames(anyOfType(m->mAbs.type4));
					nameSet *m1 = freeNames(anyOfTerm(m->mAbs.term5));
					nameSet *m2 = freeNames(anyOfTerm(m->mAbs.term6));
					minusSet(m2, m->mAbs.name1);
					minusSet(m2, m->mAbs.name3);
					nameSet *tmp1 = unionSetFreeShallow(t1, t2);
					nameSet *tmp2 = unionSetFreeShallow(m1, m2);
					res = unionSetFreeShallow(tmp1, tmp2);
					break; }
				case emTup: {
					nameSet *s1 = freeNames(anyOfTerm(m->mTup.term1));
					nameSet *s2 = freeNames(anyOfTerm(m->mTup.term2));
					nameSet *s3 = freeNames(anyOfType(m->mTup.type));
					nameSet *tmp = unionSetFreeShallow(s1, s2);
					res = unionSetFreeShallow(tmp, s3);
					break; }
				case emPi1: {
					res = freeNames(anyOfTerm(m->mPi1.term));
					break; }
				case emPi2: {
					res = freeNames(anyOfTerm(m->mPi2.term));
					break; }
				case emIn1:
					res = unionSetFreeShallow(freeNames(anyOfType(m->mIn1.type)),
								freeNames(anyOfTerm(m->mIn1.term)));
					break;
				case emIn2:
					res = unionSetFreeShallow(freeNames(anyOfType(m->mIn2.type)),
								freeNames(anyOfTerm(m->mIn2.term)));
					break;
				case emCas: {
					nameSet *m1 = freeNames(anyOfTerm(m->mCas.casIn1.term));
					minusSet(m1, m->mCas.casIn1.name);
					nameSet *m2 = freeNames(anyOfTerm(m->mCas.casIn2.term));
					minusSet(m2, m->mCas.casIn2.name);
					nameSet *s1 = unionSetFreeShallow(freeNames(anyOfType(m->mCas.casIn1.type)), m1);
					nameSet *s2 = unionSetFreeShallow(freeNames(anyOfType(m->mCas.casIn2.type)), m2);
					res = unionSetFreeShallow(freeNames(anyOfTerm(m->mCas.term)),
						unionSetFreeShallow(s1, s2));
					break; }
				case emEps:
					res = unionSetFreeShallow(freeNames(anyOfType(m->mEps.type)),
								freeNames(anyOfTerm(m->mEps.term)));
					break;
				default:
					die("Unhandled term!");
			}
			break;
		case eAnyType:;
			const Type *t = any.mType;
			switch (t->which) {
				case etVar:
					res = singletonSet(t->tVar.name);
					break;
				case etAll: {
					nameSet *t1 = freeNames(anyOfType(t->tAll.type1));
					nameSet *t2 = freeNames(anyOfType(t->tAll.type2));
					minusSet(t2, t->tAll.name);
					res = unionSetFreeShallow(t1, t2);
					break; }
				case etApp: 
					res = unionSetFreeShallow(freeNames(anyOfTerm(t->tApp.term)),
						freeNames(anyOfType(t->tApp.type)));
					break;
				case etExi: {
					nameSet *t1 = freeNames(anyOfType(t->tExi.type1));
					nameSet *t2 = freeNames(anyOfType(t->tExi.type2));
					minusSet(t2, t->tExi.name);
					res = unionSetFreeShallow(t1, t2);
					break; }
				case etAnd: 
					res = unionSetFreeShallow(freeNames(anyOfType(t->tAnd.type1)),
						freeNames(anyOfType(t->tAnd.type2)));
					break;
				case etOr: 
					res = unionSetFreeShallow(freeNames(anyOfType(t->tOr.type1)),
						freeNames(anyOfType(t->tOr.type2)));
					break;
				case etBot:
					res = createSet();
					break;
				default:
					die("Unhandled type!");
			}
			
			break;
		default:
			die("Unhandled option in Any");
	}

	if (res == NULL)
		die("Unhandled case or invalid Any!");
	
	return res;
}

//! 84 90
//!   refreshWith r ns (n,t,k)
//!       | n `elem` ns = (n', t', refreshWith r' (n':ns) k)
//!       | otherwise = (n, t', refreshWith r (n:ns) k)
//!            where
//!                  n' = freshNameFvs ns
//!                  r' = Map.insert n n' r
//!                  t' = refreshWith r ns t

Bind refreshWith_bind(namemap r, nameSet *ns, Name n, Type *t, const  Any a) {
	/* TODO: memory management 
	 *
	 * FIXME? r is modified, should be not */
	Name n_ = freshNameFvs(ns);
	namemap* r_ = namemap_copy(r);
	namemap_insert(r_, n, n_);
	Type *t_ = refreshWith_type(r, ns, t);
	nameSet *tmp = singletonSet(n_);
	nameSet *nns = unionSet(ns, tmp);
	freeSetShallow(tmp);
	Bind res;
	if (isIn(ns, n) != -1) {
		res = mBind(n_, t_, makeAny(refreshWith(*r_, nns, a)));
		freeName(n);
	} else  {
		res = mBind(n, t_, makeAny(refreshWith(r, nns, a)));
		freeName(n_);
	}
	namemap_free(*r_);
        free(r_);
	freeSetShallow(tmp);
	freeSetShallow(nns);
	return res;
}

//! 116 118
//!   refreshWith r ns (Kpi n1 t1 k1) = Kpi n2 t2 k2 where
//!     (n2,t2,k2) = refreshWith r ns (n1,t1,k1)
//!   refreshWith r ns Kstar = Kstar
Kind *refreshWith_kind(namemap r, nameSet *ns, const Kind const * t) {
	switch (t->which) {
		case eKstar:
			return copyKindDeep(t);
		case eKpi:;
			Bind b = refreshWith_bind(r, ns, t->kPi.name, t->kPi.type, anyOfKind(t->kPi.kind));
			assert(b.any->which == eAnyKind);
			Kind res = (Kind){.which=eKpi,
						.kPi = {.name = copyName(b.name),
							.type = copyTypeDeep(b.type),
							.kind = copyKindDeep(b.any->mKind)}
						};
			freeBindParts(b);
			return copyKind(&res);
	}
	die("Unhandled kind!");
}

//! 165 174
//!   refreshWith r ns t = sub t where
//!     sub t@(Tvar n) = case Map.lookup n r of
//!         Nothing -> t
//!         Just n' -> Tvar n'
//!     sub t@(Tall n1 t1 t2) = uncurry3 Tall $ refreshWith r ns (n1,t1,t2)
//!     sub t@(Tapp t1 m) = uncurry Tapp $ refreshWith r ns (t1,m)
//!     sub t@(Texi n1 t1 t2) = uncurry3 Texi $ refreshWith r ns (n1,t1,t2)
//!     sub t@(Tand t1 t2) = uncurry Tand $ refreshWith r ns (t1,t2)
//!     sub t@(Tor t1 t2) = uncurry Tor $ refreshWith r ns (t1,t2)
//!     sub t@Tbot = Tbot
Type *refreshWith_type(namemap r, nameSet *ns, const Type const*t) {
	Type *res;
	switch (t->which) {
		case etVar: {
			Name n_ = namemap_lookup(r, t->tVar.name);
			if (n_ == NULL) 
				res = copyTypeDeep(t);
				/* no free of null */
			else
				res = tTvar(copyName(n_)); /* n_ is a dangling reference to an element of r */
			break;
		}
		case etAll: {
			Bind b = refreshWith_bind(r, ns, t->tAll.name, t->tAll.type1, (anyOfType(t->tAll.type2))); 
			assert(b.any->which==eAnyType);
			res = makeType((Type){
				.which=etAll,
				.tAll={.name = copyName(b.name),
					.type1 = copyTypeDeep(b.type),
					.type2 = copyTypeDeep(b.any->mType)
				}
			});
			freeBindParts(b);
			break; }
		case etApp: 
			// FIXME: refactor if pair is spelled out? (GenChecher.hs:56)
			res = makeType((Type){
				.which = etApp,
				.tApp = {
					.type = refreshWith_type(r, ns, t->tApp.type),
					.term = refreshWith_term(r, ns, t->tApp.term),
				}
			});
			break;
		case etExi: {
			Bind b = refreshWith_bind(r, ns, t->tExi.name, t->tExi.type1, anyOfType(t->tExi.type2)); 
			assert(b.any->which==eAnyType);
			res = makeType((Type){
				.which=etExi,
				.tExi={.name = copyName(b.name),
					.type1 = copyTypeDeep(b.type),
					.type2 = copyTypeDeep(b.any->mType)
				}
			});
			freeBindParts(b);
			break; }
		case etAnd: 
			res = makeType((Type){
				.which=etAnd, 
				.tAnd={
					.type1 = refreshWith_type(r, ns, t->tAnd.type1), 
					.type2 = refreshWith_type(r, ns, t->tAnd.type2)
				}
			});
			break;
		case etOr: 
			res = makeType((Type){
				.which=etOr, 
				.tOr={
					.type1 = refreshWith_type(r, ns, t->tOr.type1), 
					.type2 = refreshWith_type(r, ns, t->tOr.type2)
				}
			});
			break;
		case etBot:
			res = copyTypeDeep(t);
			break;
		default:
			die("Unhandled type!");
	}
	return res;
}

//! 33
//!   refreshWith r ns = id
Term *refreshWith_term(namemap r, nameSet *ns, const Term const * t) {
	return copyTermDeep(t);
}

Any refreshWith(namemap r, nameSet *ns, const Any /*t*/any) {
	switch (any.which) {
		case eAnyType:
			return anyOfType(refreshWith_type(r, ns, any.mType));
		case eAnyTerm:
			return anyOfTerm(refreshWith_term(r, ns, any.mTerm));
		case eAnyKind:
			return anyOfKind(refreshWith_kind(r, ns, any.mKind));
		case eAnyName:
			return anyOfName(copyName(any.mName));
		case eAnyBind:
			return anyOfBind(refreshWith_bind(r, ns, any.mBind.name, any.mBind.type, *any.mBind.any));
	}
	die("Unhandled option in Any");
}

//! 35 36
//!   refresh :: [Name] -> a -> a
//!   refresh = refreshWith Map.empty
Any refresh(nameSet *names, Any a) {
	return refreshWith(namemap_new(), names, a);
}

//! 81 82
//!   alphaEq (n, t, k) (n', t', k')
//!     = alphaEq t t'  && alphaEq k (renameM n' n k')
bool alphaeq_bind(Name n, Type *t, const  Any k, Name n_, Type *t_, const  Any k_) {
	Any tmp;
	bool res =  alphaeq_type(t, t_) && alphaeq(k, (tmp = renameM(n_, n, k_)));
	freeAnyDeep(makeAny(tmp));
	return res;
}

//! 113 115
//!   alphaEq Kstar Kstar = True
//!   alphaEq (Kpi n t k) (Kpi n' t' k')
//!     = alphaEq (n,t,k) (n,t',k')
bool alphaeq_kind(const Kind const *t, const Kind const *t_) {
	if (t->which != t_->which) 
		return false;

	switch (t->which) {
		case eKstar:
			return true;
		case eKpi:
			return alphaeq_bind(t->kPi.name, t->kPi.type, anyOfKind(t->kPi.kind),
				t_->kPi.name, t_->kPi.type, anyOfKind(t_->kPi.kind));
	}
	die("Unhandled kind!");
}

//! 155 163
//!   alphaEq (Tvar n) (Tvar n') = n == n'
//!   alphaEq (Tall n t s) (Tall n' t' s') = alphaEq t t'
//!                                        && alphaEq s (renameM n' n s')
//!   alphaEq (Tapp t m) (Tapp t' m') = alphaEq t t' && alphaEq m m'
//!   alphaEq (Texi n t s) (Texi n' t' s') = alphaEq (n,t,s) (n',t',s')
//!   alphaEq (Tand t1 t2) (Tand t1' t2') = alphaEq t1 t1' && alphaEq t2 t2'
//!   alphaEq (Tor t1 t2) (Tor t1' t2') = alphaEq t1 t1' && alphaEq t2 t2'
//!   alphaEq Tbot Tbot = True
//!   alphaEq _ _ = False
bool alphaeq_type(const Type const *t, const Type const *t_) {
	if (t->which != t_->which) 
		return false;
	
	switch (t->which) {
		case etVar:
			return (strcmp(t->tVar.name, t_->tVar.name)==0);
		case etAll: {
			Any a = renameM(t_->tAll.name, t->tAll.name, anyOfType(t_->tAll.type2));
			assert(a.which==eAnyType);
			bool res = alphaeq_type(t->tAll.type1, t_->tAll.type1) && 
				alphaeq_type(t->tAll.type2, a.mType);
			freeAnyDeep(makeAny(a));
			return res;
			}
		case etApp: 
			return alphaeq_type(t->tApp.type, t_->tApp.type) &&
				alphaeq_term(t->tApp.term, t_->tApp.term);
		case etExi:
			return alphaeq_bind(t->tExi.name, t->tExi.type1, anyOfType(t->tExi.type2),
				t_->tExi.name, t_->tExi.type1, anyOfType(t_->tExi.type2));
		case etAnd: 
			return alphaeq_type(t->tAnd.type1, t_->tAnd.type1) &&
				alphaeq_type(t->tAnd.type2, t_->tAnd.type2);
		case etOr: 
			return alphaeq_type(t->tOr.type1, t_->tOr.type1) &&
				alphaeq_type(t->tOr.type2, t_->tOr.type2);
		case etBot:
			return true;
		default:
			die("Unhandled type!");
	}
}

bool alphaeq_term(const Term const *t, const Term const *t_) {
//! 304 330
//!   alphaEq (Mvar n) (Mvar n') = n == n'
//!   alphaEq (Mlam n t s) (Mlam n' t' s') = alphaEq t t'
//!                                        && alphaEq s (renameM n' n s')
//!   alphaEq (Mapp t m) (Mapp t' m') = alphaEq t t' && alphaEq m m'
//! 
//!   alphaEq (Mwit t m1 m2) (Mwit t' m1' m2') = alphaEq (t,(m1,m2)) (t,(m1',m2'))
//!   alphaEq (Mabs n1 t1 n2 t2 m1 m2)
//!           (Mabs n1' t1' n2' t2' m1' m2')
//!           =  alphaEq t1 t1'
//!           && alphaEq t2 t2'
//!           && alphaEq m1 m1'
//!           && alphaEq m2 (renameM n1' n1 (renameM n2' n2 m2'))
//! 
//!   alphaEq (Mtup t m1 m2) (Mtup t' m1' m2') = alphaEq (t,(m1,m2)) (t,(m1',m2'))
//!   alphaEq (Mpi1 m) (Mpi1 m') = alphaEq m m'
//!   alphaEq (Mpi2 m) (Mpi2 m') = alphaEq m m'
//!   alphaEq (Min1 t m) (Min1 t' m') = alphaEq t t' && alphaEq m m'
//!   alphaEq (Min2 t m) (Min2 t' m') = alphaEq t t' && alphaEq m m'
//! 
//!   alphaEq (Mcas m c1 c2) (Mcas m' c1' c2')
//!           =  alphaEq m m'
//!           && alphaEq c1 c1'
//!           && alphaEq c2 c2'
//! 
//!   alphaEq (Meps t m) (Meps t' m') = alphaEq t t' && alphaEq m m'
//! 
//!   alphaEq _ _ = False
	if (t->which != t_->which) 
		return false;

	switch (t->which) {
		case emVar:
			return strcmp(t->mVar.name, t_->mVar.name)==0;
		case emLam: 
			return alphaeq_type(t->mLam.type, t_->mLam.type) &&
				alphaeq_term(t->mLam.term,
						renameM_term(t_->mLam.name, t->mLam.name, t_->mLam.term));
		case emApp:
			return alphaeq_term(t->mApp.term1, t_->mApp.term1) &&
				alphaeq_term(t->mApp.term2, t_->mApp.term2);
		case emWit: 
			return alphaeq_type(t->mWit.type, t_->mWit.type) &&
				 alphaeq_term(t->mWit.term1, t_->mWit.term1) &&
				 alphaeq_term(t->mWit.term2, t_->mWit.term2);
		case emAbs: {
			/* rename for "clarity" */
			const Name  n1	= t->mAbs.name1;
			const Type *t1 	= t->mAbs.type2;
			const Name  n2	= t->mAbs.name3;
			const Type *t2 	= t->mAbs.type4;
			const Term *m1	= t->mAbs.term5;
			const Term *m2	= t->mAbs.term6;
			const Name  n1_	= t_->mAbs.name1;
			const Type *t1_ = t_->mAbs.type2;
			const Name  n2_	= t_->mAbs.name3;
			const Type *t2_ = t_->mAbs.type4;
			const Term *m1_	= t_->mAbs.term5;
			const Term *m2_	= t_->mAbs.term6;
			Term *freeme;
			/* end rename */
			bool res = alphaeq_type(t1, t1_) &&
				alphaeq_type(t2_, t2_)&&
				alphaeq_term(m1, m1_) &&
				alphaeq_term(m2,
					(freeme = renameM_term(n1_, n1, renameM_term(n2_, n2, m2_))));
			freeTermDeep(freeme);
			return res;
			}
		case emTup:
			return alphaeq_type(t->mTup.type, t_->mTup.type) &&
				 alphaeq_term(t->mTup.term1, t_->mTup.term1) &&
				 alphaeq_term(t->mTup.term2, t_->mTup.term2);
		case emPi1: 
			return alphaeq_term(t->mPi1.term, t_->mPi1.term);
		case emPi2:
			return alphaeq_term(t->mPi2.term, t_->mPi2.term);
		case emIn1:
			return alphaeq_type(t->mIn1.type, t_->mIn1.type) &&
				alphaeq_term(t->mIn1.term, t_->mIn1.term);
		case emIn2:
			return alphaeq_type(t->mIn2.type, t_->mIn2.type) &&
				alphaeq_term(t->mIn2.term, t_->mIn2.term);
		case emCas:
			return alphaeq_term(t->mCas.term, t_->mCas.term) &&
				alphaeq_bind(t->mCas.casIn1.name, t->mCas.casIn1.type, anyOfTerm(t->mCas.casIn1.term),
					t_->mCas.casIn1.name, t_->mCas.casIn1.type, anyOfTerm(t_->mCas.casIn1.term)) &&
				alphaeq_bind(t->mCas.casIn2.name, t->mCas.casIn2.type, anyOfTerm(t->mCas.casIn2.term),
					t_->mCas.casIn2.name, t_->mCas.casIn2.type, anyOfTerm(t_->mCas.casIn2.term));
		case emEps:
			return alphaeq_type(t->mEps.type, t_->mEps.type) &&
				alphaeq_term(t->mEps.term, t_->mEps.term);
		default:
			die("Unhandled term!");
	}
}

bool alphaeq(const Any t, const Any t_) {
	if (t.which != t_.which) 
		die("alphaeq: incompatible arguments");

	switch (t.which) {
		case eAnyType:
			return alphaeq_type(t.mType, t_.mType);
		case eAnyTerm:
			return alphaeq_term(t.mTerm, t_.mTerm);
		case eAnyKind:
			return alphaeq_kind(t.mKind, t_.mKind);
		case eAnyName:
			return false;
		case eAnyBind:
			return alphaeq_bind(t.mBind.name, t.mBind.type, *t.mBind.any,
				t_.mBind.name, t_.mBind.type, *t_.mBind.any);
	}
	die("Unhandled option in Any");
}

/*@ assigns \nothing;
  @*/
bool betaeq(const Any t, const Any t_) {
	return alphaeq(nf(t), nf(t_));
}

//! 246 269
//!   whnf (Mapp f a) = case whnf f of
//!     Mlam x t b -> whnf (substM x a b)
//!     f1 -> Mapp f1 a
//! 
//!   whnf (Mabs n1 t1 n2 t2 m1 m2) = case whnf m1 of
//!     (Mwit _ w1 w2) -> whnf $ substM n1 w1 $ substM n2 w2 $ m2
//!     m1' -> (Mabs n1 t1 n2 t2 m1' m2)
//! 
//!   whnf (Mpi1 m) = case whnf m of
//!     (Mtup _ m1 m2) -> whnf m1
//!     m' -> Mpi1 m'
//! 
//!   whnf (Mpi2 m) = case whnf m of
//!     (Mtup _ m1 m2) -> whnf m2
//!     m' -> Mpi2 m'
//! 
//!   -- [case inl q of inl n -> p] -->  p[n:=q]
//!   whnf (Mcas m c1 c2) = case whnf m of
//!     Min1 _ m1 -> applycase c1 m1
//!     Min2 _ m2 -> applycase c2 m2
//!     m' -> (Mcas m' c1 c2)
//!     where applycase (n,_,p) q = substM n q p
//! 
//!   whnf e = e
Term *whnf_term(const Term const * t) {
	Term *res;
	switch (t->which) {
		case emApp: {
			Term *f = t->mApp.term1;
			Term *a = copyTermDeep(t->mApp.term2);
			Term *f1 = whnf_term(f);
			if (f1->which == emLam) {
				res = substM_term(f1->mLam.name, a, f1->mLam.term);
				freeTermDeep(f1);
			} else
				res = makeTerm((Term){.which = emApp,
					.mApp = {.term1 = f1,
						 .term2 = a}
					});
			break; }
		case emAbs: {
			Name  n1	= t->mAbs.name1;
			Name  n2	= t->mAbs.name3;
			Type *t1 	= t->mAbs.type2;
			Type *t2 	= t->mAbs.type4;
			Term *m1	= t->mAbs.term5;
			Term *m2	= t->mAbs.term6;
			Term *m1_	= whnf_term(m1);
			if (m1_->which == emWit) {
				res = whnf_term(substM_term(n1, m1_->mWit.term1, substM_term(n2, m1_->mWit.term2, m2)));
				freeTermDeep(m1_);
			} else {
				res = makeTerm((Term) {.which = emAbs,
							.mAbs = {
							.name1 = copyName(n1),
							.type2 = copyTypeDeep(t1),
							.name3 = copyName(n2),
							.type4 = copyTypeDeep(t2),
							.term5 = m1_,
							.term6 = copyTermDeep(m2)}
							});
			}
			break; }
		case emPi1: {
			Term *m_ = whnf_term(t->mPi1.term);
			if (m_->which == emTup) {
				res = whnf_term(m_->mTup.term1);
				freeTermDeep(m_);
			} else
				res = makeTerm((Term) {.which = emPi1,
							.mPi1 = {.term = m_}
							});
			break; }
		case emPi2: {
			Term *m_ = whnf_term(t->mPi2.term);
			if (m_->which == emTup) {
				res = whnf_term(m_->mTup.term2);
				freeTermDeep(m_);
			} else
				res = makeTerm((Term) {.which = emPi2,
							.mPi2 = {.term = m_}
							});
			break; }
		case emCas: {
    			Term *m_ = whnf_term(t->mCas.term);
			switch (m_->which) {
				case emIn1:
					res = substM_term(t->mCas.casIn1.name,  m_->mIn1.term, t->mCas.casIn1.term);
					freeTermDeep(m_);
					break;
				case emIn2:
					res = substM_term(t->mCas.casIn2.name,  m_->mIn2.term, t->mCas.casIn2.term);
					freeTermDeep(m_);
					break;
				default:
      					res = makeTerm((Term) {.which = emCas,
								.mCas = {.term = m_,
									.casIn1 = t->mCas.casIn1,
									.casIn2 = t->mCas.casIn2 }
								});
					break;
			}
			break; }
		default:
			res = copyTermDeep(t);
	}
	return res;
}

//! 38 39
//!   whnf :: a -> a
//!   whnf = id
Any whnf(Any a) {
	if (a.which == eAnyTerm) 
		return anyOfTerm(whnf_term(a.mTerm));
	else {
		Any *b = copyAnyDeep(&a);
		/* copy contents, but not a itself */
		Any c = *b;
		freeAny(b);
		return c;
	}
}

//! 147 153
//!   nf (Tapp t m) = Tapp (nf t) (nf m)
//!   nf (Tall n t1 t2) = Tall n (nf t1) (nf t2)
//!   nf t@(Tvar _) = t
//!   nf (Texi n t1 t2) = Texi n (nf t1) (nf t2)
//!   nf (Tand t1 t2) = Tand (nf t1) (nf t2)
//!   nf (Tor  t1 t2) = Tor (nf t1) (nf t2)
//!   nf Tbot = Tbot
Type *nf_type(const Type const*t) {
	Type *res;
	switch (t->which) {
        case etApp: { //TODO rewrite in this style the whole procedure
          Type * type = nf_type(t->tApp.type);
          if (type==NULL) {
            return NULL;
          }
          Term * term = nf_term(t->tApp.term);
          if (term==NULL) {
            return NULL;
          }
          res = makeType((Type){
              .which = etApp,
                .tApp = {
                .type = type,
                .term = term
              }
            }); }
          break;
        case etAll: {
          Name name = copyName(t->tAll.name);
          if (name==NULL) return NULL;
          Type* type1 = nf_type(t->tAll.type1);
          if (type1 == NULL) {
            freeName(name);
            return NULL;
          }
          Type* type2 = nf_type(t->tAll.type2);
          if (type2 == NULL) {
            freeName(name);
            return NULL;
          }
          res = makeType((Type){
              .which=etAll,
                 .tAll={.name = name,
                        .type1 = type1,
                        .type2 = type2
              }
            });
        }
          break;
        case etVar:
          res = copyTypeDeep(t);
          break;
        case etExi: {
          Name name = copyName(t->tExi.name);
          if (name==NULL) return NULL;
          Type *type1 = nf_type(t->tExi.type1);
          if (type1 == NULL) {
            freeName(name);
            return NULL;
          }
          Type *type2 = nf_type(t->tExi.type2);
          if (type2 == NULL) {
            freeName(name);
            return NULL;
          }
          res = makeType((Type){
              .which=etExi,
                .tExi={.name = name,
                       .type1 = type1,
                       .type2 = type2,
              }
            });
        }
          break;
        case etAnd: {
          Type* type1 = nf_type(t->tAnd.type1);
          if (type1 == NULL) return NULL;
          Type* type2 = nf_type(t->tAnd.type2);
          if (type2 == NULL) return NULL;
          res = makeType((Type){
              .which=etAnd, 
                .tAnd={
                .type1 = type1,
                .type2 = type2
              }
            });
        }
          break;
        case etOr: {
          Type* type1 = nf_type(t->tOr.type1);
          if (type1 == NULL) return NULL;
          Type* type2 = nf_type(t->tOr.type2);
          if (type2 == NULL) return NULL;
          res = makeType((Type){
              .which=etOr, 
                .tOr={
                .type1 = type1,
                .type2 = type2
              }
            });
        }
          break;
        case etBot:
          res = copyTypeDeep(t);
          break;
        default:
          die("Unhandled type!");
	}
	return res;
}

//! 271 302
//!   nf (Mlam x t e) = Mlam x (nf t) (nf e)
//!   nf (Mapp f a) = case whnf f of
//!     Mlam x t b -> nf (substM x a b)
//!     f1 -> Mapp (nf f1) (nf a)
//!   nf m@(Mvar n) = m
//! 
//!   nf (Mwit t m1 m2) = Mwit (nf t) (nf m1) (nf m2)
//! 
//!   nf (Mabs n1 t1 n2 t2 m1 m2) = case whnf m1 of
//!     (Mwit _ w1 w2) -> nf $ substM n1 w1 $ substM n2 w2 $ m2
//!     m1' -> (Mabs n1 (nf t1) n2 (nf t2) (nf m1') (nf m2))
//! 
//!   nf (Mtup t m1 m2) = Mtup (nf t) (nf m1) (nf m2)
//! 
//!   nf (Mpi1 m) = case whnf m of
//!     (Mtup _ m1 m2) -> nf m1
//!     m' -> Mpi1 (nf m')
//! 
//!   nf (Mpi2 m) = case whnf m of
//!     (Mtup _ m1 m2) -> nf m2
//!     m' -> Mpi2 (nf m')
//! 
//!   nf (Min1 t m) = Min1 (nf t) (nf m)
//!   nf (Min2 t m) = Min2 (nf t) (nf m)
//! 
//!   nf (Mcas m c1 c2) = case whnf m of
//!     Min1 _ m1 -> nf(applycase c1 m1)
//!     Min2 _ m2 -> nf(applycase c2 m2)
//!     m' -> nf (Mcas m' c1 c2)
//!     where applycase (n,_,p) q = substM n q p
//! 
//!   nf (Meps t m) = Meps (nf t) (nf m)
Term *nf_term(const Term const * t) {
	Term *res;

	switch (t->which) {
		case emLam: 
			res = makeTerm((Term) {.which = emLam,
						.mLam = {.name = copyName(t->mLam.name),
							 .type = nf_type(t->mLam.type),
							 .term = nf_term(t->mLam.term) }
					});
			break;
		case emApp: {
			Term *f1 = whnf_term(t->mApp.term1);
			if (f1->which == emLam) {
				Term *freeme;
				res = nf_term((freeme =substM_term(f1->mLam.name, t->mApp.term2, f1->mLam.term)));
				freeTermDeep(freeme);
			} else
				res = makeTerm((Term){.which = emApp,
						.mApp = {.term1=nf_term(f1),
							 .term2=nf_term(t->mApp.term2)}
						});
			freeTermDeep(f1);
			break; }
		case emVar:
			res = copyTermDeep(t);
			break;
		case emWit: 
			res = makeTerm((Term) {.which = emWit,
						.mWit = {.type = nf_type(t->mWit.type),
							.term1 = nf_term(t->mWit.term1),
							.term2 = nf_term(t->mWit.term2)}
						});
			break;
		case emAbs: {
			Name  n1	= t->mAbs.name1;
			Name  n2	= t->mAbs.name3;
			Type *t1 	= t->mAbs.type2;
			Type *t2 	= t->mAbs.type4;
			Term *m1	= t->mAbs.term5;
			Term *m2	= t->mAbs.term6;
			Term *m1_	= whnf_term(m1);
			if (m1_->which == emWit) {
				Term *freeme;
				res = nf_term((freeme = substM_term(n1, m1_->mWit.term1, substM_term(n2, m1_->mWit.term2, m2))));
				freeTermDeep(freeme);
			} else {
				res = makeTerm((Term) {.which = emAbs,
							.mAbs = {
							.name1 = copyName(n1),
							.type2 = nf_type(t1),
							.name3 = copyName(n2),
							.type4 = nf_type(t2),
							.term5 = nf_term(m1_),
							.term6 = nf_term(m2)}
							});
			}
			break; }
		case emTup:
			res = makeTerm((Term) {.which = emTup,
						.mTup = {.type = nf_type(t->mTup.type),
							.term1 = nf_term(t->mTup.term1),
							.term2 = nf_term(t->mTup.term2)}
						});
			break;
		case emPi1: {
			Term *m_ = whnf_term(t->mPi1.term);
			if (m_->which == emTup)
				res = nf_term(m_->mTup.term1);
			else
				res = makeTerm((Term) {.which = emPi1,
							.mPi1 = {.term = nf_term(m_)}
							});
			freeTermDeep(m_);
			break; }
		case emPi2: {
			Term *m_ = whnf_term(t->mPi2.term);
			if (m_->which == emTup)
				res = nf_term(m_->mTup.term2);
			else
				res = makeTerm((Term) {.which = emPi2,
							.mPi2 = {.term = nf_term(m_)}
							});
			freeTermDeep(m_);
			break; }
		case emIn1:
			res = makeTerm((Term) {.which = emIn1,
						.mIn1 = {.type = nf_type(t->mIn1.type),
							 .term = nf_term(t->mIn1.term)}
						});
			break;
		case emIn2:
			res = makeTerm((Term) {.which = emIn2,
						.mIn2 = {.type = nf_type(t->mIn2.type),
							 .term = nf_term(t->mIn2.term)}
						});
			break;
		case emCas: {
    			Term *m_ = whnf_term(t->mCas.term);
			Term *res_;
			switch (m_->which) {
				case emIn1:
					res_ = substM_term(t->mCas.casIn1.name,  m_->mIn1.term, t->mCas.casIn1.term);
					break;
				case emIn2:
					res_ = substM_term(t->mCas.casIn2.name,  m_->mIn2.term, t->mCas.casIn2.term);
					break;
				default: {
      					Term tmp = (Term) {.which = emCas,
								.mCas = {.term = m_,
									.casIn1 = t->mCas.casIn1,
									.casIn2 = t->mCas.casIn2 }
								};
					res_ = copyTermDeep(&tmp);
					break; }
			}
			freeTermDeep(m_);
			res = nf_term(res_);
			freeTermDeep(res_);
			break; }
		case emEps:
			res = makeTerm((Term) {.which = emEps,
						.mEps = {.type = nf_type(t->mEps.type),
							 .term = nf_term(t->mEps.term)}
						});
			break;
		default:
			die("Unhandled term!");
	}
	return res;
}

//! 110 111
//!   nf (Kpi x t k) = Kpi x (nf t) (nf k)
//!   nf k = k
Kind *nf_kind(const Kind const * t) {
	switch (t->which) {
		case eKstar:
			return copyKindDeep(t);
		case eKpi:
			return makeKind((Kind){.which=eKpi,
						.kPi = {.name = copyName(t->kPi.name),
							.type = nf_type(t->kPi.type),
							.kind = nf_kind(t->kPi.kind)}
						});
	}
	die("Unhandled kind!");
}

Any nf(const Any /*t*/any) {
	switch (any.which) {
		case eAnyType:
			return anyOfType(nf_type(any.mType));
		case eAnyTerm:
			return anyOfTerm(nf_term(any.mTerm));
		case eAnyKind:
			return anyOfKind(nf_kind(any.mKind));
		case eAnyName:
		case eAnyBind:
			return any;
	}
	die("Unhandled option in Any");
}
