/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
/**
 * @file gen_spec_checker.h
 * @brief Basic proof-theoretic operations such as substitutions, alpha
 *        and beta equivalence.
 * @author Maciej Zielenkiewicz
 * @author Marcin Benke
 */
#ifndef _GEN_SPEC_CHECKER_H
#define _GEN_SPEC_CHECKER_H  1
#include <stdbool.h>
#include "vars_set.h"
#include "namemap.h"

nameSet *freeNames(const Any any) ;
Any substT(Name n, Type *s, const Any /*t*/any) ;
Type *substT_type(Name n, Type *s, const Type const*t) ;
Term *substT_term(Name n, Type *s, const Term const * t) ;
Any substM(Name n, Term *s, const Any /*t*/any) ;
Type *substM_type(Name n, Term *s, const Type const*t) ;
Term *substM_term(Name n, Term *s, const Term const * t) ;
Kind *substM_kind(Name n, Term *s, const Kind const * t) ;
Name  freshNameFvs(nameSet*);
Any renameT(Name n1, Name n2, const Any a);
Any renameM(Name n1, Name n2, const Any a);
Any refreshWith(namemap r, nameSet *ns, const Any /*t*/any);
Term *refreshWith_term(namemap r, nameSet *ns, const Term const * t);
Type *refreshWith_type(namemap r, nameSet *ns, const Type const*t);
bool alphaeq_type(const Type const *t, const Type const *t_) ;
bool alphaeq_term(const Term const *t, const Term const *t_);
bool alphaeq(const Any t, const Any t_);
/*@ requires valid_Any(t) && valid_Any(t_);
  @ assigns \nothing;
  @*/
bool betaeq(const Any t, const Any t_);
Any nf(const Any /*t*/any);
Term *nf_term(const Term const * t);
Type *nf_type(const Type const*t);

#endif
