/**************************************************************************/
/*                                                                        */
/*  This file is part of Frama-C.                                         */
/*                                                                        */
/*  Copyright (C) 2007-2014                                               */
/*    CEA (Commissariat à l'énergie atomique et aux énergies              */
/*         alternatives)                                                  */
/*                                                                        */
/*  you can redistribute it and/or modify it under the terms of the GNU   */
/*  Lesser General Public License as published by the Free Software       */
/*  Foundation, version 2.1.                                              */
/*                                                                        */
/*  It is distributed in the hope that it will be useful,                 */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
/*  GNU Lesser General Public License for more details.                   */
/*                                                                        */
/*  See the GNU Lesser General Public License version 2.1                 */
/*  for more details (enclosed in the file licenses/LGPLv2.1).            */
/*                                                                        */
/**************************************************************************/

/* ISO C: 7.20 */
#ifndef __FC_STDLIB
#define __FC_STDLIB
#include "__fc_define_size_t.h"
#include "__fc_define_wchar_t.h"
#include "__fc_define_restrict.h"

typedef struct __fc_div_t {
  int quot;              /* Quotient.  */
  int rem;               /* Remainder.  */
} div_t;
typedef struct __fc_ldiv_t {
  long int quot;              /* Quotient.  */
  long int rem;               /* Remainder.  */
} ldiv_t;

typedef struct __fc_lldiv_t {
  long long int quot;              /* Quotient.  */
  long long int rem;               /* Remainder.  */
} lldiv_t;

#include "__fc_define_null.h"

/* These could be customizable */
#define EXIT_FAILURE (-1)
#define EXIT_SUCCESS 0

#include "limits.h"

#define RAND_MAX __FC_RAND_MAX
#define MB_CUR_MAX __FC_MB_CUR_MAX

/*@ assigns \result \from nptr[..] ; */
double atof(const char *nptr);

/*@ assigns \result \from nptr[..] ; */
int atoi(const char *nptr);
/*@ assigns \result \from nptr[..] ; */
long int atol(const char *nptr);
/*@ assigns \result \from nptr[..] ; */
long long int atoll(const char *nptr);

/* See ISO C: 7.20.1.3 to complete these specifications */
/*@ assigns \result,*endptr \from nptr[0..],nptr ; */
double strtod(const char * restrict nptr,
     char ** restrict endptr);
/*@ assigns \result,*endptr \from nptr[0..],nptr ; */
float strtof(const char * restrict nptr,
     char ** restrict endptr);
/*@ assigns \result,*endptr \from nptr[0..],nptr ; */
long double strtold(const char * restrict nptr,
     char ** restrict endptr);

/* TODO: See ISO C 7.20.1.4 to complete these specifications */
/*@ assigns \result,*endptr \from nptr[0..]; */
long int strtol(
     const char * restrict nptr,
     char ** restrict endptr,
     int base);
/*@ assigns \result,*endptr \from nptr[0..]; */
long long int strtoll(
     const char * restrict nptr,
     char ** restrict endptr,
     int base);
/*@ assigns \result,*endptr \from nptr[0..]; */
unsigned long int strtoul(
     const char * restrict nptr,
     char ** restrict endptr,
     int base);
/*@ assigns \result,*endptr \from nptr[0..]; */
unsigned long long int strtoull(
     const char * restrict nptr,
     char ** restrict endptr,
     int base);

int __fc_random_counter __attribute__((unused));
const unsigned long __fc_rand_max = __FC_RAND_MAX;
/* ISO C: 7.20.2 */
/*@ assigns \result \from __fc_random_counter ;
  @ assigns __fc_random_counter ;
  @ ensures 0 <= \result <= __fc_rand_max ;
*/
int rand(void);

/*@ assigns __fc_random_counter \from seed ; */
void srand(unsigned int seed);

/* We give a specification of a simple allocator that has a limited
   number of slots MAX_ALLOCS available in the __allocated array and 
   total number of allocated bytes is less than or equal specified HEAP_SIZE */
/*@ axiomatic dynamic_allocation_sizes {
  @  logic size_t MAX_ALLOCS;
  @  logic size_t HEAP_SIZE;
  @  logic size_t UINT32_MAX;
  @  logic size_t SINT32_MAX;
  @  axiom uint32_max_def:
  @       UINT32_MAX == 4294967295;
  @  axiom sint32_max_def:
  @       SINT32_MAX == 2147483647;
  @  axiom max_allocs_range: 
  @       0 <= MAX_ALLOCS <= 2147483647;
  @  axiom max_allocs_size:
  @       MAX_ALLOCS == 1024;
  @  axiom heap_size_range: 
  @       0 <= HEAP_SIZE <= 2147483647;
  @ }
  @*/

//@ ghost char* __allocated[1024];
//@ ghost size_t  __size_allocated = 0;
//@ ghost size_t  __num_allocated = 0; 


// MAX_ALLOCS must be with strict inequality
/*@
  @ axiomatic dynamic_allocation {
  @
  @ predicate is_allocable{L}(size_t size, size_t no) = size > 0 && no > 0 &&
  @                 \at(__num_allocated, L) + no <= MAX_ALLOCS &&
  @                 \at(__size_allocated, L) + size <= HEAP_SIZE;

  @ predicate allocation_footprint{L,M}(size_t s, size_t no) = 
  @                 \at(__num_allocated, L) + no == \at(__num_allocated,M) &&
  @                 \at(__size_allocated, L) + s == \at(__size_allocated,M);

  @
  @ predicate correct_allocation{L}(size_t i) =
  @     \at(__num_allocated, L) <= MAX_ALLOCS &&
  @     \at(__size_allocated, L) <= HEAP_SIZE;
  @
  @ predicate is_allocated_size{L}(char* p, size_t i) = 
  @    \at(__num_allocated, L) <= MAX_ALLOCS ==>
  @      \exists size_t j; (0 <= j < \at(__num_allocated, L) && 
  @           \at(__allocated[j], L)==p &&
  @           \valid{L}(__allocated[j]+(0..i-1)));
  @
  @ predicate is_allocated{L}(char* p) = 
  @    \at(__num_allocated, L) <= MAX_ALLOCS ==>
  @    \exists size_t i; is_allocated_size{L}(p, i);
  @
  @ predicate old_allocated{L,M}(char* p) = 
  @     \forall size_t i, j; 
  @              ((0 <= i < \at(__num_allocated,L) && 
  @               (0 <= j < i &&
  @               \at(__allocated[i],L)==p) ==> 
  @                   \at(__allocated[j],L) == \at(__allocated[j],M))) &&
  @              ((0 <= i < \at(__num_allocated,L) && 
  @               (i < j < \at(__num_allocated,L) &&
  @               \at(__allocated[i],L)==p) ==> 
  @                   \at(__allocated[j],L) == \at(__allocated[j-1],M)));
  @
  @   axiom __allocated_small{L}:
  @         0 <= \at(__num_allocated,L) < MAX_ALLOCS;
  @
  @   axiom __allocated_valid{L}:
  @    \forall char* keys, size_t s;
  @         is_allocated_size{L}(keys,s) ==>
  @         \valid{L}(keys+(0..s-1));

  @   axiom valid__allocated{L}:
  @    \forall char* keys, size_t s;
  @         \valid{L}(keys+(0..s-1)) ==>
  @         \exists char* keys0, size_t s0, i; is_allocated_size{L}(keys0, s0) &&
  @                                            keys0+i==keys && i+s<=s0;
  @
  @   axiom unique_in__allocated{L}:
  @    \forall integer i, j; 0 <= i <= j < MAX_ALLOCS &&
  @                  __allocated[i] == __allocated[j] ==> i==j;
  @
  @   axiom sep__allocated{L}:
  @     \forall size_t i, size_t j; 
  @         0 <= i < __num_allocated && 
  @         \valid((__allocated[i])+(0..j)) ==> 
  @         \separated(__allocated+(0..MAX_ALLOCS-1),(__allocated[i])+(0..j));
  @
  @   axiom sep__allocated_between{L}:
  @     \forall int i, j, size_t k,l;  
  @         0 <= i < __num_allocated &&
  @         0 <= j < __num_allocated &&
  @         i != j &&
  @         \valid((__allocated[i])+(0..k)) &&
  @         \valid((__allocated[j])+(0..l)) ==>
  @         \separated((__allocated[i])+(0..k),__allocated[j]+(0..l));
  @
  @  axiom allocated_block_length{L}:
  @       \forall char* p, size_t l; is_allocated_size{L}(p,l) <==> \block_length{L}(p) == l;
  @
  @   // we should make it a lemma after the sum of sizes is axiomatised
  @   axiom allocated_in_heap_size{L}:
  @       \forall char* p, size_t l; is_allocated_size{L}(p,l) ==> l < HEAP_SIZE;
  @   
  @   axiom non_null_for_allocated:
  @      \forall size_t i; 0 <= i < __num_allocated ==> __allocated[i] != \null;
  @   
  @   lemma is_allocable_monotone: 
  @       \forall size_t m, n, k, l; (0 < n <= m && 0 < k <= l) ==> is_allocable(m,l) ==> is_allocable(n,k);
  @   
  @   
  @   lemma valid_different_separated:
  @     \forall char* p, char* q; \valid(p) && \valid(q) && p!=q ==>
  @           \separated(p,q);
  @
  @   lemma is_allocable_det{L}:
  @     \forall size_t i,j; is_allocable{L}(i,j) || !is_allocable{L}(i,j);

  @   lemma is_allocated_det{L}:
  @     \forall char* i, size_t j; is_allocated_size{L}(i,j) || !is_allocated_size{L}(i,j);
  @
  @ }
  @*/

/*@ axiomatic on_allocation {
  @
  @   lemma later_allocated_different{L,M}: 
  @       \forall size_t i, char *p, char* q;
  @             is_allocated{L}(p) && \at(__num_allocated,L) < \at(__num_allocated,M) &&
  @             (\forall size_t j; 0 <= j < \at(__num_allocated,L) ==> 
  @                           \at(__allocated[j],L) == \at(__allocated[j],M)) &&
  @             \at(__num_allocated,L) <= i <  \at(__num_allocated,M) &&
  @             \at(__num_allocated,M) <= MAX_ALLOCS &&
  @             \at(__allocated[i],M)==q ==> p!=q;
  @
  @   lemma allocated_in_separated{L}:
  @       \forall char* p, size_t l; is_allocated{L}(p) && \valid{L}(p+(0..l)) &&
  @             \at(__num_allocated,L) <= MAX_ALLOCS ==> 
  @             \separated(__allocated+(0..MAX_ALLOCS-1),p+(0..l));
  @
  @   lemma old_allocated_is_allocated{L,M}:
  @      \forall char* p, char* q; 
  @           \at(__num_allocated, L) <= MAX_ALLOCS &&
  @           \at(__num_allocated, M) <= MAX_ALLOCS &&
  @           \at(__num_allocated, M)+1 == \at(__num_allocated, L) &&
  @           p!=q && old_allocated{L,M}(p) && 
  @           is_allocated{L}(p) && is_allocated{L}(q) ==>
  @              is_allocated{M}(q);
  @
  @
  @  lemma is_allocated_size_no_size{L}:
  @      \forall char* p, size_t n; 
  @          is_allocated_size{L}(p, n) ==> is_allocated{L}(p);
  @
  @ }
  @*/

/*@ requires 0 <= nmemb*size <= UINT32_MAX;
  @ behavior allocation:
  @   assumes is_allocable{Pre}((size_t)(nmemb*size),(size_t)1);
  @   assigns __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   ensures \result!=\null;
  @   ensures allocation_footprint{Pre,Post}((size_t)(nmemb*size),(size_t)1);
  @   ensures is_allocated_size{Post}((char*)\result, (size_t)(nmemb*size));

  @   ensures \forall char* p; \result!=\null && (is_allocated{Pre}(p) ==> p != (char*)\result);
  @   ensures \forall char* p, size_t n; is_allocated_size{Pre}(p,n) ==> is_allocated_size{Post}(p,n);
  @   ensures \forall size_t i; 0 <= i <= \at(__num_allocated,Post)-1 ==> \at(__allocated[i],Post) == \at(__allocated[i],Pre);
  @   ensures __allocated[__num_allocated-1] == (char*)\result;
  @   ensures \valid((char*)\result+(0..(nmemb*size)-1));
  @   ensures \separated(__allocated+(0..MAX_ALLOCS-1),(char*)\result+(0..(nmemb*size)-1));
  @   ensures \forall char** a, size_t s; is_allocated_size{Pre}((char*)a, s) ==> 
  @                     \separated((char*)\result+(0..(size_t)(nmemb*size)-1),a+(0..(sizeof(char*)*s)-1));
  @   ensures \forall char* a, size_t s; is_allocated_size{Pre}(a, s) ==> 
  @                     \separated((char*)\result+(0..(size_t)(nmemb*size)-1),a+(0..s-1));
  @ behavior no_allocation:
  @   assumes !is_allocable{Pre}((size_t)(nmemb*size),(size_t)1);
  @   assigns \nothing;
  @   ensures \result==\null;
  @   ensures allocation_footprint{Pre,Post}((size_t)0,(size_t)0);
  @   ensures \forall char* p, size_t n; is_allocated_size{Pre}(p,n) ==> is_allocated_size{Post}(p,n);
  @   ensures \forall size_t i; 0 <= i <= \at(__num_allocated,Post) ==> \at(__allocated[i],Post) == \at(__allocated[i],Pre);
  @   ensures !is_allocable{Pre}((size_t)(nmemb*size),(size_t)1);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
/* ISO C: 7.20.3.1 */
void *calloc(size_t nmemb, size_t size);


/*@ requires 0 <= size <= UINT32_MAX;
  @ behavior allocation:
  @   assumes is_allocable{Pre}(size,(size_t)1);
  @   assigns __allocated[__num_allocated],__size_allocated,__num_allocated;
  @   ensures \at(__size_allocated,Post) == \at(__size_allocated,Pre)+size;
  @   ensures \at(__num_allocated,Post) == \at(__num_allocated,Pre) + 1;
  @   ensures is_allocated_size{Post}((char*)\result, size);
  @   ensures __allocated[__num_allocated-1] == (char*)\result;
  @   ensures \forall char* p; is_allocated{Pre}(p) ==> p != (char*)\result;
  @   ensures \forall char* p, size_t n; is_allocated_size{Pre}(p,n) ==> is_allocated_size{Post}(p,n);
  @   ensures \valid((char*)\result+(0..size-1));
  @   ensures \result!=\null;
  @ behavior no_allocation:
  @   assumes !is_allocable{Pre}(size,(size_t)1);
  @   assigns \nothing;
  @   ensures \result==\null;
  @   ensures \at(__size_allocated,Post) == \at(__size_allocated,Pre);
  @   ensures \at(__num_allocated,Post) == \at(__num_allocated,Pre);
  @   ensures \forall char* p, size_t n; is_allocated_size{Pre}(p,n) ==> is_allocated_size{Post}(p,n);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
void *malloc(size_t size);

/*@ 
  @   requires  is_allocated{Pre}((char*)p);
  @   assigns  __allocated[__num_allocated], __size_allocated, __num_allocated;
  @   frees p;
  @   ensures !is_allocated{Post}((char*)p);
  @   ensures old_allocated{Pre,Post}((char *)p);
  @   ensures \forall size_t s; is_allocated_size{Pre}((char*)p,s) ==> \at(__size_allocated,Post) == \at(__size_allocated,Pre) - s;
  @   ensures allocation_footprint{Post,Pre}((size_t)(\block_length{Pre}((char*)p)), (size_t)1);
  @*/
void free(void *p);
/* The no_deallocation behaviour is not fully correct,
   free should not have a defined behaviour for 
   non-allocated pointers.
 */

#ifdef FRAMA_C_MALLOC_POSITION
#define __FRAMA_C_STRINGIFY(x) #x
#define __FRAMA_C_XSTRINGIFY(x) __FRAMA_C_STRINGIFY(x)
#define FRAMA_C_LOCALIZE_WARNING (" file " __FILE__ " line " __FRAMA_C_XSTRINGIFY(__LINE__))
#define malloc(x) (__Frama_C_malloc_at_pos(x,__FILE__ "_function_" __func__ "_line_" __FRAMA_C_XSTRINGIFY(__LINE__)))
#define free(x) (__Frama_C_free_at_pos(x,FRAMA_C_LOCALIZE_WARNING))
void *__Frama_C_malloc_at_pos(size_t size,const char* file);
void __Frama_C_free_at_pos(void* ptr,const char* pos);
#endif


void *realloc(void *ptr, size_t size);

/* ISO C: 7.20.4 */

/*@ assigns \nothing;
  @ ensures \false; */
void abort(void);

/*@ assigns \result \from \nothing ;*/
int atexit(void (*func)(void));

/*@ assigns \result \from \nothing ;*/
int at_quick_exit(void (*func)(void));

/*@
  assigns \nothing;
  ensures \false;
*/
void exit(int status);

/*@
  assigns \nothing;
  ensures \false;
*/
void _Exit(int status);

/*@ assigns \nothing ;
  ensures \result == \null || \valid(\result) ;
 */
char *getenv(const char *name);

/*@
  assigns \nothing;
  ensures \false; */
void quick_exit(int status);

/*@ assigns \result \from string[..]; */
int system(const char *string);

/* ISO C: 7.20.5 */

/* TODO: use one of the well known specification with high order compare :-) */
/*@  assigns ((char*)\result)[..] \from ((char*)key)[..], ((char*)base)[..],
                                        nmemb, size, *compar;  */
void *bsearch(const void *key, const void *base,
     size_t nmemb, size_t size,
     int (*compar)(const void *, const void *));

/*@ assigns ((char*)base)[..] \from ((char*)base)[..], nmemb, size, *compar ;
 */
  void qsort(void *base, size_t nmemb, size_t size,
             int (*compar)(const void *, const void *));

/* ISO C: 7.20.6 */

/*@ 
  requires abs_representable:(int)(-j) == -j ;
  assigns \result \from j ;
*/
int abs(int j);

/*@ 
  requires abs_representable:(long)(-j) == -j ;
  assigns \result \from j ; */
long int labs(long int j);

/*@
  requires abs_representable:(long long)(-j) == -j ;
  assigns \result \from j ; */
long long int llabs(long long int j);

/*@ assigns \result \from numer,denom ; */
div_t div(int numer, int denom);
/*@ assigns \result \from numer,denom ; */
ldiv_t ldiv(long int numer, long int denom);
/*@ assigns \result \from numer,denom ; */
lldiv_t lldiv(long long int numer, long long int denom);

/* ISO C: 7.20.7 */
/*@ assigns \result \from s[0..], n ;*/
int mblen(const char *s, size_t n);

/*@ assigns \result, pwc[0..n-1] \from s[0..n-1], n ;
*/
int mbtowc(wchar_t * restrict pwc,
     const char * restrict s,
     size_t n);

/*@ assigns \result, s[0..] \from wc ; */
int wctomb(char *s, wchar_t wc);

/* ISO C: 7.20.8 */

/*@ assigns \result, pwcs[0..n-1] \from s[0..n-1], n ; */
size_t mbstowcs(wchar_t * restrict pwcs,
     const char * restrict s,
     size_t n);

/*@ assigns \result, s[0..n-1] \from pwcs[0..n-1] , n ; */
size_t wcstombs(char * restrict s,
     const wchar_t * restrict pwcs,
     size_t n);


#endif
