/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include <stdlib.h>
#include <assert.h>
#include "namemap.h"

/*@ predicate not_modified_charr{L,M}(char** p, size_t size) =
  @    \forall size_t i; 0 <= i < size ==> \at(p[i],L) == \at(p[i],M);
  @ 
  @*/


void memcpy_charr(char** dest, char** src, size_t size) {
  size_t i = 0;
  /*@ loop invariant \forall size_t j; 0 <= j < i ==> dest[j]==\at(src[j],LoopEntry);
    @ loop invariant \forall size_t j; 0 <= j < size ==> src[j]==\at(src[j],LoopEntry);
    @ loop invariant size <= charr_bufsize;
    @ loop invariant \valid(dest+(0..size-1));
    @ loop invariant \valid_read(src+(0..size-1));
    @ loop invariant src==\null <==> dest==\null;
    @ loop invariant \separated(dest+(0..charr_bufsize-1), src+(0..charr_bufsize-1));
    @ loop invariant \separated(__allocated+(0..MAX_ALLOCS-1),(char*)dest+(0..sizeof(char*)*charr_bufsize-1));
    @ loop invariant 0 <= i <= size;
    @ loop invariant is_allocated_size((char*)src, (size_t)(charr_bufsize*sizeof(char*))) &&
    @                is_allocated_size((char*)dest, (size_t)(charr_bufsize*sizeof(char*)));
    @ loop invariant \forall char* p, size_t i; \valid{Pre}(p+(0..i)) ==> \valid{Here}(p+(0..i));
    @ loop invariant \forall char** p, size_t i; \valid{Pre}(p+(0..i)) ==> \valid{Here}(p+(0..i));
    @ loop invariant \forall size_t i; 0 <= i < MAX_ALLOCS ==> \at(__allocated[i],LoopEntry) == __allocated[i];
    @ loop invariant \forall char* p,*q, size_t n,m; \separated(\at(p,LoopEntry)+(0..n-1),\at(q,LoopEntry)+(0..m-1)) ==>
    @                                                \separated(\at(p,Here)+(0..n-1),\at(q,Here)+(0..m-1));
    @ loop invariant \forall char** p,**q, size_t n,m; \separated(\at(p,LoopEntry)+(0..n-1),\at(q,LoopEntry)+(0..m-1)) ==>
    @                                                \separated(\at(p,Here)+(0..n-1),\at(q,Here)+(0..m-1));
    @ loop invariant valid_charray(dest, charr_bufsize, i);
    @ loop invariant \at(__num_allocated,Pre) == __num_allocated;
    @ loop invariant \at(__size_allocated,Pre) == __size_allocated;
    @ loop invariant valid_content(src,size);
    @ loop assigns i,dest[0..size-1];
    @*/
  while (i<size) {
    dest[i]=src[i];
    //@ assert i<size;
    i++;
    //@ assert \forall size_t j; 0 <= j <= i ==> (0 <= j < i || j == i);
  }
  //@ assert size==i;
}



namemap namemap_new() {
	char **keys = calloc(DEFAULT_SIZE, sizeof(*keys));
        //@ assert keys!=\null ==> \at(__num_allocated,Pre)+1 == __num_allocated;
        if (keys == NULL) {
          //@ for alloc_new: assert \false;
          return (namemap){
            .size = 0, .bufsize = 0,
              .keys = NULL, .vals = NULL};
        };
        //@ assert keys !=\null;
        //@ assert is_allocated((char*)keys);
        //@ assert allocation_footprint{Pre,Here}((size_t)(DEFAULT_SIZE*sizeof(*keys)),(size_t)1);
	char **vals = calloc(DEFAULT_SIZE, sizeof(*vals));
        //@ assert vals !=\null ==> allocation_footprint{Pre,Here}((size_t)(2*DEFAULT_SIZE*sizeof(*keys)),(size_t)2);
        //@ assert is_allocated((char*)keys);
        //@ assert vals !=\null ==> is_allocated((char*)vals);
        //@ assert keys !=\null;
        //@ assert vals !=keys;
        if (vals == NULL) {
          free(keys);
          return (namemap){
            .size = 0, .bufsize = 0,
              .keys = NULL, .vals = NULL};
        } else {
          return (namemap){
            .size = 0, .bufsize = (keys)?DEFAULT_SIZE:0,
              .keys = keys, .vals = vals};
        }
}

void namemap_free(namemap n) {
  free(n.keys);
  //@ assert is_allocated((char*)(n.vals));
  //@ assert __size_allocated == \at(__size_allocated,Pre) - (size_t)(n.bufsize*sizeof(char*));
  free(n.vals);
}


namemap *namemap_insert(namemap *n, Name elem, Name val) {
        char **tmp=NULL;
        unsigned int nsize = n->bufsize * 2;
        //@ assert \valid(n);
        //@ assert is_allocated_size((char*)n, (size_t)sizeof(namemap));
	if (n->size == n->bufsize) {
               // @ assert valid_charray(n->vals, n->bufsize, n->size);
		tmp=calloc(nsize, sizeof(char*));
		if (tmp==NULL) return NULL;
                //@ ghost charr_bufsize = n->bufsize;
                // @ assert valid_charray(n->vals, n->bufsize, n->size);
                memcpy_charr(tmp, n->keys, n->size);
                free(n->keys);
                // @ assert \at(__num_allocated,Pre)==__num_allocated;
                n->keys=tmp;
		tmp=calloc(nsize, sizeof(char*));
                if (tmp==NULL) return NULL;
                //@ assert well_separated_arrays(n->keys, tmp, n->bufsize);
                //@ ghost charr_bufsize = n->bufsize;
                // @ assert valid_charray(n->vals, n->bufsize, n->size);
                memcpy_charr(tmp, n->vals, n->size);
                // @ assert \valid(n);
                free(n->vals);
                n->vals=tmp;
                n->bufsize=nsize;
                // @ assert \valid(n->keys+(0..n->bufsize-1));
                //@ assert well_separated(n->keys, n->bufsize, n);
                //@ assert well_separated(n->vals, n->bufsize, n);
                //@ assert is_allocated_size((char*)n, (size_t)sizeof(namemap));
                //@ assert well_separated_arrays(n->keys, n->vals, n->bufsize);
	}
        // @ assert \valid(n);
        //@ assert is_allocated_size((char*)n, (size_t)sizeof(namemap));
        //@ assert n->size <= n->bufsize;
        //@ assert well_separated(n->keys, n->bufsize, n);
        //@ assert well_separated(n->vals, n->bufsize, n);
        //@ assert well_separated_arrays(n->keys, n->vals, n->bufsize);
	n->keys[n->size] = elem;
        //@ assert well_separated(n->keys, n->bufsize, n);
        //@ assert well_separated(n->vals, n->bufsize, n);
        //@ assert well_separated_arrays(n->keys, n->vals, n->bufsize);
	n->vals[n->size] = val;
        //@ assert well_separated(n->keys, n->bufsize, n);
        //@ assert well_separated(n->vals, n->bufsize, n);
        //@ assert well_separated_arrays(n->keys, n->vals, n->bufsize);
	n->size++;
	return n;
}



Name namemap_lookup(const namemap n, const Name elem) {
	/* NULL == Nothing */
	int i;
        /*@
          @ loop invariant valid_Name(elem);
          @ loop invariant valid_namemap(n);
          @ loop invariant 0 <= i <= n.size;
          @ loop invariant !IsIn(n, i, elem);
          @ loop assigns i;
          @ loop variant n.size - i;
          @*/
	for (i = 0; i < n.size; ++i) {
		if (strcmp(elem, n.keys[i]) == 0)
			return n.vals[i];
        };
	return 0;
}



namemap* namemap_copy(const namemap in) {
  char** vals;
  char** keys;
  namemap* res = calloc(1,sizeof(namemap));
  if (res == NULL) {
    //@ for alloc_new: assert \false;
    return NULL;
  }
 BB:
  //@ for alloc_new: assert is_allocable{Pre}((size_t)((2*in.bufsize*sizeof(char*))),(size_t)2);
  //@ assert valid_charray(in.vals, in.bufsize, in.size);
  //@ assert valid_charray(in.keys, in.bufsize, in.size);
  //@ assert correct_allocation((size_t)0);
  keys = calloc(in.bufsize,sizeof(char*));
  //@ assert correct_allocation((size_t)0);
  //@ assert not_modified_charr{BB,Here}(in.keys, in.size);
  //@ assert not_modified_charr{BB,Here}(in.vals, in.size);
  //@ assert valid_charray(in.vals, in.bufsize, in.size);
  //@ assert valid_charray(in.keys, in.bufsize, in.size);
  if (keys == NULL) {
    // @ for alloc_new: assert \false;
    free(res);
    //@ for alloc_no: assert allocation_footprint{Pre,Here}((size_t)0, (size_t)0);
    return NULL;
   }
  //@ for alloc_new: assert is_allocable((size_t)(in.bufsize*sizeof(char*)),(size_t)1);
  //@ assert valid_charray(in.vals, in.bufsize, in.size);
  //@ assert valid_charray(in.keys, in.bufsize, in.size);
  //@ assert well_separated(keys, in.bufsize, res);
 AA:
  vals = calloc(in.bufsize, sizeof(char*));
  //@ assert not_modified_charr{AA,Here}(in.keys, in.size);
  //@ assert not_modified_charr{AA,Here}(in.vals, in.size);
  // @ assert __num_allocated <= MAX_ALLOCS;
  //@ assert valid_charray(in.vals, in.bufsize, in.size);
  //@ assert valid_charray(in.keys, in.bufsize, in.size);
  //@ assert well_separated(keys, in.bufsize, res);
  if (vals == NULL) {
    //@ for alloc_new: assert \false;
    //@ assert allocation_footprint{Pre,Here}((size_t)((in.bufsize*sizeof(char*))+sizeof(namemap)), (size_t)2);
    free(res);
    //@ for alloc_no: assert \at(__num_allocated,Pre)+1 == __num_allocated;
    free(keys);
    //@ for alloc_new: assert \false;
    //@ for alloc_no: assert allocation_footprint{Pre,Here}((size_t)0, (size_t)0);
    return NULL;
  }
  //@ assert vals!=\null;
  //@ assert keys!=\null;
  //@ ghost charr_bufsize = in.bufsize;
  // @ assert is_allocable{Pre}((size_t)((2*in.bufsize*sizeof(char*))+sizeof(namemap)),(size_t)3);
  //@ assert \separated((char*)keys+(0..(size_t)(in.bufsize*sizeof(char*))-1),(char*)(in.keys)+(0..(size_t)(in.bufsize*sizeof(char*)-1)));
  //@ assert is_allocated_size((char*)keys, (size_t)(in.bufsize*sizeof(char*)));
  //@ assert is_allocated_size((char*)vals, (size_t)(in.bufsize*sizeof(char*)));
  //@ assert valid_charray(in.keys, in.bufsize, in.size);
  //@ assert well_separated(keys, in.bufsize, res);
  //@ assert well_separated(vals, in.bufsize, res);
 A:
  memcpy_charr(keys, in.keys, in.size);
  //@ assert not_modified_charr{A,Here}(in.keys, in.size);
  //@ assert not_modified_charr{A,Here}(in.vals, in.size);
  //@ ghost charr_bufsize = in.bufsize;
  //@ for alloc_new: assert \separated(vals+(0..(size_t)(in.bufsize-1)),in.vals+(0..(size_t)(in.bufsize-1)));
  //@ assert is_allocated_size((char*)keys, (size_t)(in.bufsize*sizeof(char*)));
  //@ assert is_allocated_size((char*)vals, (size_t)(in.bufsize*sizeof(char*)));
  //@ assert valid_charray(keys, in.bufsize, in.size);
  //@ assert valid_charray(in.vals, in.bufsize, in.size);
  //@ assert well_separated(keys, in.bufsize, res);
  //@ assert well_separated(vals, in.bufsize, res);
  memcpy_charr(vals, in.vals, in.size);
  //@ assert valid_charray(keys, in.bufsize, in.size);
  //@ assert valid_charray(vals, in.bufsize, in.size);
  //@ assert valid_sizes(in.size, in.bufsize);
  //@ assert is_allocated_size((char*)keys, (size_t)(in.bufsize*sizeof(char*)));
  //@ assert is_allocated_size((char*)vals, (size_t)(in.bufsize*sizeof(char*)));
  //@ assert keys != vals;
  //@ assert well_separated(keys, in.bufsize, res);
  //@ assert well_separated(vals, in.bufsize, res);
  res->size = in.size;
  res->bufsize = in.bufsize;
  res->keys = keys;
  res->vals = vals;
  //@ assert well_separated(res->keys, res->bufsize, res);
  //@ assert well_separated(res->vals, res->bufsize, res);
  //@ assert valid_charray(res->keys, res->bufsize, res->size);
  //@ assert valid_charray(res->vals, res->bufsize, res->size);
  //@ assert valid_sizes(res->size, res->bufsize);
  //@ assert res->keys != res->vals;
  return res;
}
