/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include <string.h>
#include "printMessages.h"

//#define PRINT_BUFFER_LEN 4096

char* printMessages[36] = {
  "Kstar", //0 PRINT_KSTAR
  "Pi ", //1  PRINT_PI
  " : ", //2  PRINT_COLONSPACES
  ".", //3    PRINT_DOT
  "(", // 4   PRINT_LPAR
  ")", // 5   PRINT_RPAR
  "A ", //6 PRINT_A
  ":", //7    PRINT_COLON2
  "E ", //8 PRINT_E
  "/\\", //9  PRINT_AND
  "\\/", //10 PRINT_OR
  "Bot", //11 PRINT_BOT
  "\n", // 12 PRINT_EOL
  "Lam ", //13 PRINT_LAMBDA
  "[",  //14 PRINT_LSQPAR
  "]_{", //15 PRINT_RSQPAR_LCURPAR
  "}", //16 PRINT_RCURPAR
  "abstract <", //17 PRINT_ABSTRACT
  ", ", //18 PRINT_COMMASPACE
  "> = ", //19 PRINT_RANGLE_EQ
  " in ", //20 PRINT_IN
  "<", // 21 PRINT_LANGLE
  ">_{", //22 PRINT_RANGLE_LCURPAR
  "Pi1", //23 PRINT_PI1
  "Pi2", //24 PRINT_PI2
  "In1_{", //25 PRINT_IN1
  "In2_{", //26 PRINT_IN2
  "case ", //27 PRINT_CASE
  " in (left ", //28 PRINT_IN_LEFT
  ")(right ", //29 PRINT_RIGHT
  "e ", //30 PRINT_EPSILON
  "Kind: wrong enum", //31 PRINT_KIND_WRONG_ENUM
  "Term: wrong enum", //32
  "Type: wrong enum", //33
  "->", //34 PRINT_ARROW
  "_", //35 PRINT_UNDERSCORE
};


char printBuffer[PRINT_BUFFER_LEN];
int printBufferOverflow=0;


void printMessage(char *s) {
  int buf_len = strlen((char*)printBuffer);
  int s_len = strlen(s);
  printBufferOverflow=0;
  if(s_len < 0 || buf_len < 0)
    return;
  if(s_len > PRINT_BUFFER_LEN - 1){
    printBufferOverflow=1;
    return;
  }
  if((buf_len + s_len) >= (PRINT_BUFFER_LEN -2)){
    printBufferOverflow=1;
    return;
  }
  printBuffer[buf_len+1] = '#';
  printBuffer[buf_len+2] = 0;
  strncat(printBuffer, s, PRINT_BUFFER_LEN - strlen(printBuffer) - 1);
  
}

//concatMessage does not set initially printBufferOverflow=0
//since it is only an auxiliary function

int concatMessage(char *s){
  int buf_len = strlen((char*)printBuffer);
  int s_len = strlen(s);
  if(s_len < 0 || buf_len < 0)
    return 0;
  if(s_len > PRINT_BUFFER_LEN - 1){
    printBufferOverflow=1;
    return buf_len;
  }
  if((buf_len + s_len) >= (PRINT_BUFFER_LEN -2)){
    printBufferOverflow=1;
    return buf_len;
  }
  strncat(printBuffer, s, PRINT_BUFFER_LEN - strlen((char*)printBuffer) - 1);
  return strlen((char*)printBuffer);
}




/*@ requires \valid(k) && valid_Kind_ptr(k);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @*/


void _printKind(Kind* k) {
  if(k==NULL)
    return;
   switch (k->which) {
  case eKstar:
    concatMessage(printMessages[PRINT_KSTAR]);
    break;
  case eKpi:
    concatMessage(printMessages[PRINT_LPAR]);
    concatMessage(printMessages[PRINT_PI]);
    concatMessage(k->kPi.name);
    concatMessage(printMessages[PRINT_COLONSPACES]);
    _printType(k->kPi.type);
    concatMessage(printMessages[PRINT_RPAR]);
    _printKind((k->kPi).kind);
    break;
  default:
      concatMessage(printMessages[PRINT_KIND_WRONG_ENUM]);
    break;
  }
}

/*@ requires \valid(t) && valid_Type_ptr(t);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @*/

void _printType(Type* t) {
  if(t==NULL)
    return;
  switch (t->which) {
    case etVar:
      concatMessage((t->tVar).name);
      break;
  case etAll:
    if (strcmp((t->tAll).name, printMessages[PRINT_UNDERSCORE])!=0) {
      concatMessage(printMessages[PRINT_LPAR]);    
      concatMessage(printMessages[PRINT_A]);
      concatMessage((t->tAll).name);
      concatMessage(printMessages[PRINT_COLON]);    
      _printType((t->tAll).type1);
      concatMessage(printMessages[PRINT_DOT]);
      _printType((t->tAll).type2);
      concatMessage(printMessages[PRINT_RPAR]);
    } else {
      concatMessage(printMessages[PRINT_LPAR]);    
      _printType((t->tAll).type1);
      concatMessage(printMessages[PRINT_ARROW]);
      _printType((t->tAll).type2);
      concatMessage(printMessages[PRINT_RPAR]);
    }
    break;
  case etApp:
    _printType((t->tApp).type);
    _printTerm((t->tApp).term);
    break;
  case etExi:
    concatMessage(printMessages[PRINT_LPAR]);            
    concatMessage(printMessages[PRINT_E]);        
    concatMessage((t->tExi).name);
    concatMessage(printMessages[PRINT_COLONSPACES]);
    _printType((t->tExi).type1);
    concatMessage(printMessages[PRINT_RPAR]);            
    _printType((t->tExi).type2);
    break;
  case etAnd:
    _printType((t->tAnd).type1);
    concatMessage(printMessages[PRINT_AND]);
    _printType((t->tAnd).type2);
    break;
  case etOr:
    _printType((t->tOr).type1);
    concatMessage(printMessages[PRINT_OR]);    
    _printType((t->tOr).type2);
    break;
  case etBot:
    concatMessage(printMessages[PRINT_BOT]);        
    break;
  default:
    concatMessage(printMessages[PRINT_TYPE_WRONG_ENUM]);
    return;
  }
 }


/*@ requires \valid(t) && valid_Term_ptr(t);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @*/

void _printTerm(Term *t) {
  switch (t->which) {
    case emVar:
      concatMessage((t->mVar).name);
      break;
  case emApp:
    concatMessage(printMessages[PRINT_LPAR]);
    _printTerm((t->mApp).term1);
    _printTerm((t->mApp).term2);
    concatMessage(printMessages[PRINT_RPAR]);
    break;
  case emLam:
    concatMessage(printMessages[PRINT_LPAR]);
    concatMessage(printMessages[PRINT_LAMBDA]);
    concatMessage((t->mLam).name);
    concatMessage(printMessages[PRINT_COLONSPACES]);
    _printType((t->mLam).type);
    concatMessage(printMessages[PRINT_DOT]);
    _printTerm((t->mLam).term);
    concatMessage(printMessages[PRINT_RPAR]);
    break;
  case emWit:
    concatMessage(printMessages[PRINT_LSQPAR]);
    _printTerm((t->mWit).term1);
    concatMessage(printMessages[PRINT_COMMASPACE]);
    _printTerm((t->mWit).term2);
    concatMessage(printMessages[PRINT_RSQPAR_LCURPAR]);
    _printType((t->mWit).type);
    concatMessage(printMessages[PRINT_RCURPAR]);    
    break;
  case emAbs: 
    concatMessage(printMessages[PRINT_ABSTRACT]);
    concatMessage((t->mAbs).name1);
    concatMessage(printMessages[PRINT_COLONSPACES]);
    _printType((t->mAbs).type2);
    concatMessage(printMessages[PRINT_COMMASPACE]);
    concatMessage((t->mAbs).name3);
    concatMessage(printMessages[PRINT_COLONSPACES]);
    _printType((t->mAbs).type4);
    concatMessage(printMessages[PRINT_RANGLE_EQ]);
    _printTerm((t->mAbs).term5);
    concatMessage(printMessages[PRINT_IN]);
    _printTerm((t->mAbs).term6);
    break;
  case emTup:
    concatMessage(printMessages[PRINT_LANGLE]);
    _printTerm((t->mTup).term1);
    concatMessage(printMessages[PRINT_COMMASPACE]);
    _printTerm((t->mTup).term2);
    concatMessage(printMessages[PRINT_RANGLE_LCURPAR]);
    _printType((t->mTup).type);
    concatMessage(printMessages[PRINT_RCURPAR]);
    break;
  case emPi1:
    concatMessage(printMessages[PRINT_PI1]);
    _printTerm((t->mPi1).term);
    break;
  case emPi2:
    concatMessage(printMessages[PRINT_PI2]);
    _printTerm((t->mPi2).term);
    break;
  case emIn1:
    concatMessage(printMessages[PRINT_IN1]);
    _printType((t->mIn1).type);
    concatMessage(printMessages[PRINT_RCURPAR]);
    _printTerm((t->mIn1).term);
    break;
  case emIn2:
    concatMessage(printMessages[PRINT_IN2]);
    _printType((t->mIn2).type);
    concatMessage(printMessages[PRINT_RCURPAR]);
    _printTerm((t->mIn2).term);
    break;
  case emCas:
    concatMessage(printMessages[PRINT_CASE]);
    _printTerm((t->mCas).term);
    concatMessage(printMessages[PRINT_IN_LEFT]);
    concatMessage(((t->mCas).casIn1).name);
    concatMessage(printMessages[PRINT_COLONSPACES]);
    _printType(((t->mCas).casIn1).type);
    concatMessage(printMessages[PRINT_DOT]);
    _printTerm(((t->mCas).casIn1).term);
    concatMessage(printMessages[PRINT_RIGHT]);
    concatMessage(((t->mCas).casIn2).name);
    concatMessage(printMessages[PRINT_COLONSPACES]);
    _printType(((t->mCas).casIn2).type);
    concatMessage(printMessages[PRINT_DOT]);
    _printTerm(((t->mCas).casIn2).term);
    concatMessage(printMessages[PRINT_RPAR]);
    break;
  case emEps:
    concatMessage(printMessages[PRINT_EPSILON]);
    _printType((t->mEps).type);
    concatMessage(printMessages[PRINT_LPAR]);
    _printTerm((t->mEps).term);
    concatMessage(printMessages[PRINT_RPAR]);
    break;
  default:
    concatMessage(printMessages[PRINT_TERM_WRONG_ENUM]);
    return;
  }
}


void printKind(Kind* k){
  printBufferOverflow=0;
  _printKind(k);
  if(printBufferOverflow==1){
     reportError(messages[ENV_MSG_PRINT_BUFFER_OVERFLOW]);
     return;
  }
  concatMessage(printMessages[PRINT_EOL]);
  if(printBufferOverflow==1){
    reportError(messages[ENV_MSG_PRINT_BUFFER_OVERFLOW]);
  }
}



void printType(Type* t){
  printBufferOverflow=0;  
  _printType(t);
  if(printBufferOverflow==1){
     reportError(messages[ENV_MSG_PRINT_BUFFER_OVERFLOW]);
     return;
  }  
  concatMessage(printMessages[PRINT_EOL]);
  if(printBufferOverflow==1){
    reportError(messages[ENV_MSG_PRINT_BUFFER_OVERFLOW]);
  }
}

void printTerm(Term* t){
  printBufferOverflow=0;  
  _printTerm(t);
  if(printBufferOverflow==1){
    reportError(messages[ENV_MSG_PRINT_BUFFER_OVERFLOW]);
    return;
  }  
  concatMessage((char*)printMessages[PRINT_EOL]);
  if(printBufferOverflow==1){
    reportError(messages[ENV_MSG_PRINT_BUFFER_OVERFLOW]);
  }
}
