/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
/**
 * @file printMessages.h
 * @brief The pretty-printing procedures.
 * @author Konrad Zdanowski
 * @author Aleksy Schubert
 * @author Maciej Zielenkiewicz
 */
#ifndef _PRINT_MESSAGES_H
#define _PRINT_MESSAGES_H  1
#include <stdlib.h>
#include "errorMessages.h"
#include "checker.h"
#ifdef _FRAMAC_
//#include <__fc_string_axiomatic.h>

#endif


#include <stdlib.h>
#include "checker.h"

#define PRINT_BUFFER_LEN 4096
extern char printBuffer[PRINT_BUFFER_LEN];
//@ logic size_t L_PRINT_BUFFER_LEN = (size_t)4096;
extern int printBufferOverflow;

//size_t const CONST_PRINT_BUFFER_LEN = PRINT_BUFFER_LEN;

//int const PRINT_BUFFER_LEN = 4096;



#define printMessages_SIZE 35;
//@ logic size_t L_printMessages_SIZE = (size_t)36;



//auxiliary table with constant printing strings
//I do not know why but I could not use printMessages_size and
//printMessages_number in declaration/definition
//I got a compilation error

//extern char  printMessages[printMessages_number][printMessages_size];
extern char*  printMessages[];


#define PRINT_KSTAR 0
//@ logic size_t L_PRINT_KSTAR = (size_t) 0;
#define PRINT_PI 1
//@ logic size_t L_PRINT_PI  = (size_t)1;
#define PRINT_COLONSPACES 2
//@ logic size_t L_PRINT_COLONSPACES  = (size_t)2;
#define PRINT_DOT 3
//@ logic size_t L_PRINT_DOT  = (size_t)3;
#define PRINT_LPAR 4
//@ logic size_t L_PRINT_LPAR  = (size_t)4;
#define PRINT_RPAR 5
//@ logic size_t L_PRINT_RPAR  = (size_t)5;
#define PRINT_A 6
//@ logic size_t L_PRINT_A  = (size_t)6;
#define PRINT_COLON 7
//@ logic size_t L_PRINT_COLON  = (size_t)7;
#define PRINT_E 8
//@ logic size_t L_PRINT_E  = (size_t)8;
#define PRINT_AND 9
//@ logic size_t L_PRINT_AND  = (size_t)9;
#define PRINT_OR 10
//@ logic size_t L_PRINT_OR  = (size_t)10;
#define PRINT_BOT 11
//@ logic size_t L_PRINT_BOT  = (size_t)11;
#define PRINT_EOL 12
//@ logic size_t L_PRINT_EOL  = (size_t)12;
#define PRINT_LAMBDA 13
//@ logic size_t L_PRINT_LAMBDA  = (size_t)13;
#define PRINT_LSQPAR 14
//@ logic size_t L_PRINT_LSQPAR  = (size_t)14;
#define PRINT_RSQPAR_LCURPAR 15
//@ logic size_t L_PRINT_RSQPAR_LCURPAR  = (size_t)15;
#define PRINT_RCURPAR 16
//@ logic size_t L_PRINT_RCURPAR  = (size_t)16;
#define PRINT_ABSTRACT 17
//@ logic size_t L_PRINT_ABSTRAC  = (size_t)17;
#define PRINT_COMMASPACE 18
//@ logic size_t L_PRINT_COMMASPACE  = (size_t)18;
#define PRINT_RANGLE_EQ 19
//@ logic size_t L_PRINT_RANGLE_EQ  = (size_t)19;
#define PRINT_IN 20
//@ logic size_t L_PRINT_IN  = (size_t)20;
#define PRINT_LANGLE 21
//@ logic size_t L_PRINT_LANGLE  = (size_t)21;
#define PRINT_RANGLE_LCURPAR 22
//@ logic size_t L_PRINT_LCURPAR  = (size_t)22;
#define PRINT_PI1 23
//@ logic size_t L_PRINT_PI1  = (size_t)23;
#define PRINT_PI2 24
//@ logic size_t L_PRINT_PI2  = (size_t)24;
#define PRINT_IN1 25
//@ logic size_t L_PRINT_IN1  = (size_t)25;
#define PRINT_IN2 26
//@ logic size_t L_PRINT_IN2  = (size_t)26;
#define PRINT_CASE 27
//@ logic size_t L_PRINT_CASE  = (size_t)27;
#define PRINT_IN_LEFT 28
//@ logic size_t L_PRINT_LEFT  = (size_t)28;
#define PRINT_RIGHT 29
//@ logic size_t L_PRINT_RIGHT  = (size_t)29;
#define PRINT_EPSILON 30
//@ logic size_t L_PRINT_EPSILON  = (size_t)30;
#define PRINT_KIND_WRONG_ENUM 31
//@ logic size_t L_PRINT_KIND_WRONG_ENUM  = (size_t)31;
#define PRINT_TYPE_WRONG_ENUM 32
//@ logic size_t L_PRINT_TYPE_WRONG_ENUM  = (size_t)32;
#define PRINT_TERM_WRONG_ENUM 33
//@ logic size_t L_PRINT_TERM_WRONG_ENUM  = (size_t)33;
#define PRINT_ARROW 34
//@ logic size_t L_PRINT_ARROW  = (size_t)34;
#define PRINT_UNDERSCORE 35
//@ logic size_t L_PRINT_UNDERSCORE  = (size_t)35;



/*@ axiomatic print_messages_table {
  @
  @ predicate valid_printMessages(integer a) =
  @       \forall size_t i; 0 <= i < L_printMessages_SIZE ==>
  @              valid_string((char*)printMessages[i]);
  @
  @   axiom ax_valid_printMessages:
  @       \forall size_t i; 0 <= i < L_printMessages_SIZE ==>
  @              valid_string((char*)printMessages[i]);
  @
  @ }//print_messages_table
  @*/




/*@ predicate printBufferValid(integer a) = 
  @          valid_string((char*)printBuffer) && 
  @          strlen((char*)printBuffer) < 4096;
  @
  @*/

/*@
  @ // lemmas for printing Kinds, Terms, ...
  @
  @ axiomatic printing_lemmas { 
  @
  @
  @ lemma valid_Kind_to_valid_kPi{L}:
  @       \forall Kind k;
  @           valid_Kind{L}(k)   ==>
  @                (k.which)==eKpi  ==> 
  @                       valid_Kpi{L}(k.kPi);
  @
  @
  @  lemma valid_Kind_ptr_to_valid_kPi_Kind_ptr{L}:
  @   \forall Kind *k;
  @       valid_Kind_ptr{L}(k) ==> 
  @       (k->which) == eKpi   ==>
  @          (valid_Kind_ptr{L}((k->kPi).kind));
  @
  @  lemma valid_Kind_ptr_to_valid_kPi_Type_ptr{L}:
  @   \forall Kind *k;
  @       valid_Kind_ptr{L}(k) ==> 
  @       (k->which) == eKpi   ==>
  @          (valid_Type_ptr{L}((k->kPi).type));
  @
  @  lemma valid_Kind_ptr_to_valid_string_kPi_ptr_Name{L}:
  @   \forall Kind *k;
  @       valid_Kind_ptr{L}(k) ==> 
  @       (k->which) == eKpi   ==>
  @          (valid_string{L}((k->kPi).name));
  @
  @  lemma valid_Type_ptr_to_valid_string_tVar_ptr_Name{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etVar   ==>
  @          (valid_string{L}((k->tVar).name));
  @
  @  lemma valid_Type_ptr_to_valid_string_tAll_ptr_Name{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etAll   ==>
  @          (valid_string{L}((k->tAll).name));
  @
  @  lemma valid_Type_ptr_to_valid_tAll_Type1_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etAll   ==>
  @          (valid_Type_ptr{L}((k->tAll).type1));
  @
  @
  @  lemma valid_Type_ptr_to_valid_tAll_Type2_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etAll   ==>
  @          (valid_Type_ptr{L}((k->tAll).type2));
  @
  @
  @  lemma valid_Type_ptr_to_valid_tApp_Type_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etApp   ==>
  @          (valid_Type_ptr{L}((k->tApp).type));
  @
  @
  @  lemma valid_Type_ptr_to_valid_tApp_Term_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etApp   ==>
  @          (valid_Term_ptr{L}((k->tApp).term));
  @
  @
  @  lemma valid_Type_ptr_to_valid_string_tExi_ptr_Name{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etExi   ==>
  @          (valid_string{L}((k->tExi).name));
  @
  @  lemma valid_Type_ptr_to_valid_tExi_Type1_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etExi   ==>
  @          (valid_Type_ptr{L}((k->tExi).type1));
  @
  @
  @  lemma valid_Type_ptr_to_valid_tExi_Type2_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etExi   ==>
  @          (valid_Type_ptr{L}((k->tExi).type2));
  @
  @
  @
  @  lemma valid_Type_ptr_to_valid_tAnd_Type1_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etAnd   ==>
  @          (valid_Type_ptr{L}((k->tAnd).type1));
  @
  @
  @  lemma valid_Type_ptr_to_valid_tAnd_Type2_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etAnd   ==>
  @          (valid_Type_ptr{L}((k->tAnd).type2));
  @
  @
  @  lemma valid_Type_ptr_to_valid_tOr_Type1_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etOr   ==>
  @          (valid_Type_ptr{L}((k->tOr).type1));
  @
  @
  @  lemma valid_Type_ptr_to_valid_tOr_Type2_ptr{L}:
  @   \forall Type *k;
  @       valid_Type_ptr{L}(k) ==> 
  @       (k->which) == etOr   ==>
  @          (valid_Type_ptr{L}((k->tOr).type2));
  @
  @
  @  lemma valid_Term_ptr_to_valid_string_mVar_ptr_Name{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emVar   ==>
  @          (valid_string{L}((k->mVar).name));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mApp_Term1_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emApp   ==>
  @          (valid_Term_ptr{L}((k->mApp).term1));
  @
  @  lemma valid_Term_ptr_to_valid_mApp_Term2_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emApp   ==>
  @          (valid_Term_ptr{L}((k->mApp).term2));
  @
  @
  @  lemma valid_Term_ptr_to_valid_string_mLam_ptr_Name{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emLam   ==>
  @          (valid_string{L}((k->mLam).name));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mLam_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emLam   ==>
  @          (valid_Type_ptr{L}((k->mLam).type));
  @
  @  lemma valid_Term_ptr_to_valid_mLam_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emLam   ==>
  @          (valid_Term_ptr{L}((k->mLam).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mWit_Term1_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emWit   ==>
  @          (valid_Term_ptr{L}((k->mWit).term1));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mWit_Term2_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emWit   ==>
  @          (valid_Term_ptr{L}((k->mWit).term2));
  @
  @  lemma valid_Term_ptr_to_valid_mWit_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emWit   ==>
  @          (valid_Type_ptr{L}((k->mWit).type));
  @
  @
  @
  @  lemma valid_Term_ptr_to_valid_string_mAbs_ptr_Name1{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emAbs   ==>
  @          (valid_string{L}((k->mAbs).name1));
  @
  @  lemma valid_Term_ptr_to_valid_string_mAbs_ptr_Name3{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emAbs   ==>
  @          (valid_string{L}((k->mAbs).name3));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mAbs_Type2_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emAbs   ==>
  @          (valid_Type_ptr{L}((k->mAbs).type2));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mAbs_Type4_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emAbs   ==>
  @          (valid_Type_ptr{L}((k->mAbs).type4));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mAbs_Term5_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emAbs   ==>
  @          (valid_Term_ptr{L}((k->mAbs).term5));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mAbs_Term6_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emAbs   ==>
  @          (valid_Term_ptr{L}((k->mAbs).term6));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mTup_Term1_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emTup   ==>
  @          (valid_Term_ptr{L}((k->mTup).term1));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mTup_Term2_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emTup   ==>
  @          (valid_Term_ptr{L}((k->mTup).term2));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mTup_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emTup   ==>
  @          (valid_Type_ptr{L}((k->mTup).type));
  @
  @
  @
  @  lemma valid_Term_ptr_to_valid_mPi1_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emPi1   ==>
  @          (valid_Term_ptr{L}((k->mPi1).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mPi2_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emPi2   ==>
  @          (valid_Term_ptr{L}((k->mPi2).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mIn1_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emIn1   ==>
  @          (valid_Type_ptr{L}((k->mIn1).type));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mIn1_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emIn1   ==>
  @          (valid_Term_ptr{L}((k->mIn1).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mIn2_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emIn2   ==>
  @          (valid_Type_ptr{L}((k->mIn2).type));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mIn2_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emIn2   ==>
  @          (valid_Term_ptr{L}((k->mIn2).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mCas_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emCas   ==>
  @          (valid_Term_ptr{L}((k->mCas).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_string_mCas_casIn1_Name{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emCas   ==>
  @          (valid_string{L}(((k->mCas).casIn1).name));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mCas_casIn1_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emCas   ==>
  @          (valid_Type_ptr{L}(((k->mCas).casIn1).type));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mCas_casIn1_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emCas   ==>
  @          (valid_Term_ptr{L}(((k->mCas).casIn1).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_string_mCas_casIn2_Name{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emCas   ==>
  @          (valid_string{L}(((k->mCas).casIn2).name));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mCas_casIn2_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emCas   ==>
  @          (valid_Type_ptr{L}(((k->mCas).casIn2).type));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mCas_casIn2_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emCas   ==>
  @          (valid_Term_ptr{L}(((k->mCas).casIn2).term));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mEps_Type_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emEps   ==>
  @          (valid_Type_ptr{L}((k->mEps).type));
  @
  @
  @  lemma valid_Term_ptr_to_valid_mEps_Term_ptr{L}:
  @   \forall Term *k;
  @       valid_Term_ptr{L}(k) ==> 
  @       (k->which) == emEps   ==>
  @          (valid_Term_ptr{L}((k->mEps).term));
  @
  @
  @
  @ lemma valid_Type_ptr_to_valid{L}:
  @       \forall Type *k;
  @           valid_Type_ptr{L}(k) ==> \valid{L}(k);
  @
  @ lemma valid_Type_ptr_to_valid_Type{L}:
  @       \forall  Type *k;
  @           valid_Type_ptr{L}(k) ==> valid_Type{L}(*k);
  @
  @ lemma valid_Any_ptr_to_valid{L}:
  @       \forall Any *k;
  @           valid_Any_ptr{L}(k) ==> \valid{L}(k);
  @
  @ lemma valid_Term_ptr_to_valid{L}:
  @       \forall Term *k;
  @           valid_Term_ptr{L}(k) ==> \valid{L}(k);
  @
  @ lemma valid_Kind_ptr_to_valid{L}:
  @       \forall Kind *k;
  @           valid_Kind_ptr{L}(k) ==> \valid{L}(k);
  @
  @ lemma valid_Kind_ptr_to_valid_Kind{L}:
  @       \forall Kind *k;
  @           valid_Kind_ptr{L}(k) ==> valid_Kind{L}(*k);
  @ 
  @ }//printing_lemmas
  @*/



/*@
  @ requires valid_string(s);
  @ requires printBufferValid(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures \result < 4096;
  @*/

int concatMessage(char *s);





/*@
  @ requires valid_string(a);
  @ requires printBufferValid(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @*/
void printMessage(char *a);





/*@ requires \valid(k) && valid_Kind_ptr(k);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ requires errorBufferValid(0)&& errorNum < 2147483646;
  @ assigns printBuffer[0..4095], errorBuffer[0..4095], errorNum, printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @ ensures errorBufferValid(0);
  @*/

void printKind(Kind* k);

/*@ requires \valid(t) && valid_Type_ptr(t);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ requires errorBufferValid(0)&& errorNum < 2147483646;
  @ assigns printBuffer[0..4095], errorBuffer[0..4095], errorNum, printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @ ensures errorBufferValid(0);
  @*/

void printType(Type* t);

/*@ requires \valid(t) && valid_Term_ptr(t);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ requires errorBufferValid(0) && errorNum < 2147483646;
  @ assigns printBuffer[0..4095], errorBuffer[0..4095], errorNum, printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @ ensures errorBufferValid(0);
  @*/

void printTerm(Term* t);



/*@ requires \valid(k) && valid_Kind_ptr(k);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @*/

void _printKind(Kind* k);

/*@ requires \valid(t) && valid_Type_ptr(t);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @*/

void _printType(Type* t);

/*@ requires \valid(t) && valid_Term_ptr(t);
  @ requires printBufferValid(0);
  @ requires valid_printMessages(0);
  @ assigns printBuffer[0..4095], printBufferOverflow;
  @ ensures printBufferValid(0);
  @ ensures valid_printMessages(0);
  @*/

void _printTerm(Term* t);

#endif
