#!/usr/bin/perl -w
use strict;
use File::Slurp;
use File::Spec;

# used to process "include" comments in source files
# example:
#  //! filename start end
# is replaced with 
#  //! filename start end
#  //! line start of file filename
#  //! line start+1 of file filename
#  		 ...
#  //! line end of file filename
#
# other example:
#  //! filename start end
#  //! old contents
# is replaced with 
#  //! filename start end
#  //! line start of file filename
#  //! line start+1 of file filename
#  		 ...
#  //! line end of file filename
# is replaced with 
#  //! filename start end
#  //! line start of file filename
#  //! line start+1 of file filename
#  		 ...
#  //! line end of file filename
#
#  setting default file:
#  //! FILE nameoffile
#  is you only write one number you'll get one line

local our %files;
local our $basepath = ($ARGV[1] or "../LambdaP");
local our $deffile = "";

sub getFile {
	my ($name) = @_;
	unless ($files{$name}) {
		my @lines = read_file(File::Spec->catdir($basepath, $name));
		$files{$name} = \@lines;
	}
	return $files{$name};
}


my $inComment = 0;

LINE:
	while (<>) {
		if ($inComment) {
			unless (/^\/\/!/) {
				$inComment = 0;
				print;
			} else {
#				no print is intentional 
			}
		} else {
			print;
			my ($file, $start, $end);
			if (/^\/\/!\s+(\S+)\s+(\d+)\s+(\d+)\s*$/) {
				($file, $start, $end) = ($1, $2,$3);
			} elsif (/^\/\/!\s+(\d+)\s+(\d+)\s*$/) {
				($file, $start, $end) = ($deffile, $1, $2);
			} elsif (/^\/\/!\s+(\S+)\s+(\d+)\s*$/) {
				($file, $start, $end) = ($1, $2,$2);
			} elsif (/^\/\/!\s+(\d+)\s*$/) {
				($file, $start, $end) = ($deffile, $1, $1);
			}
			if ($file) {
				$inComment = 1;
				print map {"//! ".$_} @{getFile($file)}[$start-1..$end-1];
			}
			if (/^\/\/!\s+FILE\s+(\S+)\s*$/) {
				$deffile = $1;
			}
		}
	}
