/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <stdint.h>

#include "vars_set.h"

/*@ lemma strcmp_symm :
  @   \forall char *s1, *s2; strcmp(s1, s2) == 0 ==> strcmp(s2, s1) == 0;
  @
  @ lemma strcmp_trans :
  @   \forall char *s1, *s2, *s3;
  @      strcmp(s1, s2) == 0 && strcmp(s2, s3) == 0 ==> strcmp(s1, s3) == 0;
  @*/

/*@
  @ lemma strcmp_neq_symm : 
  @   \forall char *s1, *s2; strcmp(s1, s2) != 0 ==> strcmp(s2, s1) != 0;
  @
  @*/


/*@  lemma carrier2unique: 
  @  \forall nameSet *s1, *s2; s1->size == s2->size &&
  @      s1->vals != \null && s2->vals != \null &&
  @      (\forall integer i; 0 <= i < s2->size && 
  @         s2->vals[i] != \null ==>  (s1->vals[i] != \null &&
  @         strcmp(s1->vals[i], s2->vals[i]) == 0)) &&
  @           vals_unique(s1) ==> vals_unique(s2);
  @*/

/*@  lemma is_allocated_two{L,M}: 
  @  \forall size_t s, char* p;
  @     \at(__num_allocated,L) <= MAX_ALLOCS &&
  @     (\forall size_t i; 0 <= i <= \at(__num_allocated,L) ==> 
  @          \at(__allocated[i],L) == \at(__allocated[i],M)) &&
  @     (\forall size_t i, s; 0 <= i <= \at(__num_allocated,L) ==> 
  @          \valid{L}(\at(__allocated[i],L)+(0..s-1)) ==>
  @          \valid{M}(\at(__allocated[i],M)+(0..s-1))) &&
  @      \at(__num_allocated,L) == \at(__num_allocated,M) &&
  @      is_allocated_size{L}(p,s) ==> is_allocated_size{M}(p,s);
  @*/


/*@
  @ predicate subset_a{L}(nameSet* s1, int k, nameSet* s2) =
  @      \forall integer i; 0 <= i < k && s1->vals[i] != \null ==> 
  @         \exists integer j; 0 <= j < s2->size && 
  @            strcmp(s1->vals[i], s2->vals[j])==0;
  @
  @ predicate subset{L}(nameSet* s1, nameSet* s2) =
  @      subset_a{L}(s1, s1->size, s2);
  @*/

//############### helper functions ################


/*@ requires 0 < size && sizeof(Name)*size + sizeof(nameSet) <= UINT32_MAX;
  @   assigns __allocated[0..MAX_ALLOCS], __size_allocated, __num_allocated;
  @ behavior alloc_new:
  @   assumes is_allocable{Pre}((size_t)(sizeof(Name)*size+sizeof(nameSet)),(size_t)2);
  @   assigns __allocated[0..MAX_ALLOCS], __size_allocated, __num_allocated;
  @   ensures \result != \null;
  @   ensures \result->size == size;
  @   ensures valid_nameSet(\result);
  @   ensures \at(__allocated[__num_allocated-2],Post)==(char*)(\result->vals);
  @   ensures \at(__allocated[__num_allocated-1],Post)==(char*)\result;
  @   ensures \at(__num_allocated,Post) == \old(__num_allocated)+2;
  @   ensures \at(__size_allocated,Post) == \old(__size_allocated)+sizeof(Name)*size+sizeof(nameSet);
  @   ensures \forall char* a, size_t s; is_allocated_size{Pre}((char*)a, s) ==> 
  @                     \separated((char*)\result+(0..(sizeof(nameSet))-1),a+(0..s-1));
  @   ensures \forall char* a, size_t s; is_allocated_size{Pre}((char*)a, s) ==> 
  @                     \separated(\result->vals+(0..(\result->size)-1),a+(0..s-1));
  @   ensures \forall size_t j; 0 <= j < \result->size  ==> 
  @                      \result->vals[j]==\null;
  @   ensures allocation_footprint{Pre,Post}((size_t)(sizeof(Name)*size + sizeof(nameSet)),(size_t)2);
  @ behavior alloc_no: 
  @   assumes !is_allocable{Pre}((size_t)(sizeof(Name)*size+sizeof(nameSet)),(size_t)2);
  @   assigns __allocated[0..MAX_ALLOCS], __size_allocated, __num_allocated;
  @   ensures !is_allocable{Post}((size_t)(sizeof(Name)*size+sizeof(nameSet)),(size_t)2);
  @   ensures \at(__num_allocated,Pre) == \at(__num_allocated,Post);
  @   ensures \at(__size_allocated,Pre) == \at(__size_allocated,Post);
  @   ensures \result == \null;
  @   ensures allocation_footprint{Pre,Post}((size_t)0,(size_t)0);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
nameSet* createSetSize(size_t size) {
  char** newNames = calloc(size, sizeof(Name));
  if (newNames == (Name*)0) {
    return (nameSet*)0;
  };
  nameSet* ns = calloc(1,sizeof(nameSet));
  if (ns == (nameSet*)0) {
    free((char*)newNames);
    return (nameSet*)0;
  };
  
  ns->size = size;
  ns->vals = newNames;


  /*@ loop invariant 0 < ns->size && 0 <= i <= ns->size && ns != \null && ns->vals != \null;
    @ loop invariant \forall integer j;  0 <= j < i ==>
    @             ns->vals[j]==\null;
    @ loop invariant __num_allocated == \at(__num_allocated,Pre)+2;
    @ loop invariant __size_allocated == \at(__size_allocated,Pre)+sizeof(Name)*size+sizeof(nameSet);
    @ loop invariant __allocated[__num_allocated-2]==(char*)(ns->vals);
    @ loop invariant __allocated[__num_allocated-1]==(char*)ns;
    @ loop invariant \valid(ns) && is_allocated((char*)ns) &&
    @                positive_size(ns) && valid_vals(ns);
    @ loop invariant \separated(ns, ns->vals+(0..ns->size-1)) &&
    @                  \separated(ns, { ns->vals[j]  | 
    @                     integer j; 0 <= j < i && ns->vals[j]!=0 }) &&
    @                  \separated(ns->vals, { (ns->vals)[j]  | 
    @                     integer j; 0 <= j < i && ns->vals[j]!=0 });
    @ loop invariant \forall integer j; 
    @   0 <= j < i && ns->vals[j] != \null  ==> 
    @              (is_allocated(ns->vals[j])) &&
    @              valid_string(ns->vals[j]);
    @ loop invariant \forall integer k,j; 
    @   0 <= k < j < i && ns->vals != \null && 
    @   ns->vals[k]!=\null && ns->vals[j]!=\null ==>
    @     strcmp(ns->vals[k],ns->vals[j])!=0;
    @ loop invariant \forall char* a, size_t s; is_allocated_size{Pre}((char*)a, s) ==> 
    @                     \separated(ns->vals+(0..(ns->size)-1),a+(0..s-1));
    @ loop assigns i,ns->vals[0..sizeof(Name)*ns->size-1];
    @ loop variant sizeof(Name)*ns->size - i;
    @*/
  for (int i=0; i<ns->size; i++) {
    ns->vals[i]=NULL;
  }

  return ns;
}


/*@ requires valid_nameSet(s);
  @ assigns \nothing;
  @ ensures \result >= 0 ==> 0<= \result < s->size && s->vals[\result] == 0;
  @*/
int getFreePos(nameSet* s) {
  int i = 0;
  /*@ loop invariant valid_nameSet(s);
    @ loop invariant 0 <= i <= s->size;
    @ loop assigns i;
    @*/
  for (i=0; i < s->size; i++) {
    if (s->vals[i] == (Name)0) {
      return i;
    }
  }
  return -1;
}

/*@ requires valid_nameSet(s);
  @ requires valid_string(elem);
  @ assigns \nothing;
  @ ensures \result>=0 ==> 0 <= \result < s->size && s->vals[\result]!=0 &&
  @             strcmp(s->vals[\result], elem) == 0;
  @ ensures \result>=0 ==> \forall integer i; 0 <= i < s->size &&
  @             i!=\result && s->vals[i]!=0 ==>
  @             strcmp(s->vals[i],elem) != 0;
  @ ensures \result<0 ==> \forall integer i; 0 <= i < s->size &&
  @             s->vals[i]!=0 ==>
  @             strcmp(s->vals[i],elem) != 0;
  @ ensures \forall char *p; 
  @     \separated(\at(__allocated+(0..MAX_ALLOCS),Pre),
                   \at(p+(0..\block_length(\at(p,Pre))-1),Pre)) ==> 
                    \separated(\at(__allocated+(0..MAX_ALLOCS),Post),
                               \at(p+(0..\block_length(\at(p,Post))-1),Post));
  @*/
int isIn(nameSet* s, Name elem) {
  int i = 0;
  /*@ loop invariant valid_nameSet(s);
    @ loop invariant valid_string(elem);
    @ loop invariant 0 <= i <= s->size;
    @ loop invariant \forall integer j;  0 <= j < i &&
    @             s->vals[j]!=0 ==>
    @               strcmp(s->vals[j],elem) != 0;
    @ loop assigns i;
    @ loop variant s->size - i;
    @*/
  for (i=0; i < s->size; i++) {
    if (s->vals[i]!=0) {
      if (strcmp(s->vals[i], elem) == 0) {
        return i;
      }
    }
  }
  return -1;
}


//############### interface functions ################

/*@ requires valid_nameSet(s1);
  @ requires valid_nameSet(s2);
  @ requires 0 < s1->size + s2->size;
  @ requires 0 <= (s1->size + s2->size) * sizeof(Name)+sizeof(nameSet)
  @   <= UINT32_MAX;
  @ requires sizeof(Name)*(s1->size + s2->size) + sizeof(nameSet) <= UINT32_MAX;
  @ requires is_allocable((size_t)(sizeof(char*)*(s1->size + s2->size)+sizeof(nameSet)),(size_t)2);
  @ requires correct_allocation((size_t)0);
  @ assigns \result;
  @ assigns __allocated[0..MAX_ALLOCS], __size_allocated, __num_allocated;
  @ ensures \result!=0 ==> subset(s1,\result) && subset(s2,\result);
  @ ensures \result!=0 ==> valid_nameSet(\result);
  @ ensures \result!=0 ==> allocation_footprint{Pre,Post}((size_t)((s1->size + s2->size) * sizeof(Name)+sizeof(nameSet)),(size_t)2);
  @ ensures \result==0 ==> allocation_footprint{Pre,Post}((size_t)0,(size_t)0);
  @ ensures valid_nameSet(s1) && valid_nameSet(s2);
  @*/
nameSet* unionSet(nameSet* s1, nameSet* s2) {
  int i = 0;
  int j = 0;
  nameSet* ns = createSetSize(s1->size + s2->size);
  //@ assert s1->size + s2->size == ns->size;
  //@ assert valid_nameSet(s1) && valid_nameSet(s2);
  //@ assert ns != 0 ==> \separated(s1->vals,ns->vals);
  //@ assert ns != 0 ==> \separated(s2->vals,ns->vals);
  if (ns == 0) {
    return (nameSet*)0;
  };
  /*@ loop invariant valid_nameSet(s1);
    @ loop invariant valid_nameSet(s2);
    @ loop invariant ns != s1 && ns != s2 && correct_allocation((size_t)0);
    @ loop invariant ns->vals != s1->vals && ns->vals != s2->vals;
    @ loop invariant \separated(s1->vals,ns->vals);
    @ loop invariant \separated(s2->vals,ns->vals);
    @ loop invariant 0 <= i <= s1->size;
    @ loop invariant s1->size + s2->size == ns->size;
    @ loop invariant valid_nameSet(ns);
    @ loop invariant subset_a(s1,i,ns);
    @ loop invariant 0 <= j <= i <= ns->size;
    @ loop invariant \at(s1,LoopEntry) == \at(s1,Here) && \at(s2,LoopEntry) == \at(s2,Here);
    @ loop invariant \forall char *p, *q, sa, sb; 
    @            \at(\separated(p+(0..sa), q+(0..sb)), LoopEntry) ==>
    @            \at(\separated(p+(0..sa), q+(0..sb)), Here);
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s1->vals+(0..(s1->size)-1));
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s2->vals+(0..(s2->size)-1));
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s1);
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s2);
    @ loop invariant \forall char *p, *q, sa, sb; 
    @            \at(\separated(p+(0..sa), q+(0..sb)), LoopEntry) ==>
    @            \at(\separated(p+(0..sa), q+(0..sb)), Here);
    @ loop invariant \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> 
    @            \separated(s1->vals[j]+(0..\block_length(s1->vals[j])-1), ns->vals+(0..(ns->size)-1));
    @ loop invariant \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==>
    @            \separated(s2->vals[j]+(0..\block_length(s2->vals[j])-1), ns->vals+(0..(ns->size)-1));
    @ loop invariant \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> 
                 \separated(ns, s1->vals[j]+(0..\block_length(s1->vals[j])-1));
    @ loop invariant \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==>
                 \separated(ns, s2->vals[j]+(0..\block_length(s2->vals[j])-1));
    @ loop assigns ns->vals[0..ns->size-1];
    @ loop variant s1->size - i;
    @*/
  for (i=0; i < s1->size; i++) {
    //@ assert \valid(s1->vals);
    //@ assert \separated(s1->vals+(0..(s1->size)-1), ns->vals+(0..(ns->size)-1));
    //@ assert \separated(s2->vals+(0..(s2->size)-1), ns->vals+(0..(ns->size)-1));
    //@ assert \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> \separated(s1->vals[j]+(0..\block_length(s1->vals[j])-1), ns->vals+(0..(ns->size)-1));
    //@ assert \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==> \separated(s2->vals[j]+(0..\block_length(s2->vals[j])-1), ns->vals+(0..(ns->size)-1));
    //@ assert \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> \separated(ns, s1->vals[j]+(0..\block_length(s1->vals[j])-1));
    //@ assert \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==> \separated(ns, s2->vals[j]+(0..\block_length(s2->vals[j])-1));
    if (s1->vals[i] != NULL) {
      if (addSet(ns, s1->vals[i]) == NULL) {
        freeSetShallow(ns);
        return (nameSet*)0;
      }
    };
  }
  /*@ loop invariant valid_nameSet(s1) && valid_nameSet(s2);
    @ loop invariant valid_nameSet(ns) && ns != s1 && ns != s2;
    @ loop invariant subset(s1,ns) && subset_a(s2,i,ns);
    @ loop invariant valid_nameSet(ns);
    @ loop invariant 0 <= i <= s2->size;
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s1->vals+(0..(s1->size)-1));
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s2->vals+(0..(s1->size)-1));
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s1);
    @ loop invariant \separated(ns->vals+(0..(ns->size)-1), 
                                s2);
    @ loop invariant \forall char *p, *q, sa, sb; 
    @            \at(\separated(p+(0..sa), q+(0..sb)), LoopEntry) ==>
    @            \at(\separated(p+(0..sa), q+(0..sb)), Here);
    @ loop invariant \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> 
    @            \separated(s1->vals[j]+(0..\block_length(s1->vals[j])-1), ns->vals+(0..(ns->size)-1));
    @ loop invariant \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==>
    @            \separated(s2->vals[j]+(0..\block_length(s2->vals[j])-1), ns->vals+(0..(ns->size)-1));
    @ loop invariant \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> 
                 \separated(ns, s1->vals[j]+(0..\block_length(s1->vals[j])-1));
    @ loop invariant \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==>
                 \separated(ns, s2->vals[j]+(0..\block_length(s2->vals[j])-1));
    @ loop assigns ns->vals[0..ns->size-1];
    @ loop variant s2->size - i;
    @*/
  for (i=0; i < s2->size; i++) {
    //@ assert \separated(s1->vals+(0..(s1->size)-1), ns->vals+(0..(ns->size)-1));
    //@ assert \separated(s2->vals+(0..(s2->size)-1), ns->vals+(0..(ns->size)-1));
    //@ assert \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> \separated(s1->vals[j]+(0..\block_length(s1->vals[j])-1), ns->vals+(0..(ns->size)-1));
    //@ assert \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==> \separated(s2->vals[j]+(0..\block_length(s2->vals[j])-1), ns->vals+(0..(ns->size)-1));
    //@ assert \forall size_t j; 0 <= j < s1->size && s1->vals[j] != \null ==> \separated(ns, s1->vals[j]+(0..\block_length(s1->vals[j])-1));
    //@ assert \forall size_t j; 0 <= j < s2->size && s2->vals[j] != \null ==> \separated(ns, s2->vals[j]+(0..\block_length(s2->vals[j])-1));
    if (s2->vals[i] != (Name)0) {
      if (addSet(ns, s2->vals[i]) == NULL) {
        freeSetShallow(ns);
        return (nameSet*)0;
      }
    };
  }
  return ns; 
}

/*@ requires valid_string(elem);
  @ requires valid_nameSet(s);
  @ assigns s->vals[0..];
  @ ensures \result!=0 ==> valid_string(\result);
  @ ensures valid_nameSet(\at(s,Post));
  @ ensures \forall integer i; 0 <= i < s->size && 
  @                            s->vals[i]!=0 ==>
  @                            strcmp(s->vals[i], elem)!=0;
  @*/
Name minusSet(nameSet* s, Name elem) {
  int where = isIn(s, elem);
  if (where>=0) {
    Name res = s->vals[where];
    s->vals[where] = (Name)0;
    return res;
  } else {
    return (Name)0;
  }
}

/*@ requires valid_string(elem);
  @ requires is_allocated(elem);
  @ requires valid_nameSet(s);
  @ requires correct_allocation((size_t)0);
  @ requires \separated(s->vals+(0..s->size-1), elem+(0..\block_length(elem)-1));
  @ requires \separated(s, elem+(0..\block_length(elem)-1));
  @ requires \separated(__allocated+(0..MAX_ALLOCS), elem+(0..\block_length(elem)-1));
  @ assigns \result, s->vals[0..s->size-1];
  @ ensures \result!=0 ==> valid_nameSet(\result);
  @ ensures \result!=0 ==> \exists integer i; 0 <= i < s->size &&
  @                             strcmp(s->vals[i], elem)==0;
  @ ensures \result!=0 ==> \result == s;
  @ ensures \forall char *p, *q, s1, s2; 
  @            \at(\separated(p+(0..s1), q+(0..s2)), Pre) ==>
  @            \at(\separated(p+(0..s1), q+(0..s2)), Post);
  @*/
nameSet* addSet(nameSet* s, Name elem) {
  if (isIn(s, elem)<0) {
    int pos = getFreePos(s);
    if (pos < 0) {
      return (nameSet*)0;
    };
    //@ assert \separated(s, { s->vals[i]  | integer i; 0 <= i < s->size && s->vals[i]!=0 });
    //@ assert \separated(s->vals, elem);
    (s->vals)[pos]=elem;
    //@ assert \separated(s->vals, { (s->vals)[i]  | integer i; 0 <= i < s->size && s->vals[i]!=0 });
    //@ assert strcmp((s->vals)[pos], elem)==0;
  }
  return s;
}


/*@ requires sizeof(Name)*L_INITIAL_SIZE + sizeof(nameSet) <= UINT32_MAX;
  @ behavior alloc_new:
  @   assumes is_allocable((size_t)(sizeof(Name)*L_INITIAL_SIZE+sizeof(nameSet)),(size_t)2);
  @   assigns __allocated[0..MAX_ALLOCS], __size_allocated, __num_allocated,\result;
  @   ensures \at(__num_allocated,Post) == \old(__num_allocated)+2;
  @   ensures \at(__size_allocated,Post) == \old(__size_allocated)+sizeof(Name)*L_INITIAL_SIZE+sizeof(nameSet);
  @   ensures valid_nameSet(\result);
  @   ensures __allocated[__num_allocated-2]==(char*)(\result->vals);
  @   ensures __allocated[__num_allocated-1]==(char*)(\result);
  @ behavior alloc_no: 
  @   assumes !is_allocable{Pre}((size_t)(sizeof(Name)*L_INITIAL_SIZE+sizeof(nameSet)),(size_t)2);
  @   assigns __allocated[0..MAX_ALLOCS], __size_allocated, __num_allocated;
  @   ensures !is_allocable((size_t)(sizeof(Name)*L_INITIAL_SIZE+sizeof(nameSet)),(size_t)2);
  @   ensures \result == \null;
  @   ensures \at(__num_allocated,Pre) == \at(__num_allocated,Post);
  @   ensures \at(__size_allocated,Pre) == \at(__size_allocated,Post);
  @ complete behaviors;
  @ disjoint behaviors;
  @*/
nameSet* createSet() {
  return createSetSize(INITIAL_SIZE);
}

/*@ requires \valid(s) && is_allocated((char*)s) && is_allocated((char*)(s->vals));
  @ requires correct_allocation((size_t)0);
  @ assigns  __allocated[0..MAX_ALLOCS],__size_allocated, __num_allocated;
  @ ensures !is_allocated((char*)s);
  @ ensures !is_allocated((char*)(s->vals));
  @ ensures \forall size_t i; (0 <= i < \at(__num_allocated,Pre) && 
  @              \at(__allocated[i],Pre)!=(char*)s &&
  @              \at(__allocated[i],Pre)!=(char*)(s->vals)) ==> 
  @                 (\exists size_t j; 0 <= j < \at(__num_allocated,Post) && 
  @                  \at(__allocated[i],Pre) == \at(__allocated[j],Post));
  @*/
void freeSetShallow(nameSet* s) {
  //@ assert is_allocated((char*)s);
  //@ assert \separated(__allocated+(0..MAX_ALLOCS), (char*)s+(0..(sizeof(nameSet)-1)));
  //@ assert *s == \at(*s, Pre);
  //@ assert is_allocated((char*)(s->vals));
  //@ assert \valid(s);
  free(s->vals);
  //@ assert !is_allocated((char*)(s->vals));
  //@ assert is_allocated((char*)s);
  free(s);
  //@ assert !is_allocated((char*)(s->vals));
}

/*@ requires valid_nameSet(s) && correct_allocation((size_t)0);
  @ ensures !is_allocated((char*)s);
  @ ensures !is_allocated((char*)s->vals);
  @ ensures \forall int i; (0 <= i < s->size && s->vals[i]!=\null) ==> 
  @               !is_allocated(\old(s->vals[i]));
  @ assigns  __allocated[0..MAX_ALLOCS], __num_allocated, __size_allocated;
  @*/
void freeSetDeep(nameSet* s) {
  int i = 0;
  /*@ loop invariant \forall int j; (0 <= j < i && s->vals[j]!=\null) ==> 
    @                      !is_allocated(\at(s->vals[j],Pre));
    @ loop invariant \forall int j; (i <= j < s->size && (s->vals)[j]!=\null) ==>
    @                      is_allocated((s->vals)[j]);
    @ loop invariant 0 <= i <= s->size;
    @ loop invariant is_allocated((char*)s) && is_allocated((char*)(s->vals));
    @ loop invariant \valid(s) && \valid(s->vals+(0..s->size-1));
    @ loop invariant correct_allocation((size_t)0);
    @ loop assigns i,__allocated[0..MAX_ALLOCS],__num_allocated, __size_allocated;
    @ loop variant s->size - i;
    @*/
  for (i=0 ; i < s->size; i++) {
    if ((s->vals[i])!=NULL) {
      //@ assert is_allocated((s->vals)[i]);
      free(s->vals[i]);
    }
  }
  //@ assert is_allocated((char*)s) && is_allocated((char*)(s->vals));
  //@ assert correct_allocation((size_t)0);
  freeSetShallow(s);
}

/*@ requires sizeof(Name)*L_INITIAL_SIZE <= 2147483647 && correct_allocation((size_t)0);
  @ requires valid_string(elem) && is_allocated(elem);
  @ requires strlen(elem)+1 < UINT32_MAX+1;
  @ requires is_allocable((size_t)(sizeof(Name)*L_INITIAL_SIZE+sizeof(nameSet)),(size_t)2);
  @ requires \separated(__allocated+(0..MAX_ALLOCS), elem+(0..\block_length(elem)-1));
  @ assigns __allocated[0..MAX_ALLOCS], __size_allocated, __num_allocated,\result,\result->vals[0..];
  @ ensures \result!=0 ==> valid_nameSet(\result);
  @*/
nameSet *singletonSet(Name elem) {
        //@ assert is_allocated(elem);
	nameSet *res = createSet();
        if (res == NULL)
          return NULL;
        else {
          //@ assert valid_string(elem);
          //@ assert (char*)res != elem;
          //@ assert (char*)(res->vals) != elem;
          //@ assert valid_nameSet(res);
          //@ assert \separated(res->vals, elem);
          //@ assert \separated(res, elem);
          return addSet(res, elem);
        }
}

/*@ requires valid_nameSet(s1);
  @ requires valid_nameSet(s2);
  @ requires 0 <= s1->size + s2->size;
  @ requires 0 <= (s1->size + s2->size) * sizeof(Name)+sizeof(nameSet)
  @   <= UINT32_MAX;
  @ requires sizeof(Name)*(s1->size + s2->size) + sizeof(nameSet) <= UINT32_MAX;
  @ requires is_allocable((size_t)(sizeof(char*)*(s1->size + s2->size)+sizeof(nameSet)),(size_t)2);
  @ requires correct_allocation((size_t)0);
  @ ensures \result!=0 ==> subset(s1,\result) && subset(s2,\result);
  @ ensures \result!=0 ==> valid_nameSet(\result);
  @*/
//TODO
nameSet* unionSetFreeShallow(nameSet* s1, nameSet* s2) {
	nameSet *res = unionSet(s1, s2);
        //@ assert  \valid(s1) && is_allocated((char*)s1) && is_allocated((char*)(s1->vals));
        //@ assert  \valid(s2) && is_allocated((char*)s2) && is_allocated((char*)(s2->vals));
        //@ assert correct_allocation((size_t)0);
	freeSetShallow(s1);
	freeSetShallow(s2);
	return res;
}


