%{
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>
#include "checker.h"
#include "parserHelpers.h"
#include "y.tab.h"
	
void lexEcho(char *format, ...);
%}

sq_char				([\040-\046\050-\133\135-\176]|[\\]['\\])
unsigned_integer		[a-zA-Z]
general_function		[a-zA-Z]
single_quoted			"'"{sq_char}+"'"
real				[a-zA-Z]
integer				[a-zA-Z]
lower_word			[a-z][a-zA-Z0-9_]*
upper_word			[A-Z][a-zA-Z0-9_]*
rational			[a-zA-Z]
distinct_object			[a-zA-Z]
dollar_dollar_word		\$\${lower_word}
dollar_word			\${lower_word}
WS                              [ \t\n]+
comment                         %.*$

%option noyywrap
%option yylineno

%%
{WS}                            ;
{comment}                       {lexEcho("comment: [\"%s\"]", yytext);
}
"|"				{lexEcho("[|]");
					return VLINE;
}
"*"				{lexEcho("[*]");
					return STAR;
}
"+"				{lexEcho("[+]");
					return PLUS;
}
"!" 				{lexEcho("[!]");
					return FOR_ALL;
}
"?" 				{lexEcho("[?]");
					return THERE_EXISTS;
}
"~" 				{lexEcho("[~]");
					return NOT;
}
"&"				{lexEcho("[&]");
					return AND;
}
"<=>" 				{lexEcho("[<=>]");
					return DOUBLE_ARROW;
}
"=>"				{lexEcho("[=>]");
					return RIGHT_ARROW;
}
"<="				{lexEcho("[<=]");
					return LEFT_ARROW;
}
"<~>"				{lexEcho("[<~>]");
					return XOR;
}
"~|" 				{lexEcho("[~|]");
					return NOR;
}
"~&"				{lexEcho("[~&]");
					return NAND;
}
"!="				{lexEcho("[!=]");
					return NOT_EQUAL_SIGN;
}
"="				{lexEcho("[=]");
					return EQUAL_SIGN;
}
">"				{lexEcho("[>]");
					return ARROW;
}
"-->"				{lexEcho("[-->]");
					return GENTZEN_ARROW;
}
":="				{lexEcho("[:=]");
					return ASSIGN;
}
"^"				{lexEcho("[^]");
					return SYMBOL1;
}
"!>"				{lexEcho("[!>]");
					return SYMBOL2;
}
"?*"				{lexEcho("[?*]");
					return SYMBOL3;
}
"!!"				{lexEcho("[!]");
					return SYMBOL4;
}
"??"				{lexEcho("[??]");
					return SYMBOL5;
}
"thf"				{lexEcho("[thf]");
					return THF;
}
"fof"				{lexEcho("[fof]");
					return FOF;
}
"cnf"				{lexEcho("[cnf]");
					return CNF;
}
"axiom"				{lexEcho("[axiom]");
					return AXIOM;
}
"hypothesis"			{lexEcho("[hypothesis]");
					return HYPOTHESIS;
}
"definition"			{lexEcho("[definition]");
					return DEFINITION;
}
"assumption"			{lexEcho("[assumption]");
					return ASSUMPTION;
}
"lemma"				{lexEcho("[lemma]");
					return LEMMA;
}
"theorem"			{lexEcho("[theorem]");
					return THEOREM;
}
"conjecture"			{lexEcho("[conjecture]");
					return CONJECTURE;
}
"negated_conjecture"		{lexEcho("[negated_conjecture]");
					return NEGATED_CONJECTURE;
}
"plain"				{lexEcho("[plain]");
					return PLAIN;
}
"fi_domain"			{lexEcho("[fi_domain]");
					return FI_DOMAIN;
}
"fi_functors"			{lexEcho("[fi_functors]");
					return FI_FUNCTORS;
}
"fi_predicates"			{lexEcho("[fi_predicates]");
					return FI_PREDICATES;
}
"type"				{lexEcho("[type]");
					return TYPE;
}
"unknown"			{lexEcho("[unknown]");
					return UNKNOWN;
}
"$oType" 			{lexEcho("[$oType]");
					return DOLLAR_OTYPE;
}
"$o"				{lexEcho("[$o]");
					return DOLLAR_O;
}
"$iType"			{lexEcho("[$iType]");
					return DOLLAR_ITYPE;
}
"$i"				{lexEcho("[$i]");
					return DOLLAR_I;
}
"$tType"			{lexEcho("[$tType]");
					return DOLLAR_TTYPE;
}
"$real"				{lexEcho("[$real]");
					return DOLLAR_REAL;
}
"$rat"				{lexEcho("[$rat]");
					return DOLLAR_RAT;
}
"$int"				{lexEcho("[$int]");
					return DOLLAR_INT;
}
"$true"				{lexEcho("[$true]");
					return DOLLAR_TRUE;
}
"$false"			{lexEcho("[$false]");
					return DOLLAR_FALSE;
}
"$equal"			{lexEcho("[$equal]");
					return DOLLAR_EQUAL;
}
"inference"			{lexEcho("[inference]");
					return INFERENCE;
}
"introduced"			{lexEcho("[introduced]");
					return INTRODUCED;
}
"axiom_of_choice"		{lexEcho("[axiom_of_choice]");
					return AXIOM_OF_CHOICE;
}
"tautology"			{lexEcho("[tautology]");
					return TAUTOLOGY;
}
"theory"			{lexEcho("[theory]");
					return THEORY;
}
"equality"			{lexEcho("[equality]");
					return EQUALITY;
}
"ac"				{lexEcho("[ac]");
					return AC;
}
"creator"			{lexEcho("[creator]");
					return CREATOR;
}
"description"			{lexEcho("[description]");
					return DESCRIPTION;
}
"iquote"			{lexEcho("[iquote]");
					return IQUOTE;
}
"status"			{lexEcho("[status]");
					return STATUS;
}
"suc"				{lexEcho("[suc]");
					return SUC;
}
"unp"				{lexEcho("[unp]");
					return UNP;
}
"sap"				{lexEcho("[sap]");
					return SAP;
}
"esa"				{lexEcho("[esa]");
					return ESA;
}
"sat"				{lexEcho("[sat]");
					return SAT;
}
"fsa"				{lexEcho("[fsa]");
					return FSA;
}
"thm"				{lexEcho("[thm]");
					return THM;
}
"eqv"				{lexEcho("[eqv]");
					return EQV;
}
"tac"				{lexEcho("[tac]");
					return TAC;
}
"wec"				{lexEcho("[wec]");
					return WEC;
}
"eth"				{lexEcho("[eth]");
					return ETH;
}
"tau"				{lexEcho("[tau]");
					return TAU;
}
"wtc"				{lexEcho("[wtc]");
					return WTC;
}
"wth"				{lexEcho("[wth]");
					return WTH;
}
"cax"				{lexEcho("[cax]");
					return CAX;
}
"sca"				{lexEcho("[sca]");
					return SCA;
}
"tca"				{lexEcho("[tca]");
					return TCA;
}
"wca"				{lexEcho("[wca]");
					return WCA;
}
"cup"				{lexEcho("[cup]");
					return CUP;
}
"csp"				{lexEcho("[csp]");
					return CSP;
}
"ecs"				{lexEcho("[ecs]");
					return ECS;
}
"csa"				{lexEcho("[csa]");
					return CSA;
}
"cth"				{lexEcho("[cth]");
					return CTH;
}
"ceq"				{lexEcho("[ceq]");
					return CEQ;
}
"unc"				{lexEcho("[unc]");
					return UNC;
}
"wcc"				{lexEcho("[wcc]");
					return WCC;
}
"ect"				{lexEcho("[ect]");
					return ECT;
}
"fun"				{lexEcho("[fun]");
					return FUN;
}
"uns"				{lexEcho("[uns]");
					return UNS;
}
"wuc"				{lexEcho("[wuc]");
					return WUC;
}
"wct"				{lexEcho("[wct]");
					return WCT;
}
"scc"				{lexEcho("[scc]");
					return SCC;
}
"uca"				{lexEcho("[uca]");
					return UCA;
}
"noc"				{lexEcho("[noc]");
					return NOC;
}
"assumptions"			{lexEcho("[assumptions]");
					return ASSUMPTIONS;
}
"refutation"			{lexEcho("[refutation]");
					return REFUTATION;
}
"include"			{lexEcho("[include]");
					return INCLUDE;
}
"$thf"				{lexEcho("[$thf]");
					return DOLLAR_THF;
}
"$fof"				{lexEcho("[$fof]");
					return DOLLAR_FOF;
}
"$cnf"				{lexEcho("[$cnf]");
					return DOLLAR_CNF;
}
"$fot"				{lexEcho("[$fot]");
					return DOLLAR_FOT;
}
"var"			        {lexEcho("[var]");
					return VAR;
}
"tuple"			        {lexEcho("[tuple]");
					return TUPLE;
}
"proj1"			        {lexEcho("[proj1]");
					return PROJ1;
}
"proj2"			        {lexEcho("[proj2]");
					return PROJ2;
}
"in1"			        {lexEcho("[in1]");
					return IN1;
}
"in2"			        {lexEcho("[in2]");
					return IN2;
}
"case"			        {lexEcho("[case]");
					return CASE;
}
"existsI"		        {lexEcho("[existsI]");
					return EXISTSI;
}
"abstract"		        {lexEcho("[abstract]");
					return ABSTRACT;
}
"app"			        {lexEcho("[app]");
					return APP;
}
"lambda"			{lexEcho("[lambda]");
					return LAMBDA;
}
"exfalso"		        {lexEcho("[exfalso]");
					return EXFALSO;
}
{lower_word}                    {lexEcho("[lower_word:%s]",yytext);
                                        return lower_word;
}
{upper_word}                    {lexEcho("[upper_word:%s]",yytext);
                                        return upper_word;
}
{single_quoted}                 {lexEcho("[single_quoted:%s]",yytext);
                                        return single_quoted;
}
{dollar_dollar_word}            {lexEcho("[dollar_dollar_word:%s]",yytext);
                                        return dollar_dollar_word;
}
{dollar_word}                   {lexEcho("[dollar_word:%s]",yytext);
                                        return dollar_word;
}
.	                        {lexEcho("[\"%s\"]", yytext);
                                        return yytext[0];
}


%%

void lexEcho(char *format, ...) {
	va_list args;
	
	#ifdef LEX_DEBUG
		va_start(args, format);
		vfprintf(stderr, format, args);
		va_end(args);
	#endif
}
