/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include <sys/resource.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <assert.h>
#include <checker.h>
#include <envmap_base.h>
#include <printMessages.h>
#include <alloc.h>
#include <free.h>
#include <typechecker.h>
#include <checker.h>
#include "parserHelpers.h"
#define YYDEBUG 1
#include "y.tab.h"


extern FILE *yyin;
extern FILE *yyout;
extern char  *yychar;
extern YYSTYPE yyval;


// forward declarations of procedures that are mutually recursive
int updateTypeVariables(Type* type, envmap *env, int arity);
int updateTypeVariablesTerm(Term * term, envmap *env);

int waserror = 0;
int proof_parsing = 0;

void yyerror(char* s) {
  fprintf( stderr, "Error in parsing: %s\n", s );
  fprintf( stderr, "Wrong character is: %d\n", yychar );
  waserror=1;
}

void printUsage(char* pname) {
  printf("Please invoke the program as:\n\n");
  printf("> %s -F <filename>\n", pname);
  printf("where <filename> is the name of a file in TPTP format with\n");
  printf("a FOF formula, or as\n\n");
  printf("> %s -P <filename>\n", pname);
  printf("where <filename> is the name of a file in TPTP format with\n");
  printf("a FOF formula, and its proof in natural deduction form.\n");
}

int formulas(char* filename) {
  proof_parsing = 0;
  yyin = fopen(filename, "r");
  if(yyin == NULL) {
    perror("Fatal error opening input");
    return 1;
  }
  
  yyparse();
  if (!waserror) {
    envmap* res = yyval.emap;
    for (int i=0; i<res->size; i++) {
      _printType(res->vals[i]->mType);
      printf("%s", printBuffer);
      printf("\n");
    }
  }
  fclose(yyin); 
	
  return waserror;
}

int updateTypeVariablesCas(McasIn cas, envmap *env) {
  if (!updateTypeVariables(cas.type, env, 0))
    return 0;
  else
    return updateTypeVariablesTerm(cas.term, env);
}

int updateTypeVariablesTerm(Term * term, envmap *env) {
  switch (term->which) {
  case emVar:
    return 1;
  case emApp:
    if (!updateTypeVariablesTerm(term->mApp.term1, env))
      return 0;
    else
      return updateTypeVariablesTerm(term->mApp.term2, env);
  case emLam:
    if (!updateTypeVariables(term->mLam.type, env, 0))
      return 0;
    else
      return updateTypeVariablesTerm(term->mLam.term, env);
  case emWit:
    if (!updateTypeVariables(term->mWit.type, env, 0))
      return 0;
    else if (!updateTypeVariablesTerm(term->mWit.term1, env))
      return 0;
    else
      return (updateTypeVariablesTerm(term->mWit.term2, env));
  case emAbs:
    if (!updateTypeVariables(term->mAbs.type2, env, 0))
      return 0;
    else if (!updateTypeVariables(term->mAbs.type4, env, 0))
      return 0;
    else if (!updateTypeVariablesTerm(term->mAbs.term5, env))
      return 0;
    else
      return updateTypeVariablesTerm(term->mAbs.term6, env);
  case emTup:
    if (!updateTypeVariables(term->mTup.type, env, 0))
      return 0;
    else if (!updateTypeVariablesTerm(term->mTup.term1, env))
      return 0;
    else
      return (updateTypeVariablesTerm(term->mTup.term2, env));
  case emPi1:
    return (updateTypeVariablesTerm(term->mPi1.term, env));
  case emPi2:
    return (updateTypeVariablesTerm(term->mPi2.term, env));
  case emIn1:
    if (!updateTypeVariables(term->mIn1.type, env, 0))
      return 0;
    else
      return updateTypeVariablesTerm(term->mIn1.term, env);
  case emIn2:
    if (!updateTypeVariables(term->mIn2.type, env, 0))
      return 0;
    else
      return updateTypeVariablesTerm(term->mIn2.term, env);
  case emCas:
    if (!updateTypeVariablesTerm(term->mCas.term, env))
      return 0;
    else if (!updateTypeVariablesCas(term->mCas.casIn1, env))
      return 0;
    else
      return updateTypeVariablesCas(term->mCas.casIn1, env);
  case emEps:
    if (!updateTypeVariables(term->mEps.type, env, 0))
      return 0;
    else
      return updateTypeVariablesTerm(term->mEps.term, env);
  default:
    return 0; //update failed
  }
}

Kind* createArity(int arity) {
  if (arity<0) return NULL;
  if (arity==0) {
    Kind* knd = allocKind();
    if (knd==NULL) return NULL;
    knd->which = eKstar;
    return knd;
  }
  Kind* kndrest = createArity(arity-1);
  if (kndrest==NULL) return NULL;
  Type* type = allocType();
  if (type==NULL) {
    freeKindDeep(kndrest); return NULL;
  }
  Name name = malloc(2);
  if (name==NULL) {
    freeKindDeep(kndrest); freeTypeDeep(type); return NULL;
  }
  strcpy(name,"o");
  type->which = etVar;
  type->tVar.name = name;
  Kind* res = allocKind();
  if (res==NULL) {
    freeKindDeep(kndrest); freeTypeDeep(type);
    free(name);
    return NULL;
  }
  res->which = eKpi;
  res->kPi.name = name;
  res->kPi.type = type;
  res->kPi.kind = kndrest;
  return res;
}

int updateTypeVariables(Type* type, envmap *env, int arity) {
  switch (type->which) {
  case etVar: {
    if (envmap_lookup(*env, type->tVar.name)==NULL) {
      Kind* knd = createArity(arity);
      if (knd==NULL) return 0;
      Name nname = makeName(type->tVar.name);
      if (nname==NULL) {
        freeKindDeep(knd);
        return 0;
      }
      Any* any = makeAny(anyOfKind(knd));
      if (any==NULL) {
        freeKindDeep(knd);
        freeName(nname);
        return 0;
      }
      if (envmap_insert(env, nname, *any)==NULL) {
        freeKindDeep(knd);
        freeName(nname);
        freeAny(any);
        return 0;
      };
    };
  };
    break;
  case etAll:
    if (!updateTypeVariables(type->tAll.type1, env, 0))
      return 0;
    else
      return updateTypeVariables(type->tAll.type2, env, 0);
  case etApp:
    if (!updateTypeVariables(type->tApp.type, env, arity+1))
      return 0;
    else
      return updateTypeVariablesTerm(type->tApp.term, env);
  case etExi:
    if (!updateTypeVariables(type->tExi.type1, env, 0))
      return 0;
    else
      return updateTypeVariables(type->tExi.type2, env, 0);
  case etAnd:
    if (!updateTypeVariables(type->tAnd.type1, env, 0))
      return 0;
    else
      return updateTypeVariables(type->tAnd.type2, env, 0);
  case etOr:
    if (!updateTypeVariables(type->tOr.type1, env, 0))
      return 0;
    else
      return updateTypeVariables(type->tOr.type2, env, 0);
  case etBot:
    return 1;
  default:
    return 0; //update failed
  }
}

int typecheckFormula(Term* term, Type* type) {
  // create env
  envmap env = envmap_new();
  // create Kind for "o"
  Kind* kindo = allocKind();
  if (kindo==NULL) return false;
  kindo->which = eKstar;
  Any* kindoany = allocAny();
  if (kindoany==NULL) return false;
  kindoany->which = eAnyKind;
  kindoany->mKind = kindo;
  // insert the Kind to env
  if (envmap_insert(&env, "o", *kindoany)) return false;
  if (!updateTypeVariables(type, &env, 0)) {
    printf("Typechecking aborted\n");
    return false;
  }
  //typecheck
  if (checkTerm(env, term, type)) {
    printf("%s\n", errorBuffer);
    printf("Typechecking succeeded\n");
    return true;
  } else {
    printf("%s\n", errorBuffer);
    printf("Typechecking failed\n");
    return true;
  }
}

int proofs(char* filename) {
  proof_parsing = 1;
  yyin = fopen(filename, "r");
  if(yyin == NULL) {
    perror("Fatal error opening input");
    return 1;
  }
  
  yyparse();
  if (!waserror) {
    envmap* res = yyval.emap;
    printf("size=%d\n", res->size);
    Any* type = envmap_lookup(*res, "f");
    Any* term = envmap_lookup(*res, "t");
    _printType(type->mType);
    printf("%s", printBuffer);
    printf(" : \n        ");
    printBuffer[0]=0;
    _printTerm(term->mTerm);
    printf("%s", printBuffer);
    printf("\n");
    printBuffer[0]=0;
    typecheckFormula(term->mTerm, type->mType);
  }
  fclose(yyin); 
	
  return waserror;
}


int main(int argc, char *argv[]) {

  char* opts = "F:P:";
  
  int opt = getopt(argc, argv, opts);
  switch (opt) {
    case 'F':
      exit(formulas(optarg));
    case 'P':
      exit(proofs(optarg));
    default:
      printUsage(argv[0]);
      exit(-1);
    }
}
