/****************************************************************************
 * Copyright (C) 2016 by University of Warsaw                               *
 *                                                                          *
 * This file is part of IntuitionTC.                                        *
 *                                                                          *
 ****************************************************************************/
#include <string.h>
#include <stdio.h>
#include "parserHelpers.h"
#include "checker.h"
#include "alloc.h"
#include "y.tab.h"

extern int yyleng;
extern char yytext[];
int proof_parsing;

//TODO: review memory management

Type* fillArgumentsOfConnectiveType(Type* res, Type* arg1, Type* arg2, int normal) {
  Type* copyarg2 = arg2; //without the copy etAnd and etOr break for
                         //unknown reason
  switch (res->which) {
  case etVar:
    if (arg1->which!=etVar) {
      printf("Var can be created only from var\n");
      return NULL;
    }
    res->tVar.name=arg1->tVar.name;
    return res;
  case etAll:
    if (normal) {
      if (arg2->which!=etVar) {
        printf("Forall in fillArgumentsOfConnectiveType with no name\n");
      }
      res->tAll.name=arg2->tVar.name;
      Type* narg2 = allocType();
      narg2->which=etVar;
      narg2->tVar.name=malloc(2);
      strcpy(narg2->tVar.name,"o");
      res->tAll.type1=narg2;
      res->tAll.type2=arg1;
    } else {
      res->tAll.name="_";
      res->tAll.type1=arg1;
      res->tAll.type2=arg2;
    }
    return res;
  case etExi:
    if (arg2->which!=etVar) {
      printf("Exists in fillArgumentsOfConnectiveType with no name\n");
    }
    res->tExi.name=arg2->tVar.name;
    Type* narg2 = allocType();
    narg2->which=etVar;
    narg2->tVar.name=malloc(2);
    strcpy(narg2->tVar.name,"o");
    res->tExi.type1=narg2;
    res->tExi.type2=arg1;
    return res;        
  case etAnd:
    (res->tAnd).type1=arg1;
    (res->tAnd).type2=copyarg2;
    return res;
  case etOr:
    res->tOr.type1=arg1;
    res->tOr.type2=copyarg2;
    return res;
  case etApp:
    printf("Unhandled case %d in fillArgumentsOfConnectiveType\n", res->which);
    return NULL;
  case etBot:
    return res;
  default:
    printf("No such type kind in fillArgumentsOfConnectiveType\n");
    break;
  }
}

Any* createBasicBinary(eType kind, Any* arg1, Any* arg2) {
  Type* t = allocType();
  if (t==NULL) {
      printf("Error in createBasicBinary (t)\n");
      return NULL;
  }
  t->which=kind;
  if (fillArgumentsOfConnectiveType(t, arg1->mType, 
                                    arg2->mType,1)==NULL) {
    free(t);
    printf("Error in createBasicBinary fill (t)\n");
    return NULL;
  }
  Any* a = allocAny();
  if (a==NULL) {
    free(t); 
    printf("Error in createBasicBinary (a, eConnNor)\n");
    return NULL;
  }
  a->mType=t;
  a->which=eAnyType;
  return a;
}

Any* createNegated(eType res, Any* arg1, Any* arg2) {
  Any* a = createBasicBinary(res, arg1, arg2);
  if (a==NULL) {
    printf("Error in createNegated (a)\n");
    return NULL;
  }
  Type* t = a->mType;
  YYSTYPE tp;
  tp.kindof = eConnNot;
  Any* b = composeUnaryConnective(tp, a);
  free(a);
  if (b==NULL) {
    free(t);
    printf("Error in createNegated (b)\n");
    return NULL;
  }
  return b;
}

Any* composeBinaryConnective(YYSTYPE res, Any* arg1, Any* arg2) {
  if (arg1==NULL || arg2==NULL) {
    printf("NULL argument in composeBinaryConnective\n");
    return NULL;
  }
  if (arg1->which!=eAnyType || arg2->which!=eAnyType) {
    printf("Arguments are not types in composeBinaryConnective\n");
    return NULL;
  }
  if (arg1->mType==NULL || arg2->mType==NULL) {
    printf("Null type in the argument of composeBinaryConnective\n");
    return NULL;
  }

  switch (res.kindof) {
  case eConnLeftArrow: {
    Any *tmp = arg1;
    arg1 = arg2;
    arg2 = tmp; }
  case eConnRightArrow: {
    Type* t = allocType();
    if (t==NULL) {
      printf("Error in composeBinaryConnective (t)\n");
      return NULL;
    }
    t->which=etAll;
    t->tAll.name=NULL;
    Any* a = allocAny();
    if (a==NULL) {
      printf("Error in composeBinaryConnective (a)\n");
      return NULL;
    }
    a->mType=t;
    a->which=eAnyType;
    if (fillArgumentsOfConnectiveType(t, arg1->mType,
                                      arg2->mType,0)!=NULL) {
      return a;
    } else {
      free(a); free(t);
      printf("Error in composeBinaryConnective\n");
      return NULL;
    }
    break;
  }
  case eConnDoubleArrow: {
    Type* t = allocType();
    if (t==NULL) {
      printf("Error in composeBinaryConnective (t, eConnDoubleArrow)\n");
      return NULL;
    }
    t->which=etAll;
    t->tAll.name=NULL;
    if (fillArgumentsOfConnectiveType(t, arg1->mType,
                                      arg2->mType,0)==NULL) {
      free(t);
      return NULL;
    }
    Type* tt = allocType();
    if (tt==NULL) {
      free(t);
      printf("Error in composeBinaryConnective (tt, eConnDoubleArrow)\n");
      return NULL;
    }
    tt->which=etAll;
    tt->tAll.name=NULL;
    if (fillArgumentsOfConnectiveType(tt, arg2->mType,
                                      arg1->mType,0)==NULL) {
      free(t); free(tt);
      printf("Error in composeBinaryConnective fill (tt, eConnDoubleArrow)\n");
      return NULL;
    }
    Type* ttt = allocType();
    if (ttt==NULL) {
      free(t); free(tt);
      printf("Error in composeBinaryConnective (ttt, eConnDoubleArrow)\n");
      return NULL;
    }
    ttt->which=etAnd;
    if (fillArgumentsOfConnectiveType(ttt, t, tt , 1)==NULL) {
      free(t); free(tt);
      printf("Error in composeBinaryConnective fill (ttt, eConnDoubleArrow)\n");
      return NULL;
    }

    Any* a = allocAny();
    if (a==NULL) {
      printf("Error in composeBinaryConnective (a, eConnDoubleArrow)\n");
      return NULL;
    }
    a->mType=ttt;

    a->which=eAnyType;
    return a;
  }
  case eConnNor: {
    return createNegated(etOr, arg1, arg2);
  }
  case eConnNand: {
    return createNegated(etAnd, arg1, arg2);
  }
  case eConnOr: {
    return createBasicBinary(etOr, arg1, arg2);
  } 
  case eAnyTerm:
  case eAnyKind:
  case eAnyName:
  case eAnyBind:
    printf("Non-binary connective in composeBinaryConnective\n");
    return NULL;
  default:
    printf("No such any kind in composeBinaryConnective\n");
    return NULL;
  }
  return NULL;
}

Any* composeUnaryConnective(YYSTYPE res, Any* arg) {
  if (arg==NULL) {
    printf("Null arg in composeUnaryConnective\n");
    return NULL;
  }
  if (arg->mType==NULL) {
    printf("Null type in the argument of composeUnaryConnective\n");
    return NULL;
  }
  if (arg->which!=eAnyType) {
    printf("Argument is not a type in composeUnaryConnective\n");
    return NULL;
  }
  switch (res.kindof) {
  case eConnNot: {
    Type* t = allocType();
    t->which=etBot;
    if (t==NULL) {
      printf("Error in composeUnaryConnective (t, eConnNot)\n");
      return NULL;
    }
    Type* tt = allocType();
    if (tt==NULL) {
      free(t);
      printf("Error in composeUnaryConnective (tt, eConnNot)\n");
      return NULL;
    }
    tt->which=etAll;
    if (fillArgumentsOfConnectiveType(tt, arg->mType, t,0)==NULL) {
      free(t); free(tt);
      printf("Error in composeBinaryConnective fill (tt, eConnNot)\n");
      return NULL;
    }
    Any* a = allocAny();
    if (a==NULL) {
      free(t); free(tt);
      printf("Error in composeUnaryConnective (a, eConnNot)\n");
      return NULL;
    }
    a->mType=tt;
    a->which=eAnyType;
    return a;
  }
  default:
    printf("No such kind in composeUnaryConnective\n");
    return NULL;
  }
}

Any* composeAnyType(eType tp, Any* first, Any* second) {
  if (first==NULL || second==NULL) {
    printf("Some argument to composeAnyType is NULL\n");
    return NULL;
  }
  if (first->which!=eAnyType && second->which!=eAnyType) {
    printf("Non type arguments in composeAnyType\n");
    return NULL;
  }
  Type* t = allocType();
  if (t==NULL) return NULL;
  t->which = tp;
  switch (tp) {
  case etAnd:
    t->tAnd.type1 = first->mType;
    t->tAnd.type2 = second->mType;
    break;
  case etOr:
    t->tOr.type1 = first->mType;
    t->tOr.type2 = second->mType;
    break;
  default:
    printf("Unhandled case in composeAnyType");
    return NULL;
  }
  Any* a = allocAny();
  if (a==NULL) {
    free(t);
    return NULL;
  }
  a->which = eAnyType;
  a->mType = t;
  return a;
}

void freeQChain(Type* start) {
  if (start!=NULL) {
    switch (start->which) {
    case etAll:
      if (start->tAll.name!=NULL) free(start->tAll.name);
      freeQChain(start->tAll.type1);
      freeQChain(start->tAll.type2);
      free(start);
      break;
    case etExi:
      if (start->tExi.name!=NULL) free(start->tExi.name);
      freeQChain(start->tExi.type1);
      freeQChain(start->tExi.type2);
      free(start);
      break;
    default:
      printf("Unhandled freeing of quantifier chain\n");
      return;
    }
  }
}

Any* composeQuantifier(eAnyH tp, nameSet* ns, Any* formula) {
  if (ns==NULL || formula==NULL) {
    printf("Error in composeQuantifier, null arguments\n");
    return NULL;
  }
  eType rtp;
  switch (tp) {
  case  eConnExists:
    rtp = etExi;
    break;
  case eConnForall:
    rtp = etAll;
    break;
  default:
    printf("Unhandled kind of quantifier in composeQuantifier\n");
    return NULL;
  }
  Type* start = NULL;
  Type* oldtp = NULL;
  Type* ntp = NULL;
  Type* vartp = allocType();
  if (vartp==NULL) {
    printf("Cannot alloc var Type in composeQuantifier\n");
    return NULL;
  }
  vartp->which=etVar;

  /* the variables enter the set in the direction opposite to the
     one in the parsed text so we have to handle them this way */
  for (int i=ns->size-1; i>=0; i--) {
    if (ns->vals[i]!=NULL) {
      ntp = allocType();
      if (ntp==NULL) {
        printf("Cannot alloc new Type in composeQuantifier\n");
        return NULL;
      }
      ntp->which=rtp;
      if (oldtp!=NULL) {
        if (fillArgumentsOfConnectiveType(oldtp,ntp,vartp,1)==NULL) {
          free(ntp);
          freeQChain(start);
          printf("Cannot fill arguments in composeQuantifier\n");
          return NULL;
        }
      }
      vartp->tVar.name=ns->vals[i];
      if (start==NULL) start=ntp;
      oldtp=ntp;
      oldtp->tAll.type1=NULL;
      oldtp->tAll.type2=NULL;
      oldtp->tExi.type1=NULL;
      oldtp->tExi.type2=NULL;
    }
  }
  if (fillArgumentsOfConnectiveType(oldtp,formula->mType,vartp,1)==NULL) {
    free(ntp);
    freeQChain(start);
    printf("Cannot fill arguments in composeQuantifier (2)\n");
    return NULL;
  }
  free(vartp);
  Any *res = allocAny();
  if (res==NULL) {
    freeQChain(start);
    printf("Cannot alloc Any result in composeQuantifier\n");
    return NULL;
  }
  res->which=eAnyType;
  res->mType=start;
  return res;
}

Name createWord(YYSTYPE *res) {
  Name s = malloc(yyleng+1);
  if (s==NULL) {
    printf("Error in createWord\n");
    return NULL;
  }
  strncpy(s, yytext, yyleng);
  s[yyleng]=0;
  res->name.which = eAnyNameH;
  res->name.name = s;
  return s;
}


Any* composeTermVariable(string arg) {
  Term* t = allocTerm();
  if (t==NULL) {
      printf("Error in composeTermVariable\n");
      return NULL;
  }
  t->which = emVar;
  t->mVar.name = arg.name;
  Any* a = allocAny();
  if (a==NULL) {
    free(t);
    printf("Error in composeTermVariable (a)\n");
    return NULL;
  }
  a->mTerm=t;
  a->which=eAnyTerm;
  return a;
}

Any* composeTypeVariable(string arg) {
  Type* t = allocType();
  if (t==NULL) {
      printf("Error in composeTypeVariable\n");
      return NULL;
  }
  t->which = etVar;
  t->tVar.name = arg.name;
  Any* a = allocAny();
  if (a==NULL) {
    free(t);
    printf("Error in composeTypeVariable (a)\n");
    return NULL;
  }
  a->mType=t;
  a->which=eAnyType;
  return a;
}

void freeArgumentsChain(Type* oldtt,Type* start) {
  while (oldtt!=start) {
    Type* tmp = oldtt->tApp.type;
    free(oldtt);
    oldtt=tmp;
  };
}

Any* composeFunctorWithArguments(string name, envmap *arguments) {
  if (arguments == NULL) {
    printf("Error in composeFunctorWithArguments (arguments are NULL)\n");
    return NULL;
  }
  Any* a = composeTypeVariable(name);
  if (a==NULL) {
    printf("Error in composeFunctorWithArguments (a)\n");
    return NULL;
  }
  Type* start = a->mType;
  Type* oldtt = start;
  for (int i = 0 ; i<arguments->size; i++) {
    Type* tt = allocType();
    if (tt==NULL) {
      freeArgumentsChain(oldtt,start);
      free(a->mType); free(a);
      printf("Error in composeFunctorWithArguments (tt)\n");
      return NULL;
    }
    tt->which = etApp;
    tt->tApp.type = oldtt;
    tt->tApp.term = (arguments->vals[i])->mTerm;
    oldtt=tt;
  }
  a->mType=oldtt;
  return a;
}


Term* typeToTermRaw(Type* mtype) {
  switch (mtype->which) {
  case etApp: {
    Term* oprtr = typeToTermRaw(mtype->tApp.type);
    Term* oprnd = mtype->tApp.term;
    Term* res = allocTerm();
    if (res==NULL) {
      free(mtype);
      return NULL;
    }
    free(mtype);
    res->which=emApp;
    res->mApp.term1=oprtr;
    res->mApp.term2=oprnd;
    return res;
  }
  case etVar: {
    Term* res = allocTerm();
    if (res==NULL) {
      return NULL;
    }
    res->which=emVar;
    res->mVar.name=mtype->tVar.name;
    free(mtype);
    return res;
  }
  default:
    printf("Unhandled case %d in typeToTermRaw\n", mtype->which);
    return NULL;
  }
}

Any* typeToTerm(Any* mtype) {
  if (mtype==NULL) {
    printf("NULL argument to typeToTerm\n");
    return NULL;
  }
  if (mtype->mType==NULL) {
    printf("NULL Type in the argument to typeToTerm\n");
    return NULL;
  }
  Term* term = typeToTermRaw(mtype->mType);
  if (term==NULL) {
    printf("Error in typeToTerm\n");
    return NULL;
  }
  mtype->which=eAnyTerm;
  mtype->mTerm=term;
  return mtype;
}

//-----------------------------------------------------
//-------- PROOF TERMS CREATION -----------------------
//-----------------------------------------------------
Any* createExFalso(Any* term, Any* type) {
  // check if all is OK
  if (term==NULL || type==NULL) return NULL;
  if (term->which!=eAnyTerm) return NULL;
  if (type->which!=eAnyType) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  rterm->which = emEps;
  rterm->mEps.type=type->mType;
  rterm->mEps.term=term->mTerm;
  // pack it in Any type
  Any* res = term;
  res->mTerm=rterm;
  free(type); // we reclaim memory here
  return res;
}

Any* createLambda(string vname, Any* type, Any* term) {
  // check if all is OK
  if (term==NULL || type==NULL) return NULL;
  if (term->which!=eAnyTerm) return NULL;
  if (type->which!=eAnyType) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  rterm->which = emLam;
  rterm->mLam.name=vname.name;
  rterm->mLam.type=type->mType;
  rterm->mLam.term=term->mTerm;
  // pack it in Any type
  Any* res = term;
  res->mTerm=rterm;
  free(type); // we reclaim memory here
  return res;
}

Any* createApp(Any* term1, Any* term2) {
  // check if all is OK
  if (term1==NULL || term2==NULL) return NULL;
  if (term1->which!=eAnyTerm) return NULL;
  if (term2->which!=eAnyTerm) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  rterm->which = emApp;
  rterm->mApp.term1=term1->mTerm;
  rterm->mApp.term2=term2->mTerm;
  // pack it in Any type
  Any* res = term1;
  res->mTerm=rterm;
  free(term2); // we reclaim memory here
  return res;
}

Any* createAbstract(string name1, Any* type2, string name3,
                    Any* type4, Any* term5, Any* term6) {
  // check if all is OK
  if (type2==NULL || type4==NULL ||
      term5==NULL || term6==NULL) return NULL;
  if (term5->which!=eAnyTerm) return NULL;
  if (term6->which!=eAnyTerm) return NULL;
  if (type2->which!=eAnyType) return NULL;
  if (type4->which!=eAnyType) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  rterm->which = emAbs;
  rterm->mAbs.name1 = name1.name;
  rterm->mAbs.type2 = type2->mType;
  rterm->mAbs.name3 = name3.name;
  rterm->mAbs.type4 = type4->mType;
  rterm->mAbs.term5 = term5->mTerm;
  rterm->mAbs.term6 = term6->mTerm;
  // pack it in Any type
  Any* res = term5;
  res->mTerm=rterm;
  free(type2); // we reclaim memory here
  free(type4); // we reclaim memory here
  free(term6); // we reclaim memory here
  return res;
}

Any* createExists(Any* type, Any* term1, Any* term2) {
  // check if all is OK
  if (term1==NULL || term2==NULL || type==NULL) return NULL;
  if (type->which!=eAnyType) return NULL;
  if (term1->which!=eAnyTerm) return NULL;
  if (term2->which!=eAnyTerm) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  rterm->which = emWit;
  rterm->mWit.type=type->mType;
  rterm->mWit.term1=term1->mTerm;
  rterm->mWit.term2=term2->mTerm;
  // pack it in Any type
  Any* res = term1;
  res->mTerm=rterm;
  free(term2); // we reclaim memory here
  free(type);  // we reclaim memory here
  return res;

}

Any* createCase(Any* term, McasIn* case1, McasIn* case2) {
  // check if all is OK
  if (case1==NULL || case2==NULL) return NULL;
  if (term->which!=eAnyTerm) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  rterm->which = emCas;
  rterm->mCas.term=term->mTerm;
  rterm->mCas.casIn1.name=case1->name;
  rterm->mCas.casIn1.type=case1->type;
  rterm->mCas.casIn1.term=case1->term;
  rterm->mCas.casIn2.name=case2->name;
  rterm->mCas.casIn2.type=case2->type;
  rterm->mCas.casIn2.term=case2->term;
  // pack it in Any type
  Any* res = term;
  res->mTerm=rterm;
  free(case1); // we reclaim memory here
  free(case2); // we reclaim memory here
  return res;
}

Any* createIn(Any* term, Any* type, int which) {
  // check if all is OK
  if (term==NULL || type==NULL) return NULL;
  if (term->which!=eAnyTerm) return NULL;
  if (type->which!=eAnyType) return NULL;
  if (which<1 || which>2) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  if (which==1) {
    rterm->which = emIn1;
    rterm->mIn1.type=type->mType;
    rterm->mIn1.term=term->mTerm;
  } else {
    rterm->which = emIn2;
    rterm->mIn2.type=type->mType;
    rterm->mIn2.term=term->mTerm;
  }
  // pack it in Any type
  Any* res = term;
  res->mTerm=rterm;
  free(type); // we reclaim memory here
  return res;
}

Any* createProj(Any* term, int which) {
  // check if all is OK
  if (term==NULL) return NULL;
  if (term->which!=eAnyTerm) return NULL;
  if (which<1 || which>2) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  if (which==1) {
    rterm->which = emPi1;
    rterm->mPi1.term=term->mTerm;
  } else {
    rterm->which = emPi2;
    rterm->mPi2.term=term->mTerm;
  }
  // pack it in Any type
  Any* res = term;
  res->mTerm=rterm; //nothing to reclaim
  return res;

}

Any* createTuple(Any* type, Any* term1, Any* term2) {
  // check if all is OK
  if (term1==NULL || term2==NULL || type==NULL) return NULL;
  if (type->which!=eAnyType) return NULL;
  if (term1->which!=eAnyTerm) return NULL;
  if (term2->which!=eAnyTerm) return NULL;
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  rterm->which = emTup;
  rterm->mTup.type=type->mType;
  rterm->mTup.term1=term1->mTerm;
  rterm->mTup.term2=term2->mTerm;
  // pack it in Any type
  Any* res = term1;
  res->mTerm=rterm;
  free(type); // we reclaim memory here
  free(term2); // we reclaim memory here
  return res;
}

Any* createTermVar(string vname) {
  // nothing to check to begin with
  // create new term
  Term* rterm = malloc(sizeof(Term));
  if (rterm==NULL) return NULL;
  Any* res = malloc(sizeof(Any));
  if (res==NULL) {
    free(rterm);
    return NULL;
  }
  rterm->which = emVar;
  rterm->mVar.name=vname.name;
  // pack it in Any type
  res->which=eAnyTerm;
  res->mTerm=rterm; //nothing to reclaim here
  return res;
}

McasIn* createCaseTerm(string name, Any* type, Any* term) {
  // check if all is OK
  if (term==NULL || type==NULL) return NULL;
  if (type->which!=eAnyType) return NULL;
  if (term->which!=eAnyTerm) return NULL;
  // create new case container
  McasIn* mcas = malloc(sizeof(McasIn));
  if (mcas==NULL) return NULL;
  mcas->name=name.name;
  mcas->type=type->mType;
  mcas->term=term->mTerm;
  free(type); // we reclaim memory here
  free(term); // we reclaim memory here
  return mcas;

}


Name getFreshName(envmap * env) {
  Name buf = malloc(11); // 10 digits of MAX_INT
  if (buf==NULL) {
    return NULL;
  }
  for (int i=0; i<env->size+1; i++) {
    snprintf(buf, 11, "o%d", i);
    if (envmap_lookup(*env, buf)==NULL) {
      return buf;
    }
  }
}
