%{
#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include "checker.h"
#include "parserHelpers.h"
#include "alloc.h"
#include "vars_set.h"

#define YYSTACKSIZE 20000
#define YYMAXDEPTH  20000
  //#define YYDEBUG 1

extern int yyleng;
extern char yytext[];

extern int yylex (void);
extern void yyerror(char* s);
%}

%token VLINE STAR PLUS FOR_ALL THERE_EXISTS NOT AND DOUBLE_ARROW RIGHT_ARROW
%token LEFT_ARROW XOR NOR NAND EQUAL_SIGN NOT_EQUAL_SIGN ARROW GENTZEN_ARROW
%token ASSIGN SYMBOL1 SYMBOL2 SYMBOL3 SYMBOL4 SYMBOL5

%token THF FOF CNF AXIOM HYPOTHESIS DEFINITION ASSUMPTION LEMMA THEOREM 
%token CONJECTURE NEGATED_CONJECTURE PLAIN FI_DOMAIN FI_FUNCTORS FI_PREDICATES
%token TYPE UNKNOWN DOLLAR_OTYPE DOLLAR_O DOLLAR_ITYPE DOLLAR_I DOLLAR_TTYPE
%token DOLLAR_REAL DOLLAR_RAT DOLLAR_INT DOLLAR_TRUE DOLLAR_FALSE DOLLAR_EQUAL
%token INFERENCE INTRODUCED AXIOM_OF_CHOICE TAUTOLOGY THEORY 
%token EQUALITY AC CREATOR DESCRIPTION IQUOTE STATUS SUC UNP SAP ESA SAT FSA 
%token THM EQV TAC WEC ETH TAU WTC WTH CAX SCA TCA WCA CUP CSP ECS CSA CTH CEQ 
%token UNC WCC ECT FUN UNS WUC WCT SCC UCA NOC ASSUMPTIONS REFUTATION INCLUDE 
%token DOLLAR_THF DOLLAR_FOF DOLLAR_CNF DOLLAR_FOT
%token VAR TUPLE PROJ1 PROJ2 IN1 IN2 CASE EXISTSI ABSTRACT APP LAMBDA EXFALSO 

%token unsigned_integer general_function dollar_dollar_word single_quoted real 
%token integer
%token dollar_word lower_word upper_word rational distinct_object

%union {
        eAnyH   kindof;
        Any     *any;
        string  name;
        nameSet *ns;
        envmap  *emap;
        McasIn  *caseterm;
}
%%

TPTP_file
        : TPTP_inputs  { $$ = $1; }
	;
TPTP_inputs
        : TPTP_input { 
          $$=$1; }
        | TPTP_input TPTP_inputs  {
          if ($1.emap!=NULL && $2.emap!=NULL) {
            for (int i=0; i<$1.emap->size; i++) {
              Name name = getFreshName($2.emap);
              envmap_insert($2.emap,name,*$1.emap->vals[i]);
            }
            $$=$2;
          } else
            $$.emap=NULL;}
	;
TPTP_input
        : annotated_formula { $$=$1; }
	| include           { yyerror("Unhandled TPTP feature: include\n"); }
	;
annotated_formula
	: thf_annotated { yyerror("Unhandled TPTP feature: thf_annotated\n"); }
	| fof_annotated { $$=$1; }
	| cnf_annotated { yyerror("Unhandled TPTP feature: cnf_annotated\n"); }
	;
thf_annotated
	: THF '(' name ',' formula_role ',' thf_formula annotations ')' '.'
	;
fof_annotated
	: FOF '(' name ',' formula_role ',' fof_formula annotations ')' '.'
        { envmap *ev=NULL;
          if ($7.any!=NULL) {
            ev = malloc(sizeof(envmap));
            envmap evn = envmap_new();
            ev->size = evn.size;
            ev->bufsize = evn.bufsize;
            ev->vals = evn.vals;
            ev->keys = evn.keys;
            Name name = malloc(2);
            strcpy(name, "f");
            envmap_insert(ev,name,*$7.any);
            if ($8.any!=NULL) {
              name = malloc(2);
              strcpy(name, "t");
              envmap_insert(ev,name,*$8.any);
            }
          }
          $$.emap=ev;
        }
	;
cnf_annotated
	: CNF '(' name ',' formula_role ',' cnf_formula annotations ')' '.'
	;
annotations
        : ',' source optional_info {
          $$=$2;
        }
	|
	;
formula_role
	: lower_word
	| AXIOM
	| HYPOTHESIS
	| DEFINITION
	| ASSUMPTION
	| LEMMA
	| THEOREM
	| CONJECTURE
	| NEGATED_CONJECTURE
	| PLAIN
	| FI_DOMAIN
	| FI_FUNCTORS
	| FI_PREDICATES
	| TYPE
	| UNKNOWN
	;
thf_formula
	: thf_logic_formula 
	| thf_definition 
	| thf_sequent
	;
thf_logic_formula
	: thf_binary_formula  
	| thf_type_formula
	;
thf_binary_formula
	: thf_binary_tuple 
	| thf_binary_type
	;
thf_binary_tuple
	: thf_unitary_formula
	| thf_binary_tuple thf_pair_connective thf_unitary_formula
	;
thf_unitary_formula
	: thf_quantified_formula 
	| thf_unary_formula 
	| thf_atom				{/* here be problem */} 
	| thf_tuple 
	| thf_letrec 
	| '(' thf_logic_formula ')'
	;
thf_quantified_formula
	: thf_quantifier '[' thf_variable_list ']' ':' thf_unitary_formula
	;
thf_variable_list
	: thf_variable 
	| thf_variable ',' thf_variable_list
	;
thf_variable
	: thf_typed_variable 
	| variable
	;
thf_typed_variable
	: variable ':' thf_top_level_type
	;
thf_unary_formula
	: thf_unary_connective '(' thf_logic_formula ')'
	;
thf_atom
	: term 
	;
thf_tuple
	: '[' ']' 
	| '[' thf_tuple_list ']'
	;
thf_tuple_list
        : thf_unitary_formula
	| thf_tuple_list ',' thf_unitary_formula	{/* swapped these */}
	;
thf_type_formula
	: thf_typeable_formula ':' thf_top_level_type
	;
thf_typeable_formula
	: thf_atom 
	| thf_tuple 
	| '(' thf_logic_formula ')'
	;
thf_top_level_type
	: thf_logic_formula
	;
thf_unitary_type
	: thf_unitary_formula
	;
thf_binary_type
	: thf_mapping_type 
	| thf_xprod_type 
	| thf_union_type
	;
thf_mapping_type
	: thf_unitary_type ARROW thf_unitary_type 
	| thf_unitary_type ARROW thf_mapping_type
	;
thf_xprod_type
	: thf_unitary_type STAR thf_unitary_type 
	| thf_xprod_type STAR thf_unitary_type
	;
thf_union_type
	: thf_unitary_type PLUS thf_unitary_type 
	| thf_union_type PLUS thf_unitary_type
	;
thf_letrec
	: ASSIGN '[' thf_letrec_list ']' ':' thf_unitary_formula
	;
thf_letrec_list
	: thf_defined_var 
	| thf_defined_var ',' thf_letrec_list
	;
thf_defined_var
	: thf_variable ASSIGN thf_logic_formula 
	| '(' thf_defined_var ')'
	;
thf_definition
	: thf_defn_constant ASSIGN thf_logic_formula 
	| '(' thf_definition ')'
	;
thf_defn_constant
	: thf_type_formula
	| constant
	;
thf_sequent
	: thf_tuple GENTZEN_ARROW thf_tuple
	;
fof_formula
        : binary_formula  { $$ = $1; }
        | unitary_formula { $$ = $1; }
	;
binary_formula
	: nonassoc_binary { $$ = $1; }
	| assoc_binary    { $$ = $1; }
	;
nonassoc_binary
	: unitary_formula binary_connective unitary_formula
        { $$.any = composeBinaryConnective($2, $1.any, $3.any); }
	;
assoc_binary
        : or_formula  { $$ = $1; }
	| and_formula { $$ = $1; }
	;
or_formula
	: unitary_formula VLINE unitary_formula
        {  $$.any = composeAnyType(etOr, $1.any, $3.any); }
	| or_formula VLINE unitary_formula
        {  $$.any = composeAnyType(etOr, $1.any, $3.any); }
	;
and_formula
	: unitary_formula AND unitary_formula
        { $$.any = composeAnyType(etAnd, $1.any, $3.any); }
	| and_formula AND unitary_formula
        { $$.any = composeAnyType(etAnd, $1.any, $3.any); }
	;
unitary_formula
        : quantified_formula  { $$ = $1; }
        | unary_formula       { $$ = $1; }
	| atomic_formula      { $$ = $1; }
        | '(' fof_formula ')' { $$ = $2; }
	;
quantified_formula
	: quantifier '[' variable_list ']' ':' unitary_formula
        { $$.any = composeQuantifier($1.kindof, $3.ns, $6.any); }
	;
variable_list
        : variable
          { $$.ns = singletonSet( $1.name.name);}
	| variable ',' variable_list
        { if ($3.ns!=NULL) {
            addSet($3.ns, $1.name.name);
          };
          $$=$3;}
	;
unary_formula
	: unary_connective unitary_formula
          { $$.any = composeUnaryConnective($1, $2.any); }
	| fol_infix_unary
          { $$ = $1; }
	;
cnf_formula
	: '(' disjunction ')' 
	| disjunction
	;
disjunction
	: literal 
	| disjunction VLINE literal
	;
literal
	: atomic_formula 
	| NOT atomic_formula 
	| fol_infix_unary
	;
fol_infix_unary
	: term infix_inequality term {
          if ($1.any!=NULL && $2.name.name!=NULL && $3.any!=NULL) {
            envmap *ev = malloc(sizeof(envmap));
            envmap evn = envmap_new();
            ev->size = evn.size;
            ev->bufsize = evn.bufsize;
            ev->vals = evn.vals;
            ev->keys = evn.keys;
            Name name = malloc(2);
            strcpy(name, "l");
            envmap_insert(ev,name,*$1.any);
            Name name1 = malloc(2);
            strcpy(name1, "p");
            envmap_insert(ev,name1,*$3.any);
            $$.any = composeFunctorWithArguments($2.name,ev);
          } else {
            $$.any=NULL;
          }
        }
	;
thf_quantifier
	: quantifier 
	| SYMBOL1
	| SYMBOL2
	| SYMBOL3
	;
thf_pair_connective
	: infix_equality 
	| infix_inequality 
	| binary_connective
	| assoc_connective
	| '@'
	;
thf_unary_connective
	: unary_connective 
	| SYMBOL4
	| SYMBOL5
	;
quantifier
        : FOR_ALL      { $$.kindof = eConnForall; }
	| THERE_EXISTS { $$.kindof = eConnExists; }
	;
binary_connective
        : DOUBLE_ARROW { $$.kindof = eConnDoubleArrow; }
        | RIGHT_ARROW  { $$.kindof = eConnRightArrow; }
	| LEFT_ARROW   { $$.kindof = eConnLeftArrow; }
        | XOR          { $$.kindof = eConnUnhandled;
                         yyerror("Unhandled connective XOR"); }
	| NOR          { $$.kindof = eConnNor; }
	| NAND         { $$.kindof = eConnNand; }
	;
assoc_connective
	: VLINE
	| AND
	;
unary_connective
        : NOT          { $$.kindof = eConnNot; }
	;
atomic_formula
        : plain_atomic_formula   { $$ = $1; }
        | defined_atomic_formula { $$ = $1; }
        | system_atomic_formula  { yyerror("Unhandled TPTP system_atomic_formula"); }
	;
plain_atomic_formula
        : plain_term { $$ = $1; }
	;
defined_atomic_formula
        : defined_plain_formula
        { $$ = $1; }
        | defined_infix_formula
        { $$ = $1; }
	;
defined_plain_formula
        : defined_plain_term
        { yyerror("Unhandled TPTP feature: defined_plain_term\n"); }
        | defined_prop { $$ = $1; }
        | defined_pred '(' arguments ')'
        { yyerror("Unhandled TPTP feature: defined_pred with arguments\n"); }
        ;
defined_pred
        : atomic_defined_word
        ;
defined_prop
        : atomic_defined_word
        { yyerror("Unhandled TPTP feature: atomic_defined_word\n"); }
        | DOLLAR_TRUE { Type* t = allocType();
          t->which = etVar;
          char* nm = malloc(strlen("$true")+1);
          strcpy(nm, "$true");
          t->tVar.name = nm;
          Any* a = allocAny();
          a->which = eAnyType;
          a->mType = t;
          $$.any = a; }

        | DOLLAR_FALSE { Type* t = allocType();
          t->which = etVar;
          char* nm = malloc(strlen("$false")+1);
          strcpy(nm, "$false");
          t->tVar.name = nm;
          Any* a = allocAny();
          a->which = eAnyType;
          a->mType = t;
          $$.any = a; }
        ;
defined_infix_formula
        : term defined_infix_pred term {
          if ($1.any!=NULL && $2.name.name!=NULL && $3.any!=NULL) {
            envmap *ev = malloc(sizeof(envmap));
            envmap evn = envmap_new();
            ev->size = evn.size;
            ev->bufsize = evn.bufsize;
            ev->vals = evn.vals;
            ev->keys = evn.keys;
            Name name = malloc(2);
            strcpy(name, "l");
            envmap_insert(ev,name,*$1.any);
            Name name1 = malloc(2);
            strcpy(name1, "p");
            envmap_insert(ev,name1,*$3.any);
            $$.any = composeFunctorWithArguments($2.name,ev);
          } else {
            $$.any = NULL;
          }
        }
	;
defined_infix_pred
        : infix_equality { $$=$1; }
	;
infix_equality
        : EQUAL_SIGN {
          char* name = malloc(2);
          strcpy(name, "=");
          $$.name.which=0;
          $$.name.name=name;}
	;
infix_inequality
	: NOT_EQUAL_SIGN {
          char* name = malloc(2);
          strcpy(name, "!=");
          $$.name.which=0;
          $$.name.name=name;}
	;
system_atomic_formula
	: system_term
	;
term
	: function_term
        { if ($1.any!=NULL)
            $$.any=typeToTerm($1.any);  }
	| variable
        { $$.any = composeTermVariable($1.name); }
	;
function_term
	: plain_term 
	| defined_term
        { yyerror("Unhandled TPTP feature defined_term\n"); }
	| system_term
        { yyerror("Unhandled TPTP feature system_term\n"); }
	;
plain_term
        : constant {
          Type* t = allocType();
          t->which = etVar;
          t->tVar.name = $1.name.name;
          Any* a = allocAny();
          a->which = eAnyType;
          a->mType = t;
          $$.any = a; }
        | functor '(' arguments ')'
          { $$.any = composeFunctorWithArguments($1.name, $3.emap);
          }
	;
constant
        : functor
          { $$ = $1; }
	;
functor
        : atomic_word { $$ = $1; }
	;
defined_term
	: defined_atom 
	| defined_atomic_term
	;
defined_atom
	: number 
	| distinct_object
	;
defined_atomic_term
	: defined_plain_term
	;
defined_plain_term
	: defined_constant 
	| defined_functor '(' arguments ')'
	;
defined_constant
	: defined_functor
	;
defined_functor
	: atomic_defined_word
	;
system_term
	: system_constant 
	| system_functor '(' arguments ')'
	;
system_constant
	: system_functor
	;
system_functor
	: atomic_system_word
	;
variable
        : upper_word { createWord(&$$); }
	;
arguments
	: term
        { if ($1.any!=NULL) {
            envmap *ev = malloc(sizeof(envmap));
            envmap evn = envmap_new();
            ev->size = evn.size;
            ev->bufsize = evn.bufsize;
            ev->vals = evn.vals;
            ev->keys = evn.keys;
            Name name = malloc(2);
            strcpy(name, "o");
            envmap_insert(ev,name,*$1.any);
            $$.emap=ev;
          } else {
            $$.emap = NULL;
          }
        }
	| term ',' arguments
        { if ($1.any !=NULL && $3.emap != NULL) {
            Name name = malloc(2);
            strcpy(name, "o");
            envmap_insert($3.emap,name,*$1.any);
            $$=$3;
          } else {
            $$.emap = NULL;
          }
        }
	;
source
        : general_term {
          $$=$1;
        }
	;
optional_info
	: ',' useful_info
	| 
	;
useful_info
	: general_list
	;
include
	: INCLUDE '(' file_name formula_selection ')' '.'
	;
formula_selection
	: ',' '[' name_list ']' 
	|
	;
name_list
	: name 
	| name ',' name_list
	;
general_term
        : general_data {
          $$=$1;
        }
	| general_data ':' general_term 
	| general_list
	;
general_data
	: atomic_word 
	| atomic_word '(' general_terms ')'
        | fof_inference {
          $$=$1;
          if (!proof_parsing) {
            printf("Unexpected proof.\n");
            exit(-1);
          } }
	| variable 
	| number 
	| distinct_object 
	| formula_data
	;
formula_data
	: DOLLAR_THF '(' thf_formula ')' 
	| DOLLAR_FOF '(' fof_formula ')' 
	| DOLLAR_CNF '(' cnf_formula ')' 
	| DOLLAR_FOT '(' term ')'
	;
general_list
	: '[' ']' 
	| '[' general_terms ']'
	;
general_terms
	: general_term 
	| general_term ',' general_terms
	;
name
	: atomic_word 
	| unsigned_integer
	;
atomic_word
        : lower_word    { createWord(&$$); }
        | single_quoted { createWord(&$$); }
	;
atomic_defined_word
	: dollar_word
	;
atomic_system_word
	: dollar_dollar_word
	;
number
	: integer 
	| rational 
	| real
	; 
file_name
	: single_quoted
	;
///////////////////// INFERENCE PROOFS

fof_inference
        : INFERENCE '(' proof_term ')' {
          $$ = $3;
        }
        ;

proof_term
        : EXFALSO '(' proof_term ',' term_fof_formula  ')' {
          $$.any = createExFalso($3.any, $5.any);
        }
        | LAMBDA '(' atomic_word ',' term_fof_formula ',' proof_term ')' {
          $$.any = createLambda($3.name, $5.any, $7.any);
        }
        | APP '(' proof_term ',' proof_term ')' {
          $$.any = createApp($3.any, $5.any);
        }
        | ABSTRACT '(' atomic_word ',' term_fof_formula ','
                       atomic_word ',' term_fof_formula ','
                       proof_term ',' proof_term')' {
          $$.any = createAbstract($3.name, $5.any, $7.name, $9.any,
                                  $11.any, $13.any);
        }
        | EXISTSI '(' proof_term ',' proof_term ',' term_fof_formula ')' {
          $$.any = createExists($7.any, $3.any, $5.any);
        } 
        | CASE '(' proof_term ',' case_term ',' case_term')' {
          $$.any = createCase($3.any, $5.caseterm, $7.caseterm);
        }
        | IN1 '(' proof_term ',' term_fof_formula ')' {
          $$.any = createIn($3.any, $5.any, 1);
        }
        | IN2 '(' proof_term ',' term_fof_formula')' {
          $$.any = createIn($3.any, $5.any, 2);
        }
        | PROJ1 '(' proof_term ')' {
          $$.any = createProj($3.any, 1);
        }
        | PROJ2 '(' proof_term ')' {
          $$.any = createProj($3.any, 2);
        }
        | TUPLE '(' proof_term ',' proof_term ',' term_fof_formula ')' {
          $$.any = createTuple($7.any, $3.any, $5.any);
        }
        | VAR '(' atomic_word ')'  {
          $$.any = createTermVar($3.name);
        }
        ;

term_fof_formula
        : FOF '(' fof_formula ')' {
          $$ = $3; }
        ;

case_term
        : atomic_word ',' term_fof_formula ',' proof_term {
          $$.caseterm = createCaseTerm($1.name, $3.any, $5.any);
        }
        ;

%%
